@@ -20,17 +20,17 @@
 */
 #include "SDL_internal.h"
 
-/* Simple error handling in SDL */
+// Simple error handling in SDL
 
 #include "SDL_error_c.h"
 
-int SDL_SetError(SDL_PRINTF_FORMAT_STRING const char *fmt, ...)
+bool SDL_SetError(SDL_PRINTF_FORMAT_STRING const char *fmt, ...)
 {
-    /* Ignore call if invalid format pointer was passed */
+    // Ignore call if invalid format pointer was passed
     if (fmt) {
         va_list ap;
         int result;
-        SDL_error *error = SDL_GetErrBuf(SDL_TRUE);
+        SDL_error *error = SDL_GetErrBuf(true);
 
         error->error = SDL_ErrorCodeGeneric;
 
@@ -50,19 +50,18 @@ int SDL_SetError(SDL_PRINTF_FORMAT_STRING const char *fmt, ...)
             }
         }
 
-        if (SDL_LogGetPriority(SDL_LOG_CATEGORY_ERROR) <= SDL_LOG_PRIORITY_DEBUG) {
-            /* If we are in debug mode, print out the error message */
+        if (SDL_GetLogPriority(SDL_LOG_CATEGORY_ERROR) <= SDL_LOG_PRIORITY_DEBUG) {
+            // If we are in debug mode, print out the error message
             SDL_LogDebug(SDL_LOG_CATEGORY_ERROR, "%s", error->str);
         }
     }
 
-    return -1;
+    return false;
 }
 
-/* Available for backwards compatibility */
 const char *SDL_GetError(void)
 {
-    const SDL_error *error = SDL_GetErrBuf(SDL_FALSE);
+    const SDL_error *error = SDL_GetErrBuf(false);
 
     if (!error) {
         return "";
@@ -78,31 +77,23 @@ const char *SDL_GetError(void)
     }
 }
 
-void SDL_ClearError(void)
+bool SDL_ClearError(void)
 {
-    SDL_error *error = SDL_GetErrBuf(SDL_FALSE);
+    SDL_error *error = SDL_GetErrBuf(false);
 
     if (error) {
         error->error = SDL_ErrorCodeNone;
     }
+    return true;
 }
 
-/* Very common errors go here */
-int SDL_Error(SDL_errorcode code)
+bool SDL_OutOfMemory(void)
 {
-    switch (code) {
-    case SDL_ENOMEM:
-        SDL_GetErrBuf(SDL_TRUE)->error = SDL_ErrorCodeOutOfMemory;
-        return -1;
-    case SDL_EFREAD:
-        return SDL_SetError("Error reading from datastream");
-    case SDL_EFWRITE:
-        return SDL_SetError("Error writing to datastream");
-    case SDL_EFSEEK:
-        return SDL_SetError("Error seeking in datastream");
-    case SDL_UNSUPPORTED:
-        return SDL_SetError("That operation is not supported");
-    default:
-        return SDL_SetError("Unknown SDL error");
+    SDL_error *error = SDL_GetErrBuf(true);
+
+    if (error) {
+        error->error = SDL_ErrorCodeOutOfMemory;
     }
+    return false;
 }
+
