@@ -29,39 +29,6 @@
 #define SDL_INT_MAX ((int)(~0u>>1))
 #endif
 
-/*
- * CHANNEL LAYOUTS AS SDL EXPECTS THEM:
- *
- * (Even if the platform expects something else later, that
- * SDL will swizzle between the app and the platform).
- *
- * Abbreviations:
- * - FRONT=single mono speaker
- * - FL=front left speaker
- * - FR=front right speaker
- * - FC=front center speaker
- * - BL=back left speaker
- * - BR=back right speaker
- * - SR=surround right speaker
- * - SL=surround left speaker
- * - BC=back center speaker
- * - LFE=low-frequency speaker
- *
- * These are listed in the order they are laid out in
- * memory, so "FL+FR" means "the front left speaker is
- * layed out in memory first, then the front right, then
- * it repeats for the next audio frame".
- *
- * 1 channel (mono) layout: FRONT
- * 2 channels (stereo) layout: FL+FR
- * 3 channels (2.1) layout: FL+FR+LFE
- * 4 channels (quad) layout: FL+FR+BL+BR
- * 5 channels (4.1) layout: FL+FR+LFE+BL+BR
- * 6 channels (5.1) layout: FL+FR+FC+LFE+BL+BR
- * 7 channels (6.1) layout: FL+FR+FC+LFE+BC+SL+SR
- * 8 channels (7.1) layout: FL+FR+FC+LFE+BL+BR+SL+SR
- */
-
 #ifdef SDL_SSE3_INTRINSICS
 // Convert from stereo to mono. Average left and right.
 static void SDL_TARGETING("sse3") SDL_ConvertStereoToMono_SSE3(float *dst, const float *src, int num_frames)
@@ -132,7 +99,7 @@ static void SDL_TARGETING("sse") SDL_ConvertMonoToStereo_SSE(float *dst, const f
 // Include the autogenerated channel converters...
 #include "SDL_audio_channel_converters.h"
 
-static SDL_bool SDL_IsSupportedAudioFormat(const SDL_AudioFormat fmt)
+static bool SDL_IsSupportedAudioFormat(const SDL_AudioFormat fmt)
 {
     switch (fmt) {
     case SDL_AUDIO_U8:
@@ -143,20 +110,86 @@ static SDL_bool SDL_IsSupportedAudioFormat(const SDL_AudioFormat fmt)
     case SDL_AUDIO_S32BE:
     case SDL_AUDIO_F32LE:
     case SDL_AUDIO_F32BE:
-        return SDL_TRUE;  // supported.
+        return true;  // supported.
 
     default:
         break;
     }
 
-    return SDL_FALSE;  // unsupported.
+    return false;  // unsupported.
 }
 
-static SDL_bool SDL_IsSupportedChannelCount(const int channels)
+static bool SDL_IsSupportedChannelCount(const int channels)
 {
     return ((channels >= 1) && (channels <= 8));
 }
 
+bool SDL_ChannelMapIsBogus(const int *chmap, int channels)
+{
+    if (chmap) {
+        for (int i = 0; i < channels; i++) {
+            const int mapping = chmap[i];
+            if ((mapping < 0) || (mapping >= channels)) {
+                return true;
+            }
+        }
+    }
+    return false;
+}
+
+bool SDL_ChannelMapIsDefault(const int *chmap, int channels)
+{
+    if (chmap) {
+        for (int i = 0; i < channels; i++) {
+            if (chmap[i] != i) {
+                return false;
+            }
+        }
+    }
+    return true;
+}
+
+// Swizzle audio channels. src and dst can be the same pointer. It does not change the buffer size.
+static void SwizzleAudio(const int num_frames, void *dst, const void *src, int channels, const int *map, int bitsize)
+{
+    #define CHANNEL_SWIZZLE(bits) { \
+        Uint##bits *tdst = (Uint##bits *) dst; /* treat as UintX; we only care about moving bits and not the type here. */ \
+        const Uint##bits *tsrc = (const Uint##bits *) src; \
+        if (src != dst) {  /* don't need to copy to a temporary frame first. */ \
+            for (int i = 0; i < num_frames; i++, tsrc += channels, tdst += channels) { \
+                for (int ch = 0; ch < channels; ch++) { \
+                    tdst[ch] = tsrc[map[ch]]; \
+                } \
+            } \
+        } else { \
+            bool isstack; \
+            Uint##bits *tmp = (Uint##bits *) SDL_small_alloc(int, channels, &isstack); /* !!! FIXME: allocate this when setting the channel map instead. */ \
+            if (tmp) { \
+                for (int i = 0; i < num_frames; i++, tsrc += channels, tdst += channels) { \
+                    for (int ch = 0; ch < channels; ch++) { \
+                        tmp[ch] = tsrc[map[ch]]; \
+                    } \
+                    for (int ch = 0; ch < channels; ch++) { \
+                        tdst[ch] = tmp[ch]; \
+                    } \
+                } \
+                SDL_small_free(tmp, isstack); \
+            } \
+        } \
+    }
+
+    switch (bitsize) {
+        case 8: CHANNEL_SWIZZLE(8); break;
+        case 16: CHANNEL_SWIZZLE(16); break;
+        case 32: CHANNEL_SWIZZLE(32); break;
+        // we don't currently have int64 or double audio datatypes, so no `case 64` for now.
+        default: SDL_assert(!"Unsupported audio datatype size"); break;
+    }
+
+    #undef CHANNEL_SWIZZLE
+}
+
+
 // This does type and channel conversions _but not resampling_ (resampling happens in SDL_AudioStream).
 // This does not check parameter validity, (beyond asserts), it expects you did that already!
 // All of this has to function as if src==dst==scratch (conversion in-place), but as a convenience
@@ -164,8 +197,14 @@ static SDL_bool SDL_IsSupportedChannelCount(const int channels)
 //
 // The scratch buffer must be able to store `num_frames * CalculateMaxSampleFrameSize(src_format, src_channels, dst_format, dst_channels)` bytes.
 // If the scratch buffer is NULL, this restriction applies to the output buffer instead.
-void ConvertAudio(int num_frames, const void *src, SDL_AudioFormat src_format, int src_channels,
-                  void *dst, SDL_AudioFormat dst_format, int dst_channels, void* scratch)
+//
+// Since this is a convenient point that audio goes through even if it doesn't need format conversion,
+// we also handle gain adjustment here, so we don't have to make another pass over the data later.
+// Strictly speaking, this is also a "conversion".  :)
+void ConvertAudio(int num_frames,
+                  const void *src, SDL_AudioFormat src_format, int src_channels, const int *src_map,
+                  void *dst, SDL_AudioFormat dst_format, int dst_channels, const int *dst_map,
+                  void* scratch, float gain)
 {
     SDL_assert(src != NULL);
     SDL_assert(dst != NULL);
@@ -188,11 +227,13 @@ void ConvertAudio(int num_frames, const void *src, SDL_AudioFormat src_format, i
     const int dst_sample_frame_size = (dst_bitsize / 8) * dst_channels;
 
     /* Type conversion goes like this now:
+        - swizzle through source channel map to "standard" layout.
         - byteswap to CPU native format first if necessary.
         - convert to native Float32 if necessary.
         - change channel count if necessary.
         - convert to final data format.
         - byteswap back to foreign format if necessary.
+        - swizzle through dest channel map from "standard" layout.
 
        The expectation is we can process data faster in float32
        (possibly with SIMD), and making several passes over the same
@@ -201,11 +242,20 @@ void ConvertAudio(int num_frames, const void *src, SDL_AudioFormat src_format, i
        (script-generated) custom converters for every data type and
        it was a bloat on SDL compile times and final library size. */
 
+    // swizzle input to "standard" format if necessary.
+    if (src_map) {
+        void* buf = scratch ? scratch : dst;  // use scratch if available, since it has to be big enough to hold src, unless it's NULL, then dst has to be.
+        SwizzleAudio(num_frames, buf, src, src_channels, src_map, src_bitsize);
+        src = buf;
+    }
+
     // see if we can skip float conversion entirely.
-    if (src_channels == dst_channels) {
+    if ((src_channels == dst_channels) && (gain == 1.0f)) {
         if (src_format == dst_format) {
             // nothing to do, we're already in the right format, just copy it over if necessary.
-            if (src != dst) {
+            if (dst_map) {
+                SwizzleAudio(num_frames, dst, src, dst_channels, dst_map, dst_bitsize);
+            } else if (src != dst) {
                 SDL_memcpy(dst, src, num_frames * dst_sample_frame_size);
             }
             return;
@@ -213,7 +263,11 @@ void ConvertAudio(int num_frames, const void *src, SDL_AudioFormat src_format, i
 
         // just a byteswap needed?
         if ((src_format ^ dst_format) == SDL_AUDIO_MASK_BIG_ENDIAN) {
-            ConvertAudioSwapEndian(dst, src, num_frames * src_channels, src_bitsize);
+            if (dst_map) {  // do this first, in case we duplicate channels, we can avoid an extra copy if src != dst.
+                SwizzleAudio(num_frames, dst, src, dst_channels, dst_map, dst_bitsize);
+                src = dst;
+            }
+            ConvertAudioSwapEndian(dst, src, num_frames * dst_channels, dst_bitsize);
             return;  // all done.
         }
     }
@@ -222,9 +276,9 @@ void ConvertAudio(int num_frames, const void *src, SDL_AudioFormat src_format, i
         scratch = dst;
     }
 
-    const SDL_bool srcconvert = src_format != SDL_AUDIO_F32;
-    const SDL_bool channelconvert = src_channels != dst_channels;
-    const SDL_bool dstconvert = dst_format != SDL_AUDIO_F32;
+    const bool srcconvert = src_format != SDL_AUDIO_F32;
+    const bool channelconvert = src_channels != dst_channels;
+    const bool dstconvert = dst_format != SDL_AUDIO_F32;
 
     // get us to float format.
     if (srcconvert) {
@@ -233,6 +287,23 @@ void ConvertAudio(int num_frames, const void *src, SDL_AudioFormat src_format, i
         src = buf;
     }
 
+    // Gain adjustment
+    if (gain != 1.0f) {
+        float *buf = (float *)(dstconvert ? scratch : dst);
+        const int total_samples = num_frames * src_channels;
+        if (src == buf) {
+            for (int i = 0; i < total_samples; i++) {
+                buf[i] *= gain;
+            }
+        } else {
+            float *fsrc = (float *)src;
+            for (int i = 0; i < total_samples; i++) {
+                buf[i] = fsrc[i] * gain;
+            }
+        }
+        src = buf;
+    }
+
     // Channel conversion
 
     if (channelconvert) {
@@ -275,6 +346,10 @@ void ConvertAudio(int num_frames, const void *src, SDL_AudioFormat src_format, i
     }
 
     SDL_assert(src == dst);  // if we got here, we _had_ to have done _something_. Otherwise, we should have memcpy'd!
+
+    if (dst_map) {
+        SwizzleAudio(num_frames, dst, src, dst_channels, dst_map, dst_bitsize);
+    }
 }
 
 // Calculate the largest frame size needed to convert between the two formats.
@@ -302,19 +377,27 @@ static Sint64 GetAudioStreamResampleRate(SDL_AudioStream* stream, int src_freq,
     return resample_rate;
 }
 
-static int UpdateAudioStreamInputSpec(SDL_AudioStream *stream, const SDL_AudioSpec *spec)
+static bool UpdateAudioStreamInputSpec(SDL_AudioStream *stream, const SDL_AudioSpec *spec, const int *chmap)
 {
-    if (AUDIO_SPECS_EQUAL(stream->input_spec, *spec)) {
-        return 0;
+    if (SDL_AudioSpecsEqual(&stream->input_spec, spec, stream->input_chmap, chmap)) {
+        return true;
     }
 
-    if (SDL_ResetAudioQueueHistory(stream->queue, SDL_GetResamplerHistoryFrames()) != 0) {
-        return -1;
+    if (!SDL_ResetAudioQueueHistory(stream->queue, SDL_GetResamplerHistoryFrames())) {
+        return false;
+    }
+
+    if (!chmap) {
+        stream->input_chmap = NULL;
+    } else {
+        const size_t chmaplen = sizeof (*chmap) * spec->channels;
+        stream->input_chmap = stream->input_chmap_storage;
+        SDL_memcpy(stream->input_chmap, chmap, chmaplen);
     }
 
     SDL_copyp(&stream->input_spec, spec);
 
-    return 0;
+    return true;
 }
 
 SDL_AudioStream *SDL_CreateAudioStream(const SDL_AudioSpec *src_spec, const SDL_AudioSpec *dst_spec)
@@ -322,34 +405,35 @@ SDL_AudioStream *SDL_CreateAudioStream(const SDL_AudioSpec *src_spec, const SDL_
     SDL_ChooseAudioConverters();
     SDL_SetupAudioResampler();
 
-    SDL_AudioStream *retval = (SDL_AudioStream *)SDL_calloc(1, sizeof(SDL_AudioStream));
-    if (!retval) {
+    SDL_AudioStream *result = (SDL_AudioStream *)SDL_calloc(1, sizeof(SDL_AudioStream));
+    if (!result) {
         return NULL;
     }
 
-    retval->freq_ratio = 1.0f;
-    retval->queue = SDL_CreateAudioQueue(8192);
+    result->freq_ratio = 1.0f;
+    result->gain = 1.0f;
+    result->queue = SDL_CreateAudioQueue(8192);
 
-    if (!retval->queue) {
-        SDL_free(retval);
+    if (!result->queue) {
+        SDL_free(result);
         return NULL;
     }
 
-    retval->lock = SDL_CreateMutex();
-    if (!retval->lock) {
-        SDL_free(retval->queue);
-        SDL_free(retval);
+    result->lock = SDL_CreateMutex();
+    if (!result->lock) {
+        SDL_free(result->queue);
+        SDL_free(result);
         return NULL;
     }
 
-    OnAudioStreamCreated(retval);
+    OnAudioStreamCreated(result);
 
-    if (SDL_SetAudioStreamFormat(retval, src_spec, dst_spec) == -1) {
-        SDL_DestroyAudioStream(retval);
+    if (!SDL_SetAudioStreamFormat(result, src_spec, dst_spec)) {
+        SDL_DestroyAudioStream(result);
         return NULL;
     }
 
-    return retval;
+    return result;
 }
 
 SDL_PropertiesID SDL_GetAudioStreamProperties(SDL_AudioStream *stream)
@@ -364,7 +448,7 @@ SDL_PropertiesID SDL_GetAudioStreamProperties(SDL_AudioStream *stream)
     return stream->props;
 }
 
-int SDL_SetAudioStreamGetCallback(SDL_AudioStream *stream, SDL_AudioStreamCallback callback, void *userdata)
+bool SDL_SetAudioStreamGetCallback(SDL_AudioStream *stream, SDL_AudioStreamCallback callback, void *userdata)
 {
     if (!stream) {
         return SDL_InvalidParamError("stream");
@@ -373,10 +457,10 @@ int SDL_SetAudioStreamGetCallback(SDL_AudioStream *stream, SDL_AudioStreamCallba
     stream->get_callback = callback;
     stream->get_callback_userdata = userdata;
     SDL_UnlockMutex(stream->lock);
-    return 0;
+    return true;
 }
 
-int SDL_SetAudioStreamPutCallback(SDL_AudioStream *stream, SDL_AudioStreamCallback callback, void *userdata)
+bool SDL_SetAudioStreamPutCallback(SDL_AudioStream *stream, SDL_AudioStreamCallback callback, void *userdata)
 {
     if (!stream) {
         return SDL_InvalidParamError("stream");
@@ -385,28 +469,28 @@ int SDL_SetAudioStreamPutCallback(SDL_AudioStream *stream, SDL_AudioStreamCallba
     stream->put_callback = callback;
     stream->put_callback_userdata = userdata;
     SDL_UnlockMutex(stream->lock);
-    return 0;
+    return true;
 }
 
-int SDL_LockAudioStream(SDL_AudioStream *stream)
+bool SDL_LockAudioStream(SDL_AudioStream *stream)
 {
     if (!stream) {
         return SDL_InvalidParamError("stream");
     }
     SDL_LockMutex(stream->lock);
-    return 0;
+    return true;
 }
 
-int SDL_UnlockAudioStream(SDL_AudioStream *stream)
+bool SDL_UnlockAudioStream(SDL_AudioStream *stream)
 {
     if (!stream) {
         return SDL_InvalidParamError("stream");
     }
     SDL_UnlockMutex(stream->lock);
-    return 0;
+    return true;
 }
 
-int SDL_GetAudioStreamFormat(SDL_AudioStream *stream, SDL_AudioSpec *src_spec, SDL_AudioSpec *dst_spec)
+bool SDL_GetAudioStreamFormat(SDL_AudioStream *stream, SDL_AudioSpec *src_spec, SDL_AudioSpec *dst_spec)
 {
     if (!stream) {
         return SDL_InvalidParamError("stream");
@@ -427,10 +511,10 @@ int SDL_GetAudioStreamFormat(SDL_AudioStream *stream, SDL_AudioSpec *src_spec, S
         return SDL_SetError("Stream has no destination format");
     }
 
-    return 0;
+    return true;
 }
 
-int SDL_SetAudioStreamFormat(SDL_AudioStream *stream, const SDL_AudioSpec *src_spec, const SDL_AudioSpec *dst_spec)
+bool SDL_SetAudioStreamFormat(SDL_AudioStream *stream, const SDL_AudioSpec *src_spec, const SDL_AudioSpec *dst_spec)
 {
     if (!stream) {
         return SDL_InvalidParamError("stream");
@@ -472,7 +556,7 @@ int SDL_SetAudioStreamFormat(SDL_AudioStream *stream, const SDL_AudioSpec *src_s
 
     // quietly refuse to change the format of the end currently bound to a device.
     if (stream->bound_device) {
-        if (stream->bound_device->physical_device->iscapture) {
+        if (stream->bound_device->physical_device->recording) {
             src_spec = NULL;
         } else {
             dst_spec = NULL;
@@ -480,16 +564,112 @@ int SDL_SetAudioStreamFormat(SDL_AudioStream *stream, const SDL_AudioSpec *src_s
     }
 
     if (src_spec) {
+        if (src_spec->channels != stream->src_spec.channels) {
+            SDL_free(stream->src_chmap);
+            stream->src_chmap = NULL;
+        }
         SDL_copyp(&stream->src_spec, src_spec);
     }
 
     if (dst_spec) {
+        if (dst_spec->channels != stream->dst_spec.channels) {
+            SDL_free(stream->dst_chmap);
+            stream->dst_chmap = NULL;
+        }
         SDL_copyp(&stream->dst_spec, dst_spec);
     }
 
     SDL_UnlockMutex(stream->lock);
 
-    return 0;
+    return true;
+}
+
+bool SetAudioStreamChannelMap(SDL_AudioStream *stream, const SDL_AudioSpec *spec, int **stream_chmap, const int *chmap, int channels, int isinput)
+{
+    if (!stream) {
+        return SDL_InvalidParamError("stream");
+    }
+
+    bool result = true;
+
+    SDL_LockMutex(stream->lock);
+
+    if (channels != spec->channels) {
+        result = SDL_SetError("Wrong number of channels");
+    } else if (!*stream_chmap && !chmap) {
+        // already at default, we're good.
+    } else if (*stream_chmap && chmap && (SDL_memcmp(*stream_chmap, chmap, sizeof (*chmap) * channels) == 0)) {
+        // already have this map, don't allocate/copy it again.
+    } else if (SDL_ChannelMapIsBogus(chmap, channels)) {
+        result = SDL_SetError("Invalid channel mapping");
+    } else if ((isinput != -1) && stream->bound_device && (!!isinput == !!stream->bound_device->physical_device->recording)) {
+        // quietly refuse to change the format of the end currently bound to a device.
+    } else {
+        if (SDL_ChannelMapIsDefault(chmap, channels)) {
+            chmap = NULL;  // just apply a default mapping.
+        }
+        if (chmap) {
+            int *dupmap = SDL_ChannelMapDup(chmap, channels);
+            if (!dupmap) {
+                result = SDL_SetError("Invalid channel mapping");
+            } else {
+                SDL_free(*stream_chmap);
+                *stream_chmap = dupmap;
+            }
+        } else {
+            SDL_free(*stream_chmap);
+            *stream_chmap = NULL;
+        }
+    }
+
+    SDL_UnlockMutex(stream->lock);
+    return result;
+}
+
+bool SDL_SetAudioStreamInputChannelMap(SDL_AudioStream *stream, const int *chmap, int channels)
+{
+    return SetAudioStreamChannelMap(stream, &stream->src_spec, &stream->src_chmap, chmap, channels, true);
+}
+
+bool SDL_SetAudioStreamOutputChannelMap(SDL_AudioStream *stream, const int *chmap, int channels)
+{
+    return SetAudioStreamChannelMap(stream, &stream->dst_spec, &stream->dst_chmap, chmap, channels, false);
+}
+
+int *SDL_GetAudioStreamInputChannelMap(SDL_AudioStream *stream, int *count)
+{
+    int *result = NULL;
+    int channels = 0;
+    if (stream) {
+        SDL_LockMutex(stream->lock);
+        channels = stream->src_spec.channels;
+        result = SDL_ChannelMapDup(stream->src_chmap, channels);
+        SDL_UnlockMutex(stream->lock);
+    }
+
+    if (count) {
+        *count = channels;
+    }
+
+    return result;
+}
+
+int *SDL_GetAudioStreamOutputChannelMap(SDL_AudioStream *stream, int *count)
+{
+    int *result = NULL;
+    int channels = 0;
+    if (stream) {
+        SDL_LockMutex(stream->lock);
+        channels = stream->dst_spec.channels;
+        result = SDL_ChannelMapDup(stream->dst_chmap, channels);
+        SDL_UnlockMutex(stream->lock);
+    }
+
+    if (count) {
+        *count = channels;
+    }
+
+    return result;
 }
 
 float SDL_GetAudioStreamFrequencyRatio(SDL_AudioStream *stream)
@@ -506,7 +686,7 @@ float SDL_GetAudioStreamFrequencyRatio(SDL_AudioStream *stream)
     return freq_ratio;
 }
 
-int SDL_SetAudioStreamFrequencyRatio(SDL_AudioStream *stream, float freq_ratio)
+bool SDL_SetAudioStreamFrequencyRatio(SDL_AudioStream *stream, float freq_ratio)
 {
     if (!stream) {
         return SDL_InvalidParamError("stream");
@@ -526,10 +706,39 @@ int SDL_SetAudioStreamFrequencyRatio(SDL_AudioStream *stream, float freq_ratio)
     stream->freq_ratio = freq_ratio;
     SDL_UnlockMutex(stream->lock);
 
-    return 0;
+    return true;
 }
 
-static int CheckAudioStreamIsFullySetup(SDL_AudioStream *stream)
+float SDL_GetAudioStreamGain(SDL_AudioStream *stream)
+{
+    if (!stream) {
+        SDL_InvalidParamError("stream");
+        return -1.0f;
+    }
+
+    SDL_LockMutex(stream->lock);
+    const float gain = stream->gain;
+    SDL_UnlockMutex(stream->lock);
+
+    return gain;
+}
+
+bool SDL_SetAudioStreamGain(SDL_AudioStream *stream, float gain)
+{
+    if (!stream) {
+        return SDL_InvalidParamError("stream");
+    } else if (gain < 0.0f) {
+        return SDL_InvalidParamError("gain");
+    }
+
+    SDL_LockMutex(stream->lock);
+    stream->gain = gain;
+    SDL_UnlockMutex(stream->lock);
+
+    return true;
+}
+
+static bool CheckAudioStreamIsFullySetup(SDL_AudioStream *stream)
 {
     if (stream->src_spec.format == 0) {
         return SDL_SetError("Stream has no source format");
@@ -537,10 +746,10 @@ static int CheckAudioStreamIsFullySetup(SDL_AudioStream *stream)
         return SDL_SetError("Stream has no destination format");
     }
 
-    return 0;
+    return true;
 }
 
-static int PutAudioStreamBuffer(SDL_AudioStream *stream, const void *buf, int len, SDL_ReleaseAudioBufferCallback callback, void* userdata)
+static bool PutAudioStreamBuffer(SDL_AudioStream *stream, const void *buf, int len, SDL_ReleaseAudioBufferCallback callback, void* userdata)
 {
 #if DEBUG_AUDIOSTREAM
     SDL_Log("AUDIOSTREAM: wants to put %d bytes", len);
@@ -548,9 +757,9 @@ static int PutAudioStreamBuffer(SDL_AudioStream *stream, const void *buf, int le
 
     SDL_LockMutex(stream->lock);
 
-    if (CheckAudioStreamIsFullySetup(stream) != 0) {
+    if (!CheckAudioStreamIsFullySetup(stream)) {
         SDL_UnlockMutex(stream->lock);
-        return -1;
+        return false;
     }
 
     if ((len % SDL_AUDIO_FRAMESIZE(stream->src_spec)) != 0) {
@@ -561,25 +770,25 @@ static int PutAudioStreamBuffer(SDL_AudioStream *stream, const void *buf, int le
     SDL_AudioTrack* track = NULL;
 
     if (callback) {
-        track = SDL_CreateAudioTrack(stream->queue, &stream->src_spec, (Uint8 *)buf, len, len, callback, userdata);
+        track = SDL_CreateAudioTrack(stream->queue, &stream->src_spec, stream->src_chmap, (Uint8 *)buf, len, len, callback, userdata);
 
         if (!track) {
             SDL_UnlockMutex(stream->lock);
-            return -1;
+            return false;
         }
     }
 
     const int prev_available = stream->put_callback ? SDL_GetAudioStreamAvailable(stream) : 0;
 
-    int retval = 0;
+    bool result = true;
 
     if (track) {
         SDL_AddTrackToAudioQueue(stream->queue, track);
     } else {
-        retval = SDL_WriteToAudioQueue(stream->queue, &stream->src_spec, (const Uint8 *)buf, len);
+        result = SDL_WriteToAudioQueue(stream->queue, &stream->src_spec, stream->src_chmap, (const Uint8 *)buf, len);
     }
 
-    if (retval == 0) {
+    if (result) {
         if (stream->put_callback) {
             const int newavail = SDL_GetAudioStreamAvailable(stream) - prev_available;
             stream->put_callback(stream->put_callback_userdata, stream, newavail, newavail);
@@ -588,7 +797,7 @@ static int PutAudioStreamBuffer(SDL_AudioStream *stream, const void *buf, int le
 
     SDL_UnlockMutex(stream->lock);
 
-    return retval;
+    return result;
 }
 
 static void SDLCALL FreeAllocatedAudioBuffer(void *userdata, const void *buf, int len)
@@ -596,7 +805,7 @@ static void SDLCALL FreeAllocatedAudioBuffer(void *userdata, const void *buf, in
     SDL_free((void*) buf);
 }
 
-int SDL_PutAudioStreamData(SDL_AudioStream *stream, const void *buf, int len)
+bool SDL_PutAudioStreamData(SDL_AudioStream *stream, const void *buf, int len)
 {
     if (!stream) {
         return SDL_InvalidParamError("stream");
@@ -605,7 +814,7 @@ int SDL_PutAudioStreamData(SDL_AudioStream *stream, const void *buf, int len)
     } else if (len < 0) {
         return SDL_InvalidParamError("len");
     } else if (len == 0) {
-        return 0; // nothing to do.
+        return true; // nothing to do.
     }
 
     // When copying in large amounts of data, try and do as much work as possible
@@ -613,28 +822,26 @@ int SDL_PutAudioStreamData(SDL_AudioStream *stream, const void *buf, int len)
     const int large_input_thresh = 64 * 1024;
 
     if (len >= large_input_thresh) {
-        void* data = SDL_malloc(len);
+        void *data = SDL_malloc(len);
 
         if (!data) {
-            return -1;
+            return false;
         }
 
         SDL_memcpy(data, buf, len);
         buf = data;
 
-        int ret = PutAudioStreamBuffer(stream, buf, len, FreeAllocatedAudioBuffer, NULL);
-
-        if (ret < 0) {
+        bool ret = PutAudioStreamBuffer(stream, buf, len, FreeAllocatedAudioBuffer, NULL);
+        if (!ret) {
             SDL_free(data);
         }
-
         return ret;
     }
 
     return PutAudioStreamBuffer(stream, buf, len, NULL, NULL);
 }
 
-int SDL_FlushAudioStream(SDL_AudioStream *stream)
+bool SDL_FlushAudioStream(SDL_AudioStream *stream)
 {
     if (!stream) {
         return SDL_InvalidParamError("stream");
@@ -644,7 +851,7 @@ int SDL_FlushAudioStream(SDL_AudioStream *stream)
     SDL_FlushAudioQueue(stream->queue);
     SDL_UnlockMutex(stream->lock);
 
-    return 0;
+    return true;
 }
 
 /* this does not save the previous contents of stream->work_buffer. It's a work buffer!!
@@ -655,7 +862,7 @@ static Uint8 *EnsureAudioStreamWorkBufferSize(SDL_AudioStream *stream, size_t ne
         return stream->work_buffer;
     }
 
-    Uint8 *ptr = (Uint8 *) SDL_aligned_alloc(SDL_SIMDGetAlignment(), newlen);
+    Uint8 *ptr = (Uint8 *) SDL_aligned_alloc(SDL_GetSIMDAlignment(), newlen);
     if (!ptr) {
         return NULL;  // previous work buffer is still valid!
     }
@@ -667,22 +874,27 @@ static Uint8 *EnsureAudioStreamWorkBufferSize(SDL_AudioStream *stream, size_t ne
 }
 
 static Sint64 NextAudioStreamIter(SDL_AudioStream* stream, void** inout_iter,
-    Sint64* inout_resample_offset, SDL_AudioSpec* out_spec, SDL_bool* out_flushed)
+    Sint64* inout_resample_offset, SDL_AudioSpec* out_spec, int **out_chmap, bool* out_flushed)
 {
     SDL_AudioSpec spec;
-    SDL_bool flushed;
-    size_t queued_bytes = SDL_NextAudioQueueIter(stream->queue, inout_iter, &spec, &flushed);
+    bool flushed;
+    int *chmap;
+    size_t queued_bytes = SDL_NextAudioQueueIter(stream->queue, inout_iter, &spec, &chmap, &flushed);
 
     if (out_spec) {
         SDL_copyp(out_spec, &spec);
     }
 
+    if (out_chmap) {
+        *out_chmap = chmap;
+    }
+
     // There is infinite audio available, whether or not we are resampling
     if (queued_bytes == SDL_SIZE_MAX) {
         *inout_resample_offset = 0;
 
         if (out_flushed) {
-            *out_flushed = SDL_FALSE;
+            *out_flushed = false;
         }
 
         return SDL_MAX_SINT32;
@@ -724,7 +936,7 @@ static Sint64 GetAudioStreamAvailableFrames(SDL_AudioStream* stream, Sint64* out
     Sint64 output_frames = 0;
 
     while (iter) {
-        output_frames += NextAudioStreamIter(stream, &iter, &resample_offset, NULL, NULL);
+        output_frames += NextAudioStreamIter(stream, &iter, &resample_offset, NULL, NULL, NULL);
 
         // Already got loads of frames. Just clamp it to something reasonable
         if (output_frames >= SDL_MAX_SINT32) {
@@ -740,23 +952,23 @@ static Sint64 GetAudioStreamAvailableFrames(SDL_AudioStream* stream, Sint64* out
     return output_frames;
 }
 
-static Sint64 GetAudioStreamHead(SDL_AudioStream* stream, SDL_AudioSpec* out_spec, SDL_bool* out_flushed)
+static Sint64 GetAudioStreamHead(SDL_AudioStream* stream, SDL_AudioSpec* out_spec, int **out_chmap, bool* out_flushed)
 {
     void* iter = SDL_BeginAudioQueueIter(stream->queue);
 
     if (!iter) {
         SDL_zerop(out_spec);
-        *out_flushed = SDL_FALSE;
+        *out_flushed = false;
         return 0;
     }
 
     Sint64 resample_offset = stream->resample_offset;
-    return NextAudioStreamIter(stream, &iter, &resample_offset, out_spec, out_flushed);
+    return NextAudioStreamIter(stream, &iter, &resample_offset, out_spec, out_chmap, out_flushed);
 }
 
 // You must hold stream->lock and validate your parameters before calling this!
 // Enough input data MUST be available!
-static int GetAudioStreamDataInternal(SDL_AudioStream *stream, void *buf, int output_frames)
+static bool GetAudioStreamDataInternal(SDL_AudioStream *stream, void *buf, int output_frames, float gain)
 {
     const SDL_AudioSpec* src_spec = &stream->input_spec;
     const SDL_AudioSpec* dst_spec = &stream->dst_spec;
@@ -766,6 +978,7 @@ static int GetAudioStreamDataInternal(SDL_AudioStream *stream, void *buf, int ou
 
     const SDL_AudioFormat dst_format = dst_spec->format;
     const int dst_channels = dst_spec->channels;
+    const int *dst_map = stream->dst_chmap;
 
     const int max_frame_size = CalculateMaxFrameSize(src_format, src_channels, dst_format, dst_channels);
     const Sint64 resample_rate = GetAudioStreamResampleRate(stream, src_spec->freq, stream->resample_offset);
@@ -785,22 +998,22 @@ static int GetAudioStreamDataInternal(SDL_AudioStream *stream, void *buf, int ou
             work_buffer = EnsureAudioStreamWorkBufferSize(stream, output_frames * max_frame_size);
 
             if (!work_buffer) {
-                return -1;
+                return false;
             }
         }
 
-        if (SDL_ReadFromAudioQueue(stream->queue, buf, dst_format, dst_channels, 0, output_frames, 0, work_buffer) != buf) {
+        if (SDL_ReadFromAudioQueue(stream->queue, (Uint8 *)buf, dst_format, dst_channels, dst_map, 0, output_frames, 0, work_buffer, gain) != buf) {
             return SDL_SetError("Not enough data in queue");
         }
 
-        return 0;
+        return true;
     }
 
     // Time to do some resampling!
     // Calculate the number of input frames necessary for this request.
     // Because resampling happens "between" frames, The same number of output_frames
     // can require a different number of input_frames, depending on the resample_offset.
-    // Infact, input_frames can sometimes even be zero when upsampling.
+    // In fact, input_frames can sometimes even be zero when upsampling.
     const int input_frames = (int) SDL_GetResamplerInputFrames(output_frames, resample_rate, stream->resample_offset);
 
     const int padding_frames = SDL_GetResamplerPaddingFrames(resample_rate);
@@ -838,7 +1051,7 @@ static int GetAudioStreamDataInternal(SDL_AudioStream *stream, void *buf, int ou
         work_buffer_capacity = SDL_max(work_buffer_capacity, resample_convert_bytes);
 
         // SIMD-align the buffer
-        int simd_alignment = (int) SDL_SIMDGetAlignment();
+        int simd_alignment = (int) SDL_GetSIMDAlignment();
         work_buffer_capacity += simd_alignment - 1;
         work_buffer_capacity -= work_buffer_capacity % simd_alignment;
 
@@ -851,12 +1064,18 @@ static int GetAudioStreamDataInternal(SDL_AudioStream *stream, void *buf, int ou
     Uint8* work_buffer = EnsureAudioStreamWorkBufferSize(stream, work_buffer_capacity);
 
     if (!work_buffer) {
-        return -1;
+        return false;
     }
 
+    // adjust gain either before resampling or after, depending on which point has less
+    // samples to process.
+    const float preresample_gain = (input_frames > output_frames) ? 1.0f : gain;
+    const float postresample_gain = (input_frames > output_frames) ? gain : 1.0f;
+
+    // (dst channel map is NULL because we'll do the final swizzle on ConvertAudio after resample.)
     const Uint8* input_buffer = SDL_ReadFromAudioQueue(stream->queue,
-        NULL, resample_format, resample_channels,
-        padding_frames, input_frames, padding_frames, work_buffer);
+        NULL, resample_format, resample_channels, NULL,
+        padding_frames, input_frames, padding_frames, work_buffer, preresample_gain);
 
     if (!input_buffer) {
         return SDL_SetError("Not enough data in queue (resample)");
@@ -872,14 +1091,14 @@ static int GetAudioStreamDataInternal(SDL_AudioStream *stream, void *buf, int ou
                   (float*) resample_buffer, output_frames,
                   resample_rate, &stream->resample_offset);
 
-    // Convert to the final format, if necessary
-    ConvertAudio(output_frames, resample_buffer, resample_format, resample_channels, buf, dst_format, dst_channels, work_buffer);
+    // Convert to the final format, if necessary (src channel map is NULL because SDL_ReadFromAudioQueue already handled this).
+    ConvertAudio(output_frames, resample_buffer, resample_format, resample_channels, NULL, buf, dst_format, dst_channels, dst_map, work_buffer, postresample_gain);
 
-    return 0;
+    return true;
 }
 
 // get converted/resampled data from the stream
-int SDL_GetAudioStreamData(SDL_AudioStream *stream, void *voidbuf, int len)
+int SDL_GetAudioStreamDataAdjustGain(SDL_AudioStream *stream, void *voidbuf, int len, float extra_gain)
 {
     Uint8 *buf = (Uint8 *) voidbuf;
 
@@ -888,22 +1107,26 @@ int SDL_GetAudioStreamData(SDL_AudioStream *stream, void *voidbuf, int len)
 #endif
 
     if (!stream) {
-        return SDL_InvalidParamError("stream");
+        SDL_InvalidParamError("stream");
+        return -1;
     } else if (!buf) {
-        return SDL_InvalidParamError("buf");
+        SDL_InvalidParamError("buf");
+        return -1;
     } else if (len < 0) {
-        return SDL_InvalidParamError("len");
+        SDL_InvalidParamError("len");
+        return -1;
     } else if (len == 0) {
         return 0; // nothing to do.
     }
 
     SDL_LockMutex(stream->lock);
 
-    if (CheckAudioStreamIsFullySetup(stream) != 0) {
+    if (!CheckAudioStreamIsFullySetup(stream)) {
         SDL_UnlockMutex(stream->lock);
         return -1;
     }
 
+    const float gain = stream->gain * extra_gain;
     const int dst_frame_size = SDL_AUDIO_FRAMESIZE(stream->dst_spec);
 
     len -= len % dst_frame_size;  // chop off any fractional sample frame.
@@ -938,21 +1161,23 @@ int SDL_GetAudioStreamData(SDL_AudioStream *stream, void *voidbuf, int len)
     while (total < len) {
         // Audio is processed a track at a time.
         SDL_AudioSpec input_spec;
-        SDL_bool flushed;
-        const Sint64 available_frames = GetAudioStreamHead(stream, &input_spec, &flushed);
+        int *input_chmap;
+        bool flushed;
+        const Sint64 available_frames = GetAudioStreamHead(stream, &input_spec, &input_chmap, &flushed);
 
         if (available_frames == 0) {
             if (flushed) {
                 SDL_PopAudioQueueHead(stream->queue);
                 SDL_zero(stream->input_spec);
                 stream->resample_offset = 0;
+                stream->input_chmap = NULL;
                 continue;
             }
             // There are no frames available, but the track hasn't been flushed, so more might be added later.
             break;
         }
 
-        if (UpdateAudioStreamInputSpec(stream, &input_spec) != 0) {
+        if (!UpdateAudioStreamInputSpec(stream, &input_spec, input_chmap)) {
             total = total ? total : -1;
             break;
         }
@@ -963,7 +1188,7 @@ int SDL_GetAudioStreamData(SDL_AudioStream *stream, void *voidbuf, int len)
         output_frames = SDL_min(output_frames, chunk_size);
         output_frames = (int) SDL_min(output_frames, available_frames);
 
-        if (GetAudioStreamDataInternal(stream, &buf[total], output_frames) != 0) {
+        if (!GetAudioStreamDataInternal(stream, &buf[total], output_frames, gain)) {
             total = total ? total : -1;
             break;
         }
@@ -980,16 +1205,22 @@ int SDL_GetAudioStreamData(SDL_AudioStream *stream, void *voidbuf, int len)
     return total;
 }
 
+int SDL_GetAudioStreamData(SDL_AudioStream *stream, void *voidbuf, int len)
+{
+    return SDL_GetAudioStreamDataAdjustGain(stream, voidbuf, len, 1.0f);
+}
+
 // number of converted/resampled bytes available for output
 int SDL_GetAudioStreamAvailable(SDL_AudioStream *stream)
 {
     if (!stream) {
-        return SDL_InvalidParamError("stream");
+        SDL_InvalidParamError("stream");
+        return -1;
     }
 
     SDL_LockMutex(stream->lock);
 
-    if (CheckAudioStreamIsFullySetup(stream) != 0) {
+    if (!CheckAudioStreamIsFullySetup(stream)) {
         SDL_UnlockMutex(stream->lock);
         return 0;
     }
@@ -1009,7 +1240,8 @@ int SDL_GetAudioStreamAvailable(SDL_AudioStream *stream)
 int SDL_GetAudioStreamQueued(SDL_AudioStream *stream)
 {
     if (!stream) {
-        return SDL_InvalidParamError("stream");
+        SDL_InvalidParamError("stream");
+        return -1;
     }
 
     SDL_LockMutex(stream->lock);
@@ -1022,7 +1254,7 @@ int SDL_GetAudioStreamQueued(SDL_AudioStream *stream)
     return (int) SDL_min(total, SDL_INT_MAX);
 }
 
-int SDL_ClearAudioStream(SDL_AudioStream *stream)
+bool SDL_ClearAudioStream(SDL_AudioStream *stream)
 {
     if (!stream) {
         return SDL_InvalidParamError("stream");
@@ -1032,10 +1264,11 @@ int SDL_ClearAudioStream(SDL_AudioStream *stream)
 
     SDL_ClearAudioQueue(stream->queue);
     SDL_zero(stream->input_spec);
+    stream->input_chmap = NULL;
     stream->resample_offset = 0;
 
     SDL_UnlockMutex(stream->lock);
-    return 0;
+    return true;
 }
 
 void SDL_DestroyAudioStream(SDL_AudioStream *stream)
@@ -1048,7 +1281,7 @@ void SDL_DestroyAudioStream(SDL_AudioStream *stream)
 
     OnAudioStreamDestroy(stream);
 
-    const SDL_bool simplified = stream->simplified;
+    const bool simplified = stream->simplified;
     if (simplified) {
         if (stream->bound_device) {
             SDL_assert(stream->bound_device->simplified);
@@ -1070,8 +1303,7 @@ static void SDLCALL DontFreeThisAudioBuffer(void *userdata, const void *buf, int
     // We don't own the buffer, but know it will outlive the stream
 }
 
-int SDL_ConvertAudioSamples(const SDL_AudioSpec *src_spec, const Uint8 *src_data, int src_len,
-                            const SDL_AudioSpec *dst_spec, Uint8 **dst_data, int *dst_len)
+bool SDL_ConvertAudioSamples(const SDL_AudioSpec *src_spec, const Uint8 *src_data, int src_len, const SDL_AudioSpec *dst_spec, Uint8 **dst_data, int *dst_len)
 {
     if (dst_data) {
         *dst_data = NULL;
@@ -1091,30 +1323,31 @@ int SDL_ConvertAudioSamples(const SDL_AudioSpec *src_spec, const Uint8 *src_data
         return SDL_InvalidParamError("dst_len");
     }
 
-    int retval = -1;
+    bool result = false;
     Uint8 *dst = NULL;
     int dstlen = 0;
 
     SDL_AudioStream *stream = SDL_CreateAudioStream(src_spec, dst_spec);
     if (stream) {
-        if ((PutAudioStreamBuffer(stream, src_data, src_len, DontFreeThisAudioBuffer, NULL) == 0) && (SDL_FlushAudioStream(stream) == 0)) {
+        if (PutAudioStreamBuffer(stream, src_data, src_len, DontFreeThisAudioBuffer, NULL) &&
+            SDL_FlushAudioStream(stream)) {
             dstlen = SDL_GetAudioStreamAvailable(stream);
             if (dstlen >= 0) {
                 dst = (Uint8 *)SDL_malloc(dstlen);
                 if (dst) {
-                    retval = (SDL_GetAudioStreamData(stream, dst, dstlen) == dstlen) ? 0 : -1;
+                    result = (SDL_GetAudioStreamData(stream, dst, dstlen) == dstlen);
                 }
             }
         }
     }
 
-    if (retval == -1) {
-        SDL_free(dst);
-    } else {
+    if (result) {
         *dst_data = dst;
         *dst_len = dstlen;
+    } else {
+        SDL_free(dst);
     }
 
     SDL_DestroyAudioStream(stream);
-    return retval;
+    return result;
 }
