@@ -23,8 +23,6 @@
 #include "SDL_audioqueue.h"
 #include "SDL_sysaudio.h"
 
-#define AUDIO_SPECS_EQUAL(x, y) (((x).format == (y).format) && ((x).channels == (y).channels) && ((x).freq == (y).freq))
-
 typedef struct SDL_MemoryPool SDL_MemoryPool;
 
 struct SDL_MemoryPool
@@ -38,7 +36,8 @@ struct SDL_MemoryPool
 struct SDL_AudioTrack
 {
     SDL_AudioSpec spec;
-    SDL_bool flushed;
+    int *chmap;
+    bool flushed;
     SDL_AudioTrack *next;
 
     void *userdata;
@@ -48,6 +47,8 @@ struct SDL_AudioTrack
     size_t head;
     size_t tail;
     size_t capacity;
+
+    int chmap_storage[SDL_MAX_CHANNELMAP_CHANNELS];  // !!! FIXME: this needs to grow if SDL ever supports more channels. But if it grows, we should probably be more clever about allocations.
 };
 
 struct SDL_AudioQueue
@@ -120,13 +121,13 @@ static void InitMemoryPool(SDL_MemoryPool *pool, size_t block_size, size_t max_f
 }
 
 // Allocates a number of blocks and adds them to the pool
-static int ReserveMemoryPoolBlocks(SDL_MemoryPool *pool, size_t num_blocks)
+static bool ReserveMemoryPoolBlocks(SDL_MemoryPool *pool, size_t num_blocks)
 {
     for (; num_blocks; --num_blocks) {
         void *block = AllocNewMemoryPoolBlock(pool);
 
         if (block == NULL) {
-            return SDL_OutOfMemory();
+            return false;
         }
 
         *(void **)block = pool->free_blocks;
@@ -134,7 +135,7 @@ static int ReserveMemoryPoolBlocks(SDL_MemoryPool *pool, size_t num_blocks)
         ++pool->num_free;
     }
 
-    return 0;
+    return true;
 }
 
 void SDL_DestroyAudioQueue(SDL_AudioQueue *queue)
@@ -159,7 +160,7 @@ SDL_AudioQueue *SDL_CreateAudioQueue(size_t chunk_size)
     InitMemoryPool(&queue->track_pool, sizeof(SDL_AudioTrack), 8);
     InitMemoryPool(&queue->chunk_pool, chunk_size, 4);
 
-    if (ReserveMemoryPoolBlocks(&queue->track_pool, 2) != 0) {
+    if (!ReserveMemoryPoolBlocks(&queue->track_pool, 2)) {
         SDL_DestroyAudioQueue(queue);
         return NULL;
     }
@@ -191,7 +192,7 @@ void SDL_ClearAudioQueue(SDL_AudioQueue *queue)
 
 static void FlushAudioTrack(SDL_AudioTrack *track)
 {
-    track->flushed = SDL_TRUE;
+    track->flushed = true;
 }
 
 void SDL_FlushAudioQueue(SDL_AudioQueue *queue)
@@ -208,7 +209,7 @@ void SDL_PopAudioQueueHead(SDL_AudioQueue *queue)
     SDL_AudioTrack *track = queue->head;
 
     for (;;) {
-        SDL_bool flushed = track->flushed;
+        bool flushed = track->flushed;
 
         SDL_AudioTrack *next = track->next;
         DestroyAudioTrack(queue, track);
@@ -228,17 +229,24 @@ void SDL_PopAudioQueueHead(SDL_AudioQueue *queue)
 }
 
 SDL_AudioTrack *SDL_CreateAudioTrack(
-    SDL_AudioQueue *queue, const SDL_AudioSpec *spec,
+    SDL_AudioQueue *queue, const SDL_AudioSpec *spec, const int *chmap,
     Uint8 *data, size_t len, size_t capacity,
     SDL_ReleaseAudioBufferCallback callback, void *userdata)
 {
-    SDL_AudioTrack *track = AllocMemoryPoolBlock(&queue->track_pool);
+    SDL_AudioTrack *track = (SDL_AudioTrack *)AllocMemoryPoolBlock(&queue->track_pool);
 
     if (!track) {
         return NULL;
     }
 
     SDL_zerop(track);
+
+    if (chmap) {
+        SDL_assert(SDL_arraysize(track->chmap_storage) >= spec->channels);
+        SDL_memcpy(track->chmap_storage, chmap, sizeof (*chmap) * spec->channels);
+        track->chmap = track->chmap_storage;
+    }
+
     SDL_copyp(&track->spec, spec);
 
     track->userdata = userdata;
@@ -253,14 +261,14 @@ SDL_AudioTrack *SDL_CreateAudioTrack(
 
 static void SDLCALL FreeChunkedAudioBuffer(void *userdata, const void *buf, int len)
 {
-    SDL_AudioQueue *queue = userdata;
+    SDL_AudioQueue *queue = (SDL_AudioQueue *)userdata;
 
     FreeMemoryPoolBlock(&queue->chunk_pool, (void *)buf);
 }
 
-static SDL_AudioTrack *CreateChunkedAudioTrack(SDL_AudioQueue *queue, const SDL_AudioSpec *spec)
+static SDL_AudioTrack *CreateChunkedAudioTrack(SDL_AudioQueue *queue, const SDL_AudioSpec *spec, const int *chmap)
 {
-    void *chunk = AllocMemoryPoolBlock(&queue->chunk_pool);
+    Uint8 *chunk = (Uint8 *)AllocMemoryPoolBlock(&queue->chunk_pool);
 
     if (!chunk) {
         return NULL;
@@ -269,7 +277,7 @@ static SDL_AudioTrack *CreateChunkedAudioTrack(SDL_AudioQueue *queue, const SDL_
     size_t capacity = queue->chunk_pool.block_size;
     capacity -= capacity % SDL_AUDIO_FRAMESIZE(*spec);
 
-    SDL_AudioTrack *track = SDL_CreateAudioTrack(queue, spec, chunk, 0, capacity, FreeChunkedAudioBuffer, queue);
+    SDL_AudioTrack *track = SDL_CreateAudioTrack(queue, spec, chmap, chunk, 0, capacity, FreeChunkedAudioBuffer, queue);
 
     if (!track) {
         FreeMemoryPoolBlock(&queue->chunk_pool, chunk);
@@ -285,7 +293,7 @@ void SDL_AddTrackToAudioQueue(SDL_AudioQueue *queue, SDL_AudioTrack *track)
 
     if (tail) {
         // If the spec has changed, make sure to flush the previous track
-        if (!AUDIO_SPECS_EQUAL(tail->spec, track->spec)) {
+        if (!SDL_AudioSpecsEqual(&tail->spec, &track->spec, tail->chmap, track->chmap)) {
             FlushAudioTrack(tail);
         }
 
@@ -310,24 +318,24 @@ static size_t WriteToAudioTrack(SDL_AudioTrack *track, const Uint8 *data, size_t
     return len;
 }
 
-int SDL_WriteToAudioQueue(SDL_AudioQueue *queue, const SDL_AudioSpec *spec, const Uint8 *data, size_t len)
+bool SDL_WriteToAudioQueue(SDL_AudioQueue *queue, const SDL_AudioSpec *spec, const int *chmap, const Uint8 *data, size_t len)
 {
     if (len == 0) {
-        return 0;
+        return true;
     }
 
     SDL_AudioTrack *track = queue->tail;
 
     if (track) {
-        if (!AUDIO_SPECS_EQUAL(track->spec, *spec)) {
+        if (!SDL_AudioSpecsEqual(&track->spec, spec, track->chmap, chmap)) {
             FlushAudioTrack(track);
         }
     } else {
         SDL_assert(!queue->head);
-        track = CreateChunkedAudioTrack(queue, spec);
+        track = CreateChunkedAudioTrack(queue, spec, chmap);
 
         if (!track) {
-            return -1;
+            return false;
         }
 
         queue->head = track;
@@ -335,7 +343,7 @@ int SDL_WriteToAudioQueue(SDL_AudioQueue *queue, const SDL_AudioSpec *spec, cons
     }
 
     for (;;) {
-        size_t written = WriteToAudioTrack(track, data, len);
+        const size_t written = WriteToAudioTrack(track, data, len);
         data += written;
         len -= written;
 
@@ -343,10 +351,10 @@ int SDL_WriteToAudioQueue(SDL_AudioQueue *queue, const SDL_AudioSpec *spec, cons
             break;
         }
 
-        SDL_AudioTrack *new_track = CreateChunkedAudioTrack(queue, spec);
+        SDL_AudioTrack *new_track = CreateChunkedAudioTrack(queue, spec, chmap);
 
         if (!new_track) {
-            return -1;
+            return false;
         }
 
         track->next = new_track;
@@ -354,7 +362,7 @@ int SDL_WriteToAudioQueue(SDL_AudioQueue *queue, const SDL_AudioSpec *spec, cons
         track = new_track;
     }
 
-    return 0;
+    return true;
 }
 
 void *SDL_BeginAudioQueueIter(SDL_AudioQueue *queue)
@@ -362,14 +370,15 @@ void *SDL_BeginAudioQueueIter(SDL_AudioQueue *queue)
     return queue->head;
 }
 
-size_t SDL_NextAudioQueueIter(SDL_AudioQueue *queue, void **inout_iter, SDL_AudioSpec *out_spec, SDL_bool *out_flushed)
+size_t SDL_NextAudioQueueIter(SDL_AudioQueue *queue, void **inout_iter, SDL_AudioSpec *out_spec, int **out_chmap, bool *out_flushed)
 {
     SDL_AudioTrack *iter = (SDL_AudioTrack *)(*inout_iter);
     SDL_assert(iter != NULL);
 
     SDL_copyp(out_spec, &iter->spec);
+    *out_chmap = iter->chmap;
 
-    SDL_bool flushed = SDL_FALSE;
+    bool flushed = false;
     size_t queued_bytes = 0;
 
     while (iter) {
@@ -380,7 +389,7 @@ size_t SDL_NextAudioQueueIter(SDL_AudioQueue *queue, void **inout_iter, SDL_Audi
 
         if (avail >= SDL_SIZE_MAX - queued_bytes) {
             queued_bytes = SDL_SIZE_MAX;
-            flushed = SDL_FALSE;
+            flushed = false;
             break;
         }
 
@@ -514,9 +523,9 @@ static const Uint8 *PeekIntoAudioQueueFuture(SDL_AudioQueue *queue, Uint8 *data,
 }
 
 const Uint8 *SDL_ReadFromAudioQueue(SDL_AudioQueue *queue,
-                                    Uint8 *dst, SDL_AudioFormat dst_format, int dst_channels,
+                                    Uint8 *dst, SDL_AudioFormat dst_format, int dst_channels, const int *dst_map,
                                     int past_frames, int present_frames, int future_frames,
-                                    Uint8 *scratch)
+                                    Uint8 *scratch, float gain)
 {
     SDL_AudioTrack *track = queue->head;
 
@@ -526,6 +535,7 @@ const Uint8 *SDL_ReadFromAudioQueue(SDL_AudioQueue *queue,
 
     SDL_AudioFormat src_format = track->spec.format;
     int src_channels = track->spec.channels;
+    const int *src_map = track->chmap;
 
     size_t src_frame_size = SDL_AUDIO_BYTESIZE(src_format) * src_channels;
     size_t dst_frame_size = SDL_AUDIO_BYTESIZE(dst_format) * dst_channels;
@@ -538,7 +548,7 @@ const Uint8 *SDL_ReadFromAudioQueue(SDL_AudioQueue *queue,
     size_t dst_present_bytes = present_frames * dst_frame_size;
     size_t dst_future_bytes = future_frames * dst_frame_size;
 
-    SDL_bool convert = (src_format != dst_format) || (src_channels != dst_channels);
+    bool convert = (src_format != dst_format) || (src_channels != dst_channels);
 
     if (convert && !dst) {
         // The user didn't ask for the data to be copied, but we need to convert it, so store it in the scratch buffer
@@ -553,7 +563,7 @@ const Uint8 *SDL_ReadFromAudioQueue(SDL_AudioQueue *queue,
         // Do we still need to copy/convert the data?
         if (dst) {
             ConvertAudio(past_frames + present_frames + future_frames, ptr,
-                         src_format, src_channels, dst, dst_format, dst_channels, scratch);
+                         src_format, src_channels, src_map, dst, dst_format, dst_channels, dst_map, scratch, gain);
             ptr = dst;
         }
 
@@ -571,19 +581,19 @@ const Uint8 *SDL_ReadFromAudioQueue(SDL_AudioQueue *queue,
     Uint8 *ptr = dst;
 
     if (src_past_bytes) {
-        ConvertAudio(past_frames, PeekIntoAudioQueuePast(queue, scratch, src_past_bytes), src_format, src_channels, dst, dst_format, dst_channels, scratch);
+        ConvertAudio(past_frames, PeekIntoAudioQueuePast(queue, scratch, src_past_bytes), src_format, src_channels, src_map, dst, dst_format, dst_channels, dst_map, scratch, gain);
         dst += dst_past_bytes;
         scratch += dst_past_bytes;
     }
 
     if (src_present_bytes) {
-        ConvertAudio(present_frames, ReadFromAudioQueue(queue, scratch, src_present_bytes), src_format, src_channels, dst, dst_format, dst_channels, scratch);
+        ConvertAudio(present_frames, ReadFromAudioQueue(queue, scratch, src_present_bytes), src_format, src_channels, src_map, dst, dst_format, dst_channels, dst_map, scratch, gain);
         dst += dst_present_bytes;
         scratch += dst_present_bytes;
     }
 
     if (src_future_bytes) {
-        ConvertAudio(future_frames, PeekIntoAudioQueueFuture(queue, scratch, src_future_bytes), src_format, src_channels, dst, dst_format, dst_channels, scratch);
+        ConvertAudio(future_frames, PeekIntoAudioQueueFuture(queue, scratch, src_future_bytes), src_format, src_channels, src_map, dst, dst_format, dst_channels, dst_map, scratch, gain);
         dst += dst_future_bytes;
         scratch += dst_future_bytes;
     }
@@ -598,9 +608,10 @@ size_t SDL_GetAudioQueueQueued(SDL_AudioQueue *queue)
 
     while (iter) {
         SDL_AudioSpec src_spec;
-        SDL_bool flushed;
+        int *src_chmap;
+        bool flushed;
 
-        size_t avail = SDL_NextAudioQueueIter(queue, &iter, &src_spec, &flushed);
+        size_t avail = SDL_NextAudioQueueIter(queue, &iter, &src_spec, &src_chmap, &flushed);
 
         if (avail >= SDL_SIZE_MAX - total) {
             total = SDL_SIZE_MAX;
@@ -613,21 +624,21 @@ size_t SDL_GetAudioQueueQueued(SDL_AudioQueue *queue)
     return total;
 }
 
-int SDL_ResetAudioQueueHistory(SDL_AudioQueue *queue, int num_frames)
+bool SDL_ResetAudioQueueHistory(SDL_AudioQueue *queue, int num_frames)
 {
     SDL_AudioTrack *track = queue->head;
 
     if (!track) {
-        return -1;
+        return false;
     }
 
     size_t length = num_frames * SDL_AUDIO_FRAMESIZE(track->spec);
     Uint8 *history_buffer = queue->history_buffer;
 
     if (queue->history_capacity < length) {
-        history_buffer = SDL_aligned_alloc(SDL_SIMDGetAlignment(), length);
+        history_buffer = (Uint8 *)SDL_aligned_alloc(SDL_GetSIMDAlignment(), length);
         if (!history_buffer) {
-            return -1;
+            return false;
         }
         SDL_aligned_free(queue->history_buffer);
         queue->history_buffer = history_buffer;
@@ -637,5 +648,5 @@ int SDL_ResetAudioQueueHistory(SDL_AudioQueue *queue, int num_frames)
     queue->history_length = length;
     SDL_memset(history_buffer, SDL_GetSilenceValueForFormat(track->spec.format), length);
 
-    return 0;
+    return true;
 }
