@@ -40,31 +40,31 @@ static const char *SDL_UDEV_LIBS[] = { "libudev.so.1", "libudev.so.0" };
 
 static SDL_UDEV_PrivateData *_this = NULL;
 
-static SDL_bool SDL_UDEV_load_sym(const char *fn, void **addr);
-static int SDL_UDEV_load_syms(void);
-static SDL_bool SDL_UDEV_hotplug_update_available(void);
+static bool SDL_UDEV_load_sym(const char *fn, void **addr);
+static bool SDL_UDEV_load_syms(void);
+static bool SDL_UDEV_hotplug_update_available(void);
 static void get_caps(struct udev_device *dev, struct udev_device *pdev, const char *attr, unsigned long *bitmask, size_t bitmask_len);
 static int guess_device_class(struct udev_device *dev);
 static int device_class(struct udev_device *dev);
 static void device_event(SDL_UDEV_deviceevent type, struct udev_device *dev);
 
-static SDL_bool SDL_UDEV_load_sym(const char *fn, void **addr)
+static bool SDL_UDEV_load_sym(const char *fn, void **addr)
 {
     *addr = SDL_LoadFunction(_this->udev_handle, fn);
     if (!*addr) {
-        /* Don't call SDL_SetError(): SDL_LoadFunction already did. */
-        return SDL_FALSE;
+        // Don't call SDL_SetError(): SDL_LoadFunction already did.
+        return false;
     }
 
-    return SDL_TRUE;
+    return true;
 }
 
-static int SDL_UDEV_load_syms(void)
+static bool SDL_UDEV_load_syms(void)
 {
 /* cast funcs to char* first, to please GCC's strict aliasing rules. */
 #define SDL_UDEV_SYM(x)                                          \
     if (!SDL_UDEV_load_sym(#x, (void **)(char *)&_this->syms.x)) \
-    return -1
+        return false
 
     SDL_UDEV_SYM(udev_device_get_action);
     SDL_UDEV_SYM(udev_device_get_devnode);
@@ -95,34 +95,31 @@ static int SDL_UDEV_load_syms(void)
     SDL_UDEV_SYM(udev_device_get_devnum);
 #undef SDL_UDEV_SYM
 
-    return 0;
+    return true;
 }
 
-static SDL_bool SDL_UDEV_hotplug_update_available(void)
+static bool SDL_UDEV_hotplug_update_available(void)
 {
     if (_this->udev_mon) {
         const int fd = _this->syms.udev_monitor_get_fd(_this->udev_mon);
         if (SDL_IOReady(fd, SDL_IOR_READ, 0)) {
-            return SDL_TRUE;
+            return true;
         }
     }
-    return SDL_FALSE;
+    return false;
 }
 
-int SDL_UDEV_Init(void)
+bool SDL_UDEV_Init(void)
 {
-    int retval = 0;
-
     if (!_this) {
         _this = (SDL_UDEV_PrivateData *)SDL_calloc(1, sizeof(*_this));
         if (!_this) {
-            return -1;
+            return false;
         }
 
-        retval = SDL_UDEV_LoadLibrary();
-        if (retval < 0) {
+        if (!SDL_UDEV_LoadLibrary()) {
             SDL_UDEV_Quit();
-            return retval;
+            return false;
         }
 
         /* Set up udev monitoring
@@ -146,13 +143,13 @@ int SDL_UDEV_Init(void)
         _this->syms.udev_monitor_filter_add_match_subsystem_devtype(_this->udev_mon, "video4linux", NULL);
         _this->syms.udev_monitor_enable_receiving(_this->udev_mon);
 
-        /* Do an initial scan of existing devices */
+        // Do an initial scan of existing devices
         SDL_UDEV_Scan();
     }
 
     _this->ref_count += 1;
 
-    return retval;
+    return true;
 }
 
 void SDL_UDEV_Quit(void)
@@ -174,7 +171,7 @@ void SDL_UDEV_Quit(void)
             _this->udev = NULL;
         }
 
-        /* Remove existing devices */
+        // Remove existing devices
         while (_this->first) {
             SDL_UDEV_CallbackList *item = _this->first;
             _this->first = _this->first->next;
@@ -187,14 +184,14 @@ void SDL_UDEV_Quit(void)
     }
 }
 
-int SDL_UDEV_Scan(void)
+bool SDL_UDEV_Scan(void)
 {
     struct udev_enumerate *enumerate = NULL;
     struct udev_list_entry *devs = NULL;
     struct udev_list_entry *item = NULL;
 
     if (!_this) {
-        return 0;
+        return true;
     }
 
     enumerate = _this->syms.udev_enumerate_new(_this->udev);
@@ -219,10 +216,10 @@ int SDL_UDEV_Scan(void)
     }
 
     _this->syms.udev_enumerate_unref(enumerate);
-    return 0;
+    return true;
 }
 
-SDL_bool SDL_UDEV_GetProductInfo(const char *device_path, Uint16 *vendor, Uint16 *product, Uint16 *version, int *class)
+bool SDL_UDEV_GetProductInfo(const char *device_path, Uint16 *vendor, Uint16 *product, Uint16 *version, int *class)
 {
     struct stat statbuf;
     char type;
@@ -231,11 +228,11 @@ SDL_bool SDL_UDEV_GetProductInfo(const char *device_path, Uint16 *vendor, Uint16
     int class_temp;
 
     if (!_this) {
-        return SDL_FALSE;
+        return false;
     }
 
     if (stat(device_path, &statbuf) == -1) {
-        return SDL_FALSE;
+        return false;
     }
 
     if (S_ISBLK(statbuf.st_mode)) {
@@ -245,13 +242,13 @@ SDL_bool SDL_UDEV_GetProductInfo(const char *device_path, Uint16 *vendor, Uint16
         type = 'c';
     }
     else {
-        return SDL_FALSE;
+        return false;
     }
 
     dev = _this->syms.udev_device_new_from_devnum(_this->udev, type, statbuf.st_rdev);
 
     if (!dev) {
-        return SDL_FALSE;
+        return false;
     }
 
     val = _this->syms.udev_device_get_property_value(dev, "ID_VENDOR_ID");
@@ -276,7 +273,7 @@ SDL_bool SDL_UDEV_GetProductInfo(const char *device_path, Uint16 *vendor, Uint16
 
     _this->syms.udev_device_unref(dev);
 
-    return SDL_TRUE;
+    return true;
 }
 
 void SDL_UDEV_UnloadLibrary(void)
@@ -291,26 +288,26 @@ void SDL_UDEV_UnloadLibrary(void)
     }
 }
 
-int SDL_UDEV_LoadLibrary(void)
+bool SDL_UDEV_LoadLibrary(void)
 {
-    int retval = 0, i;
+    bool result = true;
 
     if (!_this) {
         return SDL_SetError("UDEV not initialized");
     }
 
-    /* See if there is a udev library already loaded */
-    if (SDL_UDEV_load_syms() == 0) {
-        return 0;
+    // See if there is a udev library already loaded
+    if (SDL_UDEV_load_syms()) {
+        return true;
     }
 
 #ifdef SDL_UDEV_DYNAMIC
-    /* Check for the build environment's libudev first */
+    // Check for the build environment's libudev first
     if (!_this->udev_handle) {
         _this->udev_handle = SDL_LoadObject(SDL_UDEV_DYNAMIC);
         if (_this->udev_handle) {
-            retval = SDL_UDEV_load_syms();
-            if (retval < 0) {
+            result = SDL_UDEV_load_syms();
+            if (!result) {
                 SDL_UDEV_UnloadLibrary();
             }
         }
@@ -318,11 +315,11 @@ int SDL_UDEV_LoadLibrary(void)
 #endif
 
     if (!_this->udev_handle) {
-        for (i = 0; i < SDL_arraysize(SDL_UDEV_LIBS); i++) {
+        for (int i = 0; i < SDL_arraysize(SDL_UDEV_LIBS); i++) {
             _this->udev_handle = SDL_LoadObject(SDL_UDEV_LIBS[i]);
             if (_this->udev_handle) {
-                retval = SDL_UDEV_load_syms();
-                if (retval < 0) {
+                result = SDL_UDEV_load_syms();
+                if (!result) {
                     SDL_UDEV_UnloadLibrary();
                 } else {
                     break;
@@ -331,12 +328,12 @@ int SDL_UDEV_LoadLibrary(void)
         }
 
         if (!_this->udev_handle) {
-            retval = -1;
-            /* Don't call SDL_SetError(): SDL_LoadObject already did. */
+            result = false;
+            // Don't call SDL_SetError(): SDL_LoadObject already did.
         }
     }
 
-    return retval;
+    return result;
 }
 
 static void get_caps(struct udev_device *dev, struct udev_device *pdev, const char *attr, unsigned long *bitmask, size_t bitmask_len)
@@ -420,7 +417,7 @@ static int device_class(struct udev_device *dev)
             devclass = SDL_UDEV_DEVICE_VIDEO_CAPTURE;
         }
     } else if (SDL_strcmp(subsystem, "input") == 0) {
-        /* udev rules reference: http://cgit.freedesktop.org/systemd/systemd/tree/src/udev/udev-builtin-input_id.c */
+        // udev rules reference: http://cgit.freedesktop.org/systemd/systemd/tree/src/udev/udev-builtin-input_id.c
 
         val = _this->syms.udev_device_get_property_value(dev, "ID_INPUT_JOYSTICK");
         if (val && SDL_strcmp(val, "1") == 0) {
@@ -459,7 +456,7 @@ static int device_class(struct udev_device *dev)
         }
 
         if (devclass == 0) {
-            /* Fall back to old style input classes */
+            // Fall back to old style input classes
             val = _this->syms.udev_device_get_property_value(dev, "ID_CLASS");
             if (val) {
                 if (SDL_strcmp(val, "joystick") == 0) {
@@ -470,7 +467,7 @@ static int device_class(struct udev_device *dev)
                     devclass = SDL_UDEV_DEVICE_HAS_KEYS | SDL_UDEV_DEVICE_KEYBOARD;
                 }
             } else {
-                /* We could be linked with libudev on a system that doesn't have udev running */
+                // We could be linked with libudev on a system that doesn't have udev running
                 devclass = guess_device_class(dev);
             }
         }
@@ -495,7 +492,7 @@ static void device_event(SDL_UDEV_deviceevent type, struct udev_device *dev)
          return;
     }
 
-    /* Process callbacks */
+    // Process callbacks
     for (item = _this->first; item; item = item->next) {
         item->callback(type, devclass, path);
     }
@@ -529,12 +526,12 @@ void SDL_UDEV_Poll(void)
     }
 }
 
-int SDL_UDEV_AddCallback(SDL_UDEV_Callback cb)
+bool SDL_UDEV_AddCallback(SDL_UDEV_Callback cb)
 {
     SDL_UDEV_CallbackList *item;
     item = (SDL_UDEV_CallbackList *)SDL_calloc(1, sizeof(SDL_UDEV_CallbackList));
     if (!item) {
-        return -1;
+        return false;
     }
 
     item->callback = cb;
@@ -546,7 +543,7 @@ int SDL_UDEV_AddCallback(SDL_UDEV_Callback cb)
         _this->last = item;
     }
 
-    return 0;
+    return true;
 }
 
 void SDL_UDEV_DelCallback(SDL_UDEV_Callback cb)
@@ -559,7 +556,7 @@ void SDL_UDEV_DelCallback(SDL_UDEV_Callback cb)
     }
 
     for (item = _this->first; item; item = item->next) {
-        /* found it, remove it. */
+        // found it, remove it.
         if (item->callback == cb) {
             if (prev) {
                 prev->next = item->next;
@@ -579,7 +576,7 @@ void SDL_UDEV_DelCallback(SDL_UDEV_Callback cb)
 
 const SDL_UDEV_Symbols *SDL_UDEV_GetUdevSyms(void)
 {
-    if (SDL_UDEV_Init() < 0) {
+    if (!SDL_UDEV_Init()) {
         SDL_SetError("Could not initialize UDEV");
         return NULL;
     }
@@ -592,4 +589,4 @@ void SDL_UDEV_ReleaseUdevSyms(void)
     SDL_UDEV_Quit();
 }
 
-#endif /* SDL_USE_LIBUDEV */
+#endif // SDL_USE_LIBUDEV
