@@ -20,22 +20,17 @@
 */
 #include "SDL_internal.h"
 
-/* Clipboard event handling code for SDL */
+// Clipboard event handling code for SDL
 
 #include "SDL_events_c.h"
 #include "SDL_clipboardevents_c.h"
 
-int SDL_SendClipboardUpdate(void)
+void SDL_SendClipboardUpdate(void)
 {
-    int posted;
-
-    /* Post the event, if desired */
-    posted = 0;
     if (SDL_EventEnabled(SDL_EVENT_CLIPBOARD_UPDATE)) {
         SDL_Event event;
         event.type = SDL_EVENT_CLIPBOARD_UPDATE;
         event.clipboard.timestamp = 0;
-        posted = (SDL_PushEvent(&event) > 0);
+        SDL_PushEvent(&event);
     }
-    return posted;
 }
