@@ -23,6 +23,6 @@
 #ifndef SDL_clipboardevents_c_h_
 #define SDL_clipboardevents_c_h_
 
-extern int SDL_SendClipboardUpdate(void);
+extern void SDL_SendClipboardUpdate(void);
 
-#endif /* SDL_clipboardevents_c_h_ */
+#endif // SDL_clipboardevents_c_h_
