@@ -34,8 +34,8 @@
 #include "../joystick/usb_ids.h"
 #include "../SDL_hints_c.h"
 
-/* Initial type declarations */
-#define HID_API_NO_EXPORT_DEFINE /* do not export hidapi procedures */
+// Initial type declarations
+#define HID_API_NO_EXPORT_DEFINE // do not export hidapi procedures
 #include "hidapi/hidapi.h"
 
 #ifndef SDL_HIDAPI_DISABLED
@@ -51,7 +51,7 @@
 #include <IOKit/hid/IOHIDDevice.h>
 #include <IOKit/usb/USBSpec.h>
 #include <AvailabilityMacros.h>
-/* Things named "Master" were renamed to "Main" in macOS 12.0's SDK. */
+// Things named "Master" were renamed to "Main" in macOS 12.0's SDK.
 #if MAC_OS_X_VERSION_MIN_REQUIRED < 120000
 #define kIOMainPortDefault kIOMasterPortDefault
 #endif
@@ -64,10 +64,10 @@
 #endif
 
 #ifdef HAVE_INOTIFY
-#include <string.h> /* strerror */
-#include <errno.h>  /* errno */
+#include <string.h> // strerror
+#include <errno.h>  // errno
 #include <fcntl.h>
-#include <limits.h> /* For the definition of NAME_MAX */
+#include <limits.h> // For the definition of NAME_MAX
 #include <sys/inotify.h>
 #endif
 
@@ -96,9 +96,9 @@ static const SDL_UDEV_Symbols *usyms = NULL;
 
 static struct
 {
-    SDL_bool m_bInitialized;
+    bool m_bInitialized;
     Uint32 m_unDeviceChangeCounter;
-    SDL_bool m_bCanGetNotifications;
+    bool m_bCanGetNotifications;
     Uint64 m_unLastDetect;
 
 #if defined(SDL_PLATFORM_WIN32) || defined(SDL_PLATFORM_WINGDK)
@@ -139,13 +139,13 @@ typedef struct _DEV_BROADCAST_DEVICEINTERFACE_A
 } DEV_BROADCAST_DEVICEINTERFACE_A, *PDEV_BROADCAST_DEVICEINTERFACE_A;
 
 typedef struct _DEV_BROADCAST_HDR DEV_BROADCAST_HDR;
-#define DBT_DEVICEARRIVAL          0x8000     /* system detected a new device */
-#define DBT_DEVICEREMOVECOMPLETE   0x8004     /* device was removed from the system */
-#define DBT_DEVTYP_DEVICEINTERFACE 0x00000005 /* device interface class */
+#define DBT_DEVICEARRIVAL          0x8000     // system detected a new device
+#define DBT_DEVICEREMOVECOMPLETE   0x8004     // device was removed from the system
+#define DBT_DEVTYP_DEVICEINTERFACE 0x00000005 // device interface class
 #define DBT_DEVNODES_CHANGED       0x0007
 #define DBT_CONFIGCHANGED          0x0018
-#define DBT_DEVICETYPESPECIFIC     0x8005 /* type specific event */
-#define DBT_DEVINSTSTARTED         0x8008 /* device installed and started */
+#define DBT_DEVICETYPESPECIFIC     0x8005 // type specific event
+#define DBT_DEVINSTSTARTED         0x8008 // device installed and started
 
 #include <initguid.h>
 DEFINE_GUID(GUID_DEVINTERFACE_USB_DEVICE, 0xA5DCBF10L, 0x6530, 0x11D2, 0x90, 0x1F, 0x00, 0xC0, 0x4F, 0xB9, 0x51, 0xED);
@@ -167,19 +167,19 @@ static LRESULT CALLBACK ControllerWndProc(HWND hwnd, UINT message, WPARAM wParam
 
     return DefWindowProc(hwnd, message, wParam, lParam);
 }
-#endif /* defined(SDL_PLATFORM_WIN32) || defined(SDL_PLATFORM_WINGDK) */
+#endif // defined(SDL_PLATFORM_WIN32) || defined(SDL_PLATFORM_WINGDK)
 
 #ifdef SDL_PLATFORM_MACOS
 static void CallbackIOServiceFunc(void *context, io_iterator_t portIterator)
 {
-    /* Must drain the iterator, or we won't receive new notifications */
+    // Must drain the iterator, or we won't receive new notifications
     io_object_t entry;
     while ((entry = IOIteratorNext(portIterator)) != 0) {
         IOObjectRelease(entry);
         ++SDL_HIDAPI_discovery.m_unDeviceChangeCounter;
     }
 }
-#endif /* SDL_PLATFORM_MACOS */
+#endif // SDL_PLATFORM_MACOS
 
 #ifdef HAVE_INOTIFY
 #ifdef HAVE_INOTIFY_INIT1
@@ -221,13 +221,13 @@ static int StrIsInteger(const char *string)
 
     return 1;
 }
-#endif /* HAVE_INOTIFY */
+#endif // HAVE_INOTIFY
 
 static void HIDAPI_InitializeDiscovery(void)
 {
-    SDL_HIDAPI_discovery.m_bInitialized = SDL_TRUE;
+    SDL_HIDAPI_discovery.m_bInitialized = true;
     SDL_HIDAPI_discovery.m_unDeviceChangeCounter = 1;
-    SDL_HIDAPI_discovery.m_bCanGetNotifications = SDL_FALSE;
+    SDL_HIDAPI_discovery.m_bCanGetNotifications = false;
     SDL_HIDAPI_discovery.m_unLastDetect = 0;
 
 #if defined(SDL_PLATFORM_WIN32) || defined(SDL_PLATFORM_WINGDK)
@@ -236,7 +236,7 @@ static void HIDAPI_InitializeDiscovery(void)
     SDL_zero(SDL_HIDAPI_discovery.m_wndClass);
     SDL_HIDAPI_discovery.m_wndClass.hInstance = GetModuleHandle(NULL);
     SDL_HIDAPI_discovery.m_wndClass.lpszClassName = "SDL_HIDAPI_DEVICE_DETECTION";
-    SDL_HIDAPI_discovery.m_wndClass.lpfnWndProc = ControllerWndProc; /* This function is called by windows */
+    SDL_HIDAPI_discovery.m_wndClass.lpfnWndProc = ControllerWndProc; // This function is called by windows
     SDL_HIDAPI_discovery.m_wndClass.cbSize = sizeof(WNDCLASSEX);
 
     RegisterClassExA(&SDL_HIDAPI_discovery.m_wndClass);
@@ -257,7 +257,7 @@ static void HIDAPI_InitializeDiscovery(void)
         SDL_HIDAPI_discovery.m_hNotify = RegisterDeviceNotification(SDL_HIDAPI_discovery.m_hwndMsg, &devBroadcast, DEVICE_NOTIFY_WINDOW_HANDLE | DEVICE_NOTIFY_ALL_INTERFACE_CLASSES);
         SDL_HIDAPI_discovery.m_bCanGetNotifications = (SDL_HIDAPI_discovery.m_hNotify != 0);
     }
-#endif /* defined(SDL_PLATFORM_WIN32) || defined(SDL_PLATFORM_WINGDK) */
+#endif // defined(SDL_PLATFORM_WIN32) || defined(SDL_PLATFORM_WINGDK)
 
 #ifdef SDL_PLATFORM_MACOS
     SDL_HIDAPI_discovery.m_notificationPort = IONotificationPortCreate(kIOMainPortDefault);
@@ -272,7 +272,7 @@ static void HIDAPI_InitializeDiscovery(void)
                 CallbackIOServiceFunc, NULL, &portIterator);
 
             if (result == 0) {
-                /* Must drain the existing iterator, or we won't receive new notifications */
+                // Must drain the existing iterator, or we won't receive new notifications
                 while ((entry = IOIteratorNext(portIterator)) != 0) {
                     IOObjectRelease(entry);
                 }
@@ -291,7 +291,7 @@ static void HIDAPI_InitializeDiscovery(void)
                 CallbackIOServiceFunc, NULL, &portIterator);
 
             if (result == 0) {
-                /* Must drain the existing iterator, or we won't receive new notifications */
+                // Must drain the existing iterator, or we won't receive new notifications
                 while ((entry = IOIteratorNext(portIterator)) != 0) {
                     IOObjectRelease(entry);
                 }
@@ -309,7 +309,7 @@ static void HIDAPI_InitializeDiscovery(void)
 
     SDL_HIDAPI_discovery.m_bCanGetNotifications = (SDL_HIDAPI_discovery.m_notificationMach != MACH_PORT_NULL);
 
-#endif /* SDL_PLATFORM_MACOS */
+#endif // SDL_PLATFORM_MACOS
 
 #ifdef SDL_USE_LIBUDEV
     if (linux_enumeration_method == ENUMERATION_LIBUDEV) {
@@ -325,12 +325,12 @@ static void HIDAPI_InitializeDiscovery(void)
                 if (SDL_HIDAPI_discovery.m_pUdevMonitor != NULL) {
                     usyms->udev_monitor_enable_receiving(SDL_HIDAPI_discovery.m_pUdevMonitor);
                     SDL_HIDAPI_discovery.m_nUdevFd = usyms->udev_monitor_get_fd(SDL_HIDAPI_discovery.m_pUdevMonitor);
-                    SDL_HIDAPI_discovery.m_bCanGetNotifications = SDL_TRUE;
+                    SDL_HIDAPI_discovery.m_bCanGetNotifications = true;
                 }
             }
         }
     } else
-#endif /* SDL_USE_LIBUDEV */
+#endif // SDL_USE_LIBUDEV
     {
 #ifdef HAVE_INOTIFY
         inotify_fd = SDL_inotify_init1();
@@ -357,8 +357,8 @@ static void HIDAPI_InitializeDiscovery(void)
             return;
         }
 
-        SDL_HIDAPI_discovery.m_bCanGetNotifications = SDL_TRUE;
-#endif /* HAVE_INOTIFY */
+        SDL_HIDAPI_discovery.m_bCanGetNotifications = true;
+#endif // HAVE_INOTIFY
     }
 }
 
@@ -369,7 +369,7 @@ static void HIDAPI_UpdateDiscovery(void)
     }
 
     if (!SDL_HIDAPI_discovery.m_bCanGetNotifications) {
-        const Uint32 SDL_HIDAPI_DETECT_INTERVAL_MS = 3000; /* Update every 3 seconds */
+        const Uint32 SDL_HIDAPI_DETECT_INTERVAL_MS = 3000; // Update every 3 seconds
         Uint64 now = SDL_GetTicks();
         if (!SDL_HIDAPI_discovery.m_unLastDetect || now >= (SDL_HIDAPI_discovery.m_unLastDetect + SDL_HIDAPI_DETECT_INTERVAL_MS)) {
             ++SDL_HIDAPI_discovery.m_unDeviceChangeCounter;
@@ -379,8 +379,8 @@ static void HIDAPI_UpdateDiscovery(void)
     }
 
 #if defined(SDL_PLATFORM_WIN32) || defined(SDL_PLATFORM_WINGDK)
-#if 0 /* just let the usual SDL_PumpEvents loop dispatch these, fixing bug 4286. --ryan. */
-    /* We'll only get messages on the same thread that created the window */
+#if 0 // just let the usual SDL_PumpEvents loop dispatch these, fixing bug 4286. --ryan.
+    // We'll only get messages on the same thread that created the window
     if (SDL_GetCurrentThreadID() == SDL_HIDAPI_discovery.m_nThreadID) {
         MSG msg;
         while (PeekMessage(&msg, SDL_HIDAPI_discovery.m_hwndMsg, 0, 0, PM_NOREMOVE)) {
@@ -391,7 +391,7 @@ static void HIDAPI_UpdateDiscovery(void)
         }
     }
 #endif
-#endif /* defined(SDL_PLATFORM_WIN32) || defined(SDL_PLATFORM_WINGDK) */
+#endif // defined(SDL_PLATFORM_WIN32) || defined(SDL_PLATFORM_WINGDK)
 
 #ifdef SDL_PLATFORM_MACOS
     if (SDL_HIDAPI_discovery.m_notificationPort) {
@@ -436,7 +436,7 @@ static void HIDAPI_UpdateDiscovery(void)
             }
         }
     } else
-#endif /* SDL_USE_LIBUDEV */
+#endif // SDL_USE_LIBUDEV
     {
 #ifdef HAVE_INOTIFY
         if (inotify_fd >= 0) {
@@ -475,7 +475,7 @@ static void HIDAPI_UpdateDiscovery(void)
                 }
             }
         }
-#endif /* HAVE_INOTIFY */
+#endif // HAVE_INOTIFY
     }
 }
 
@@ -516,7 +516,7 @@ static void HIDAPI_ShutdownDiscovery(void)
             usyms = NULL;
         }
     } else
-#endif /* SDL_USE_LIBUDEV */
+#endif // SDL_USE_LIBUDEV
     {
 #ifdef HAVE_INOTIFY
         if (inotify_fd >= 0) {
@@ -526,10 +526,10 @@ static void HIDAPI_ShutdownDiscovery(void)
 #endif
     }
 
-    SDL_HIDAPI_discovery.m_bInitialized = SDL_FALSE;
+    SDL_HIDAPI_discovery.m_bInitialized = false;
 }
 
-/* Platform HIDAPI Implementation */
+// Platform HIDAPI Implementation
 
 #define HIDAPI_USING_SDL_RUNTIME
 #define HIDAPI_IGNORE_DEVICE(BUS, VID, PID, USAGE_PAGE, USAGE) \
@@ -626,7 +626,7 @@ typedef struct PLATFORM_hid_device_ PLATFORM_hid_device;
 
 #ifdef HAVE_DRIVER_BACKEND
 
-/* DRIVER HIDAPI Implementation */
+// DRIVER HIDAPI Implementation
 
 struct DRIVER_hid_device_;
 typedef struct DRIVER_hid_device_ DRIVER_hid_device;
@@ -685,19 +685,19 @@ typedef struct DRIVER_hid_device_ DRIVER_hid_device;
 #undef hid_set_nonblocking
 #undef hid_write
 
-#endif /* HAVE_DRIVER_BACKEND */
+#endif // HAVE_DRIVER_BACKEND
 
 #ifdef HAVE_LIBUSB
-/* libusb HIDAPI Implementation */
+// libusb HIDAPI Implementation
 
-/* Include this now, for our dynamically-loaded libusb context */
+// Include this now, for our dynamically-loaded libusb context
 #include <libusb.h>
 
 static struct
 {
-    void *libhandle;
+    SDL_SharedObject *libhandle;
 
-    /* *INDENT-OFF* */ /* clang-format off */
+    /* *INDENT-OFF* */ // clang-format off
     int (LIBUSB_CALL *init)(libusb_context **ctx);
     void (LIBUSB_CALL *exit)(libusb_context *ctx);
     ssize_t (LIBUSB_CALL *get_device_list)(libusb_context *ctx, libusb_device ***list);
@@ -747,7 +747,7 @@ static struct
     int (LIBUSB_CALL *handle_events)(libusb_context *ctx);
     int (LIBUSB_CALL *handle_events_completed)(libusb_context *ctx, int *completed);
     const char * (LIBUSB_CALL *error_name)(int errcode);
-/* *INDENT-ON* */ /* clang-format on */
+/* *INDENT-ON* */ // clang-format on
 
 } libusb_ctx;
 
@@ -888,36 +888,36 @@ static const struct {
     Uint16 vendor;
     Uint16 product;
 } SDL_libusb_whitelist[] = {
-    { 0x057e, 0x0337 } /* Nintendo WUP-028, Wii U/Switch GameCube Adapter */
+    { 0x057e, 0x0337 } // Nintendo WUP-028, Wii U/Switch GameCube Adapter
 };
 
-static SDL_bool IsInWhitelist(Uint16 vendor, Uint16 product)
+static bool IsInWhitelist(Uint16 vendor, Uint16 product)
 {
     int i;
     for (i = 0; i < SDL_arraysize(SDL_libusb_whitelist); i += 1) {
         if (vendor == SDL_libusb_whitelist[i].vendor &&
             product == SDL_libusb_whitelist[i].product) {
-            return SDL_TRUE;
+            return true;
         }
     }
-    return SDL_FALSE;
+    return false;
 }
 
-#endif /* HAVE_LIBUSB */
+#endif // HAVE_LIBUSB
 
-#endif /* !SDL_HIDAPI_DISABLED */
+#endif // !SDL_HIDAPI_DISABLED
 
 #if defined(HAVE_PLATFORM_BACKEND) || defined(HAVE_DRIVER_BACKEND)
-/* We have another way to get HID devices, so use the whitelist to get devices where libusb is preferred */
-#define SDL_HIDAPI_LIBUSB_WHITELIST_DEFAULT SDL_TRUE
+// We have another way to get HID devices, so use the whitelist to get devices where libusb is preferred
+#define SDL_HINT_HIDAPI_LIBUSB_WHITELIST_DEFAULT true
 #else
-/* libusb is the only way to get HID devices, so don't use the whitelist, get them all */
-#define SDL_HIDAPI_LIBUSB_WHITELIST_DEFAULT SDL_FALSE
-#endif /* HAVE_PLATFORM_BACKEND || HAVE_DRIVER_BACKEND */
+// libusb is the only way to get HID devices, so don't use the whitelist, get them all
+#define SDL_HINT_HIDAPI_LIBUSB_WHITELIST_DEFAULT false
+#endif // HAVE_PLATFORM_BACKEND || HAVE_DRIVER_BACKEND
 
-static SDL_bool use_libusb_whitelist = SDL_HIDAPI_LIBUSB_WHITELIST_DEFAULT;
+static bool use_libusb_whitelist = SDL_HINT_HIDAPI_LIBUSB_WHITELIST_DEFAULT;
 
-/* Shared HIDAPI Implementation */
+// Shared HIDAPI Implementation
 
 struct hidapi_backend
 {
@@ -956,7 +956,7 @@ static const struct hidapi_backend PLATFORM_Backend = {
     (void *)PLATFORM_hid_get_report_descriptor,
     (void *)PLATFORM_hid_error
 };
-#endif /* HAVE_PLATFORM_BACKEND */
+#endif // HAVE_PLATFORM_BACKEND
 
 #ifdef HAVE_DRIVER_BACKEND
 static const struct hidapi_backend DRIVER_Backend = {
@@ -976,7 +976,7 @@ static const struct hidapi_backend DRIVER_Backend = {
     (void *)DRIVER_hid_get_report_descriptor,
     (void *)DRIVER_hid_error
 };
-#endif /* HAVE_DRIVER_BACKEND */
+#endif // HAVE_DRIVER_BACKEND
 
 #ifdef HAVE_LIBUSB
 static const struct hidapi_backend LIBUSB_Backend = {
@@ -996,45 +996,43 @@ static const struct hidapi_backend LIBUSB_Backend = {
     (void *)LIBUSB_hid_get_report_descriptor,
     (void *)LIBUSB_hid_error
 };
-#endif /* HAVE_LIBUSB */
+#endif // HAVE_LIBUSB
 
 struct SDL_hid_device
 {
-    const void *magic;
     void *device;
     const struct hidapi_backend *backend;
     SDL_hid_device_info info;
 };
-static char device_magic;
 
 #if defined(HAVE_PLATFORM_BACKEND) || defined(HAVE_DRIVER_BACKEND) || defined(HAVE_LIBUSB)
 
 static SDL_hid_device *CreateHIDDeviceWrapper(void *device, const struct hidapi_backend *backend)
 {
     SDL_hid_device *wrapper = (SDL_hid_device *)SDL_malloc(sizeof(*wrapper));
-    wrapper->magic = &device_magic;
+    SDL_SetObjectValid(wrapper, SDL_OBJECT_TYPE_HIDAPI_DEVICE, true);
     wrapper->device = device;
     wrapper->backend = backend;
     SDL_zero(wrapper->info);
     return wrapper;
 }
 
-#endif /* HAVE_PLATFORM_BACKEND || HAVE_DRIVER_BACKEND || HAVE_LIBUSB */
+#endif // HAVE_PLATFORM_BACKEND || HAVE_DRIVER_BACKEND || HAVE_LIBUSB
 
-static void DeleteHIDDeviceWrapper(SDL_hid_device *device)
+static void DeleteHIDDeviceWrapper(SDL_hid_device *wrapper)
 {
-    device->magic = NULL;
-    SDL_free(device->info.path);
-    SDL_free(device->info.serial_number);
-    SDL_free(device->info.manufacturer_string);
-    SDL_free(device->info.product_string);
-    SDL_free(device);
+    SDL_SetObjectValid(wrapper, SDL_OBJECT_TYPE_HIDAPI_DEVICE, false);
+    SDL_free(wrapper->info.path);
+    SDL_free(wrapper->info.serial_number);
+    SDL_free(wrapper->info.manufacturer_string);
+    SDL_free(wrapper->info.product_string);
+    SDL_free(wrapper);
 }
 
-#define CHECK_DEVICE_MAGIC(device, retval)           \
-    if (!device || device->magic != &device_magic) { \
-        SDL_SetError("Invalid device");              \
-        return retval;                               \
+#define CHECK_DEVICE_MAGIC(device, result)                          \
+    if (!SDL_ObjectValid(device, SDL_OBJECT_TYPE_HIDAPI_DEVICE)) {  \
+        SDL_SetError("Invalid device");                             \
+        return result;                                              \
     }
 
 #define COPY_IF_EXISTS(var)                \
@@ -1073,12 +1071,12 @@ static void CopyHIDDeviceInfo(struct hid_device_info *pSrc, struct SDL_hid_devic
 #undef WCOPY_IF_EXISTS
 
 static int SDL_hidapi_refcount = 0;
-static SDL_bool SDL_hidapi_only_controllers;
+static bool SDL_hidapi_only_controllers;
 static char *SDL_hidapi_ignored_devices = NULL;
 
 static void SDLCALL OnlyControllersChanged(void *userdata, const char *name, const char *oldValue, const char *hint)
 {
-    SDL_hidapi_only_controllers = SDL_GetStringBoolean(hint, SDL_TRUE);
+    SDL_hidapi_only_controllers = SDL_GetStringBoolean(hint, true);
 }
 
 static void SDLCALL IgnoredDevicesChanged(void *userdata, const char *name, const char *oldValue, const char *hint)
@@ -1093,28 +1091,28 @@ static void SDLCALL IgnoredDevicesChanged(void *userdata, const char *name, cons
     }
 }
 
-SDL_bool SDL_HIDAPI_ShouldIgnoreDevice(int bus, Uint16 vendor_id, Uint16 product_id, Uint16 usage_page, Uint16 usage)
+bool SDL_HIDAPI_ShouldIgnoreDevice(int bus, Uint16 vendor_id, Uint16 product_id, Uint16 usage_page, Uint16 usage)
 {
-    /* See if there are any devices we should skip in enumeration */
+    // See if there are any devices we should skip in enumeration
     if (SDL_hidapi_only_controllers && usage_page) {
         if (vendor_id == USB_VENDOR_VALVE) {
-            /* Ignore the mouse/keyboard interface on Steam Controllers */
+            // Ignore the mouse/keyboard interface on Steam Controllers
             if (
 #ifdef SDL_PLATFORM_WIN32
-                /* Check the usage page and usage on both USB and Bluetooth */
+                // Check the usage page and usage on both USB and Bluetooth
 #else
-                /* Only check the usage page and usage on USB */
+                // Only check the usage page and usage on USB
                 bus == HID_API_BUS_USB &&
 #endif
                 usage_page == USB_USAGEPAGE_GENERIC_DESKTOP &&
                 (usage == USB_USAGE_GENERIC_KEYBOARD || usage == USB_USAGE_GENERIC_MOUSE)) {
-                return SDL_TRUE;
+                return true;
             }
         } else if (usage_page == USB_USAGEPAGE_GENERIC_DESKTOP &&
                    (usage == USB_USAGE_GENERIC_JOYSTICK || usage == USB_USAGE_GENERIC_GAMEPAD || usage == USB_USAGE_GENERIC_MULTIAXISCONTROLLER)) {
-            /* This is a controller */
+            // This is a controller
         } else {
-            return SDL_TRUE;
+            return true;
         }
     }
     if (SDL_hidapi_ignored_devices) {
@@ -1123,10 +1121,10 @@ SDL_bool SDL_HIDAPI_ShouldIgnoreDevice(int bus, Uint16 vendor_id, Uint16 product
         SDL_snprintf(product_match, sizeof(product_match), "0x%.4x/0x%.4x", vendor_id, product_id);
         if (SDL_strcasestr(SDL_hidapi_ignored_devices, vendor_match) ||
             SDL_strcasestr(SDL_hidapi_ignored_devices, product_match)) {
-            return SDL_TRUE;
+            return true;
         }
     }
-    return SDL_FALSE;
+    return false;
 }
 
 int SDL_hid_init(void)
@@ -1142,9 +1140,9 @@ int SDL_hid_init(void)
     SDL_AddHintCallback(SDL_HINT_HIDAPI_IGNORE_DEVICES, IgnoredDevicesChanged, NULL);
 
 #ifdef SDL_USE_LIBUDEV
-    if (SDL_getenv("SDL_HIDAPI_JOYSTICK_DISABLE_UDEV") != NULL) {
+    if (!SDL_GetHintBoolean(SDL_HINT_HIDAPI_UDEV, true)) {
         SDL_LogDebug(SDL_LOG_CATEGORY_INPUT,
-                     "udev disabled by SDL_HIDAPI_JOYSTICK_DISABLE_UDEV");
+                     "udev disabled by SDL_HINT_HIDAPI_UDEV");
         linux_enumeration_method = ENUMERATION_FALLBACK;
     } else if (SDL_DetectSandbox() != SDL_SANDBOX_NONE) {
         SDL_LogDebug(SDL_LOG_CATEGORY_INPUT,
@@ -1157,12 +1155,12 @@ int SDL_hid_init(void)
     }
 #endif
 
-    use_libusb_whitelist = SDL_GetHintBoolean("SDL_HIDAPI_LIBUSB_WHITELIST",
-                                              SDL_HIDAPI_LIBUSB_WHITELIST_DEFAULT);
+    use_libusb_whitelist = SDL_GetHintBoolean(SDL_HINT_HIDAPI_LIBUSB_WHITELIST,
+                                              SDL_HINT_HIDAPI_LIBUSB_WHITELIST_DEFAULT);
 #ifdef HAVE_LIBUSB
-    if (SDL_getenv("SDL_HIDAPI_DISABLE_LIBUSB") != NULL) {
+    if (!SDL_GetHintBoolean(SDL_HINT_HIDAPI_LIBUSB, true)) {
         SDL_LogDebug(SDL_LOG_CATEGORY_INPUT,
-                     "libusb disabled by SDL_HIDAPI_DISABLE_LIBUSB");
+                     "libusb disabled with SDL_HINT_HIDAPI_LIBUSB");
         libusb_ctx.libhandle = NULL;
     } else {
         ++attempts;
@@ -1172,11 +1170,11 @@ int SDL_hid_init(void)
         libusb_ctx.libhandle = (void *)1;
 #endif
         if (libusb_ctx.libhandle != NULL) {
-            SDL_bool loaded = SDL_TRUE;
+            bool loaded = true;
 #ifdef SDL_LIBUSB_DYNAMIC
 #define LOAD_LIBUSB_SYMBOL(type, func)                                                        \
     if (!(libusb_ctx.func = (type)SDL_LoadFunction(libusb_ctx.libhandle, "libusb_" #func))) { \
-        loaded = SDL_FALSE;                                                                   \
+        loaded = false;                                                                   \
     }
 #else
 #define LOAD_LIBUSB_SYMBOL(type, func) \
@@ -1218,7 +1216,7 @@ int SDL_hid_init(void)
                 SDL_UnloadObject(libusb_ctx.libhandle);
 #endif
                 libusb_ctx.libhandle = NULL;
-                /* SDL_LogWarn(SDL_LOG_CATEGORY_INPUT, SDL_LIBUSB_DYNAMIC " found but could not load function"); */
+                // SDL_LogWarn(SDL_LOG_CATEGORY_INPUT, SDL_LIBUSB_DYNAMIC " found but could not load function");
             } else if (LIBUSB_hid_init() < 0) {
 #ifdef SDL_LIBUSB_DYNAMIC
                 SDL_UnloadObject(libusb_ctx.libhandle);
@@ -1229,17 +1227,17 @@ int SDL_hid_init(void)
             }
         }
     }
-#endif /* HAVE_LIBUSB */
+#endif // HAVE_LIBUSB
 
 #ifdef HAVE_PLATFORM_BACKEND
     ++attempts;
 #ifdef SDL_PLATFORM_LINUX
     udev_ctx = SDL_UDEV_GetUdevSyms();
-#endif /* __LINUX __ */
+#endif // __LINUX __
     if (udev_ctx && PLATFORM_hid_init() == 0) {
         ++success;
     }
-#endif /* HAVE_PLATFORM_BACKEND */
+#endif // HAVE_PLATFORM_BACKEND
 
     if (attempts > 0 && success == 0) {
         return -1;
@@ -1276,8 +1274,8 @@ int SDL_hid_exit(void)
     }
 #ifdef SDL_PLATFORM_LINUX
     SDL_UDEV_ReleaseUdevSyms();
-#endif /* __LINUX __ */
-#endif /* HAVE_PLATFORM_BACKEND */
+#endif // __LINUX __
+#endif // HAVE_PLATFORM_BACKEND
 
 #ifdef HAVE_LIBUSB
     if (libusb_ctx.libhandle) {
@@ -1287,10 +1285,10 @@ int SDL_hid_exit(void)
 #endif
         libusb_ctx.libhandle = NULL;
     }
-#endif /* HAVE_LIBUSB */
+#endif // HAVE_LIBUSB
 
-    SDL_DelHintCallback(SDL_HINT_HIDAPI_ENUMERATE_ONLY_CONTROLLERS, OnlyControllersChanged, NULL);
-    SDL_DelHintCallback(SDL_HINT_HIDAPI_IGNORE_DEVICES, IgnoredDevicesChanged, NULL);
+    SDL_RemoveHintCallback(SDL_HINT_HIDAPI_ENUMERATE_ONLY_CONTROLLERS, OnlyControllersChanged, NULL);
+    SDL_RemoveHintCallback(SDL_HINT_HIDAPI_IGNORE_DEVICES, IgnoredDevicesChanged, NULL);
 
     if (SDL_hidapi_ignored_devices) {
         SDL_free(SDL_hidapi_ignored_devices);
@@ -1305,19 +1303,19 @@ Uint32 SDL_hid_device_change_count(void)
     Uint32 counter = 0;
 
 #ifndef SDL_HIDAPI_DISABLED
-    if (SDL_hidapi_refcount == 0 && SDL_hid_init() != 0) {
+    if (SDL_hidapi_refcount == 0 && SDL_hid_init() < 0) {
         return 0;
     }
 
     HIDAPI_UpdateDiscovery();
 
     if (SDL_HIDAPI_discovery.m_unDeviceChangeCounter == 0) {
-        /* Counter wrapped! */
+        // Counter wrapped!
         ++SDL_HIDAPI_discovery.m_unDeviceChangeCounter;
     }
     counter = SDL_HIDAPI_discovery.m_unDeviceChangeCounter;
 
-#endif /* !SDL_HIDAPI_DISABLED */
+#endif // !SDL_HIDAPI_DISABLED
 
     return counter;
 }
@@ -1335,7 +1333,7 @@ static void AddDeviceToEnumeration(const char *driver_name, struct hid_device_in
 
     new_dev = (struct SDL_hid_device_info *)SDL_malloc(sizeof(struct SDL_hid_device_info));
     if (new_dev == NULL) {
-        /* Don't bother returning an error, get as many devices as possible */
+        // Don't bother returning an error, get as many devices as possible
         return;
     }
     CopyHIDDeviceInfo(dev, new_dev);
@@ -1378,7 +1376,7 @@ static void RemoveDeviceFromEnumeration(const char *driver_name, struct hid_devi
         last = curr;
     }
 }
-#endif /* HAVE_LIBUSB || HAVE_PLATFORM_BACKEND */
+#endif // HAVE_LIBUSB || HAVE_PLATFORM_BACKEND
 
 #ifdef HAVE_LIBUSB
 static void RemoveNonWhitelistedDevicesFromEnumeration(struct hid_device_info **devs, void (*free_device_info)(struct hid_device_info *))
@@ -1406,7 +1404,7 @@ static void RemoveNonWhitelistedDevicesFromEnumeration(struct hid_device_info **
         last = curr;
     }
 }
-#endif /* HAVE_LIBUSB */
+#endif // HAVE_LIBUSB
 
 struct SDL_hid_device_info *SDL_hid_enumerate(unsigned short vendor_id, unsigned short product_id)
 {
@@ -1416,11 +1414,11 @@ struct SDL_hid_device_info *SDL_hid_enumerate(unsigned short vendor_id, unsigned
     struct hid_device_info *dev;
     struct SDL_hid_device_info *devs = NULL, *last = NULL;
 
-    if (SDL_hidapi_refcount == 0 && SDL_hid_init() != 0) {
+    if (SDL_hidapi_refcount == 0 && SDL_hid_init() < 0) {
         return NULL;
     }
 
-    /* Collect the available devices */
+    // Collect the available devices
 #ifdef HAVE_DRIVER_BACKEND
     driver_devs = DRIVER_hid_enumerate(vendor_id, product_id);
 #endif
@@ -1433,7 +1431,7 @@ struct SDL_hid_device_info *SDL_hid_enumerate(unsigned short vendor_id, unsigned
             RemoveNonWhitelistedDevicesFromEnumeration(&usb_devs,  LIBUSB_hid_free_enumeration);
         }
     }
-#endif /* HAVE_LIBUSB */
+#endif // HAVE_LIBUSB
 
 #ifdef HAVE_PLATFORM_BACKEND
     if (udev_ctx) {
@@ -1441,7 +1439,7 @@ struct SDL_hid_device_info *SDL_hid_enumerate(unsigned short vendor_id, unsigned
     }
 #endif
 
-    /* Highest priority are custom driver devices */
+    // Highest priority are custom driver devices
     for (dev = driver_devs; dev; dev = dev->next) {
         AddDeviceToEnumeration("driver", dev, &devs, &last);
 #ifdef HAVE_LIBUSB
@@ -1452,7 +1450,7 @@ struct SDL_hid_device_info *SDL_hid_enumerate(unsigned short vendor_id, unsigned
 #endif
     }
 
-    /* If whitelist is in effect, libusb has priority, otherwise raw devices do */
+    // If whitelist is in effect, libusb has priority, otherwise raw devices do
     if (use_libusb_whitelist) {
         for (dev = usb_devs; dev; dev = dev->next) {
             AddDeviceToEnumeration("libusb", dev, &devs, &last);
@@ -1506,7 +1504,7 @@ SDL_hid_device *SDL_hid_open(unsigned short vendor_id, unsigned short product_id
 #if defined(HAVE_PLATFORM_BACKEND) || defined(HAVE_DRIVER_BACKEND) || defined(HAVE_LIBUSB)
     void *pDevice = NULL;
 
-    if (SDL_hidapi_refcount == 0 && SDL_hid_init() != 0) {
+    if (SDL_hidapi_refcount == 0 && SDL_hid_init() < 0) {
         return NULL;
     }
 
@@ -1517,14 +1515,14 @@ SDL_hid_device *SDL_hid_open(unsigned short vendor_id, unsigned short product_id
             return CreateHIDDeviceWrapper(pDevice, &PLATFORM_Backend);
         }
     }
-#endif /* HAVE_PLATFORM_BACKEND */
+#endif // HAVE_PLATFORM_BACKEND
 
 #ifdef HAVE_DRIVER_BACKEND
     pDevice = DRIVER_hid_open(vendor_id, product_id, serial_number);
     if (pDevice != NULL) {
         return CreateHIDDeviceWrapper(pDevice, &DRIVER_Backend);
     }
-#endif /* HAVE_DRIVER_BACKEND */
+#endif // HAVE_DRIVER_BACKEND
 
 #ifdef HAVE_LIBUSB
     if (libusb_ctx.libhandle != NULL) {
@@ -1533,9 +1531,9 @@ SDL_hid_device *SDL_hid_open(unsigned short vendor_id, unsigned short product_id
             return CreateHIDDeviceWrapper(pDevice, &LIBUSB_Backend);
         }
     }
-#endif /* HAVE_LIBUSB */
+#endif // HAVE_LIBUSB
 
-#endif /* HAVE_PLATFORM_BACKEND || HAVE_DRIVER_BACKEND || HAVE_LIBUSB */
+#endif // HAVE_PLATFORM_BACKEND || HAVE_DRIVER_BACKEND || HAVE_LIBUSB
 
     return NULL;
 }
@@ -1545,7 +1543,7 @@ SDL_hid_device *SDL_hid_open_path(const char *path)
 #if defined(HAVE_PLATFORM_BACKEND) || defined(HAVE_DRIVER_BACKEND) || defined(HAVE_LIBUSB)
     void *pDevice = NULL;
 
-    if (SDL_hidapi_refcount == 0 && SDL_hid_init() != 0) {
+    if (SDL_hidapi_refcount == 0 && SDL_hid_init() < 0) {
         return NULL;
     }
 
@@ -1556,14 +1554,14 @@ SDL_hid_device *SDL_hid_open_path(const char *path)
             return CreateHIDDeviceWrapper(pDevice, &PLATFORM_Backend);
         }
     }
-#endif /* HAVE_PLATFORM_BACKEND */
+#endif // HAVE_PLATFORM_BACKEND
 
 #ifdef HAVE_DRIVER_BACKEND
     pDevice = DRIVER_hid_open_path(path);
     if (pDevice != NULL) {
         return CreateHIDDeviceWrapper(pDevice, &DRIVER_Backend);
     }
-#endif /* HAVE_DRIVER_BACKEND */
+#endif // HAVE_DRIVER_BACKEND
 
 #ifdef HAVE_LIBUSB
     if (libusb_ctx.libhandle != NULL) {
@@ -1572,9 +1570,9 @@ SDL_hid_device *SDL_hid_open_path(const char *path)
             return CreateHIDDeviceWrapper(pDevice, &LIBUSB_Backend);
         }
     }
-#endif /* HAVE_LIBUSB */
+#endif // HAVE_LIBUSB
 
-#endif /* HAVE_PLATFORM_BACKEND || HAVE_DRIVER_BACKEND || HAVE_LIBUSB */
+#endif // HAVE_PLATFORM_BACKEND || HAVE_DRIVER_BACKEND || HAVE_LIBUSB
 
     return NULL;
 }
@@ -1687,7 +1685,7 @@ int SDL_hid_get_report_descriptor(SDL_hid_device *device, unsigned char *buf, si
     return device->backend->hid_get_report_descriptor(device->device, buf, buf_size);
 }
 
-void SDL_hid_ble_scan(SDL_bool active)
+void SDL_hid_ble_scan(bool active)
 {
 #if !defined(SDL_HIDAPI_DISABLED) && (defined(SDL_PLATFORM_IOS) || defined(SDL_PLATFORM_TVOS))
     extern void hid_ble_scan(int bStart);
@@ -1696,7 +1694,7 @@ void SDL_hid_ble_scan(SDL_bool active)
 }
 
 #ifdef HAVE_ENABLE_GAMECUBE_ADAPTORS
-/* This is needed to enable input for Nyko and EVORETRO GameCube adaptors */
+// This is needed to enable input for Nyko and EVORETRO GameCube adaptors
 void SDL_EnableGameCubeAdaptors(void)
 {
 #ifdef HAVE_LIBUSB
@@ -1748,6 +1746,6 @@ void SDL_EnableGameCubeAdaptors(void)
 
         libusb_ctx.exit(context);
     }
-#endif /* HAVE_LIBUSB */
+#endif // HAVE_LIBUSB
 }
-#endif /* HAVE_ENABLE_GAMECUBE_ADAPTORS */
+#endif // HAVE_ENABLE_GAMECUBE_ADAPTORS
