@@ -713,7 +713,7 @@ public:
 			size_t uBytesToCopy = m_reportResponse.size() > nDataLen ? nDataLen : m_reportResponse.size();
 			SDL_memcpy( pData, m_reportResponse.data(), uBytesToCopy );
 			m_reportResponse.clear();
-			LOGV( "=== Got %u bytes", uBytesToCopy );
+			LOGV( "=== Got %zu bytes", uBytesToCopy );
 
 			return (int)uBytesToCopy;
 		}
@@ -1030,25 +1030,25 @@ extern "C"
 {
 
 // !!! FIXME: make this non-blocking!
-static void SDLCALL AndroidRequestPermissionBlockingCallback(void *userdata, const char *permission, SDL_bool granted)
+static void SDLCALL RequestAndroidPermissionBlockingCallback(void *userdata, const char *permission, bool granted)
 {
-    SDL_AtomicSet((SDL_AtomicInt *) userdata, granted ? 1 : -1);
+    SDL_SetAtomicInt((SDL_AtomicInt *) userdata, granted ? 1 : -1);
 }
 
-static SDL_bool RequestBluetoothPermissions(const char *permission)
+static bool RequestBluetoothPermissions(const char *permission)
 {
     // !!! FIXME: make this non-blocking!
     SDL_AtomicInt permission_response;
-    SDL_AtomicSet(&permission_response, 0);
-    if (SDL_AndroidRequestPermission(permission, AndroidRequestPermissionBlockingCallback, &permission_response) == -1) {
-        return SDL_FALSE;
+    SDL_SetAtomicInt(&permission_response, 0);
+    if (!SDL_RequestAndroidPermission(permission, RequestAndroidPermissionBlockingCallback, &permission_response)) {
+        return false;
     }
 
-    while (SDL_AtomicGet(&permission_response) == 0) {
+    while (SDL_GetAtomicInt(&permission_response) == 0) {
         SDL_Delay(10);
     }
 
-    return SDL_AtomicGet(&permission_response) > 0;
+    return SDL_GetAtomicInt(&permission_response) > 0;
 }
 
 
@@ -1067,7 +1067,7 @@ int hid_init(void)
 			// before initializing Bluetooth, which will prompt the user for permission.
 			bool init_usb = true;
 			bool init_bluetooth = false;
-			if (SDL_GetHintBoolean(SDL_HINT_JOYSTICK_HIDAPI_STEAM, SDL_FALSE)) {
+			if (SDL_GetHintBoolean(SDL_HINT_JOYSTICK_HIDAPI_STEAM, false)) {
 				if (SDL_GetAndroidSDKVersion() < 31 ||
 					RequestBluetoothPermissions("android.permission.BLUETOOTH_CONNECT")) {
 					init_bluetooth = true;
@@ -1159,7 +1159,7 @@ int  HID_API_EXPORT HID_API_CALL hid_write(hid_device *device, const unsigned ch
 {
 	if ( device )
 	{
-		LOGV( "hid_write id=%d length=%u", device->m_nId, length );
+		LOGV( "hid_write id=%d length=%zu", device->m_nId, length );
 		hid_device_ref<CHIDDevice> pDevice = FindDevice( device->m_nId );
 		if ( pDevice )
 		{
@@ -1223,7 +1223,7 @@ int HID_API_EXPORT HID_API_CALL hid_read_timeout(hid_device *device, unsigned ch
 // TODO: Implement blocking
 int  HID_API_EXPORT HID_API_CALL hid_read(hid_device *device, unsigned char *data, size_t length)
 {
-	LOGV( "hid_read id=%d length=%u", device->m_nId, length );
+	LOGV( "hid_read id=%d length=%zu", device->m_nId, length );
 	return hid_read_timeout( device, data, length, 0 );
 }
 
@@ -1237,7 +1237,7 @@ int HID_API_EXPORT HID_API_CALL hid_send_feature_report(hid_device *device, cons
 {
 	if ( device )
 	{
-		LOGV( "hid_send_feature_report id=%d length=%u", device->m_nId, length );
+		LOGV( "hid_send_feature_report id=%d length=%zu", device->m_nId, length );
 		hid_device_ref<CHIDDevice> pDevice = FindDevice( device->m_nId );
 		if ( pDevice )
 		{
@@ -1253,7 +1253,7 @@ int HID_API_EXPORT HID_API_CALL hid_get_feature_report(hid_device *device, unsig
 {
 	if ( device )
 	{
-		LOGV( "hid_get_feature_report id=%d length=%u", device->m_nId, length );
+		LOGV( "hid_get_feature_report id=%d length=%zu", device->m_nId, length );
 		hid_device_ref<CHIDDevice> pDevice = FindDevice( device->m_nId );
 		if ( pDevice )
 		{
@@ -1269,7 +1269,7 @@ int HID_API_EXPORT HID_API_CALL hid_get_input_report(hid_device *device, unsigne
 {
 	if ( device )
 	{
-		LOGV( "hid_get_input_report id=%d length=%u", device->m_nId, length );
+		LOGV( "hid_get_input_report id=%d length=%zu", device->m_nId, length );
 		hid_device_ref<CHIDDevice> pDevice = FindDevice( device->m_nId );
 		if ( pDevice )
 		{
