@@ -23,25 +23,25 @@
 #ifndef SDL_sysjoystick_h_
 #define SDL_sysjoystick_h_
 
-/* This is the system specific header for the SDL joystick API */
+// This is the system specific header for the SDL joystick API
 #include "SDL_joystick_c.h"
 
-/* Set up for C function definitions, even when using C++ */
+// Set up for C function definitions, even when using C++
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-/* The SDL joystick structure */
+// The SDL joystick structure
 
 typedef struct SDL_JoystickAxisInfo
 {
-    Sint16 initial_value;           /* Initial axis state */
-    Sint16 value;                   /* Current axis state */
-    Sint16 zero;                    /* Zero point on the axis (-32768 for triggers) */
-    SDL_bool has_initial_value;     /* Whether we've seen a value on the axis yet */
-    SDL_bool has_second_value;      /* Whether we've seen a second value on the axis yet */
-    SDL_bool sent_initial_value;    /* Whether we've sent the initial axis value */
-    SDL_bool sending_initial_value; /* Whether we are sending the initial axis value */
+    Sint16 initial_value;           // Initial axis state
+    Sint16 value;                   // Current axis state
+    Sint16 zero;                    // Zero point on the axis (-32768 for triggers)
+    bool has_initial_value;     // Whether we've seen a value on the axis yet
+    bool has_second_value;      // Whether we've seen a second value on the axis yet
+    bool sent_initial_value;    // Whether we've sent the initial axis value
+    bool sending_initial_value; // Whether we are sending the initial axis value
 } SDL_JoystickAxisInfo;
 
 typedef struct SDL_JoystickBallData
@@ -52,7 +52,7 @@ typedef struct SDL_JoystickBallData
 
 typedef struct SDL_JoystickTouchpadFingerInfo
 {
-    Uint8 state;
+    bool down;
     float x;
     float y;
     float pressure;
@@ -67,41 +67,39 @@ typedef struct SDL_JoystickTouchpadInfo
 typedef struct SDL_JoystickSensorInfo
 {
     SDL_SensorType type;
-    SDL_bool enabled;
+    bool enabled;
     float rate;
-    float data[3]; /* If this needs to expand, update SDL_GamepadSensorEvent */
+    float data[3]; // If this needs to expand, update SDL_GamepadSensorEvent
 } SDL_JoystickSensorInfo;
 
 #define _guarded SDL_GUARDED_BY(SDL_joystick_lock)
 
 struct SDL_Joystick
 {
-    const void *magic _guarded;
+    SDL_JoystickID instance_id _guarded; // Device instance, monotonically increasing from 0
+    char *name _guarded;                 // Joystick name - system dependent
+    char *path _guarded;                 // Joystick path - system dependent
+    char *serial _guarded;               // Joystick serial
+    SDL_GUID guid _guarded;      // Joystick guid
+    Uint16 firmware_version _guarded;    // Firmware version, if available
+    Uint64 steam_handle _guarded;        // Steam controller API handle
 
-    SDL_JoystickID instance_id _guarded; /* Device instance, monotonically increasing from 0 */
-    char *name _guarded;                 /* Joystick name - system dependent */
-    char *path _guarded;                 /* Joystick path - system dependent */
-    char *serial _guarded;               /* Joystick serial */
-    SDL_JoystickGUID guid _guarded;      /* Joystick guid */
-    Uint16 firmware_version _guarded;    /* Firmware version, if available */
-    Uint64 steam_handle _guarded;        /* Steam controller API handle */
-
-    int naxes _guarded; /* Number of axis controls on the joystick */
+    int naxes _guarded; // Number of axis controls on the joystick
     SDL_JoystickAxisInfo *axes _guarded;
 
-    int nballs _guarded; /* Number of trackballs on the joystick */
-    SDL_JoystickBallData *balls _guarded; /* Current ball motion deltas */
+    int nballs _guarded; // Number of trackballs on the joystick
+    SDL_JoystickBallData *balls _guarded; // Current ball motion deltas
 
-    int nhats _guarded;   /* Number of hats on the joystick */
-    Uint8 *hats _guarded; /* Current hat states */
+    int nhats _guarded;   // Number of hats on the joystick
+    Uint8 *hats _guarded; // Current hat states
 
-    int nbuttons _guarded;   /* Number of buttons on the joystick */
-    Uint8 *buttons _guarded; /* Current button states */
+    int nbuttons _guarded;   // Number of buttons on the joystick
+    bool *buttons _guarded; // Current button states
 
-    int ntouchpads _guarded;                      /* Number of touchpads on the joystick */
-    SDL_JoystickTouchpadInfo *touchpads _guarded; /* Current touchpad states */
+    int ntouchpads _guarded;                      // Number of touchpads on the joystick
+    SDL_JoystickTouchpadInfo *touchpads _guarded; // Current touchpad states
 
-    int nsensors _guarded; /* Number of sensors on the joystick */
+    int nsensors _guarded; // Number of sensors on the joystick
     int nsensors_enabled _guarded;
     SDL_JoystickSensorInfo *sensors _guarded;
 
@@ -119,13 +117,12 @@ struct SDL_Joystick
     Uint8 led_blue _guarded;
     Uint64 led_expiration _guarded;
 
-    SDL_bool attached _guarded;
-    SDL_bool is_gamepad _guarded;
+    bool attached _guarded;
     SDL_JoystickConnectionState connection_state _guarded;
     SDL_PowerState battery_state _guarded;
     int battery_percent _guarded;
 
-    SDL_bool delayed_guide_button _guarded;      /* SDL_TRUE if this device has the guide button event delayed */
+    bool delayed_guide_button _guarded;      // true if this device has the guide button event delayed
 
     SDL_SensorID accel_sensor _guarded;
     SDL_Sensor *accel _guarded;
@@ -137,24 +134,24 @@ struct SDL_Joystick
 
     struct SDL_JoystickDriver *driver _guarded;
 
-    struct joystick_hwdata *hwdata _guarded; /* Driver dependent information */
+    struct joystick_hwdata *hwdata _guarded; // Driver dependent information
 
     SDL_PropertiesID props _guarded;
 
-    int ref_count _guarded; /* Reference count for multiple opens */
+    int ref_count _guarded; // Reference count for multiple opens
 
-    struct SDL_Joystick *next _guarded; /* pointer to next joystick we have allocated */
+    struct SDL_Joystick *next _guarded; // pointer to next joystick we have allocated
 };
 
 #undef _guarded
 
-/* Device bus definitions */
+// Device bus definitions
 #define SDL_HARDWARE_BUS_UNKNOWN   0x00
 #define SDL_HARDWARE_BUS_USB       0x03
 #define SDL_HARDWARE_BUS_BLUETOOTH 0x05
 #define SDL_HARDWARE_BUS_VIRTUAL   0xFF
 
-/* Macro to combine a USB vendor ID and product ID into a single Uint32 value */
+// Macro to combine a USB vendor ID and product ID into a single Uint32 value
 #define MAKE_VIDPID(VID, PID) (((Uint32)(VID)) << 16 | (PID))
 
 typedef struct SDL_JoystickDriver
@@ -163,36 +160,36 @@ typedef struct SDL_JoystickDriver
      * Joystick 0 should be the system default joystick.
      * This function should return 0, or -1 on an unrecoverable error.
      */
-    int (*Init)(void);
+    bool (*Init)(void);
 
-    /* Function to return the number of joystick devices plugged in right now */
+    // Function to return the number of joystick devices plugged in right now
     int (*GetCount)(void);
 
-    /* Function to cause any queued joystick insertions to be processed */
+    // Function to cause any queued joystick insertions to be processed
     void (*Detect)(void);
 
-    /* Function to determine whether a device is currently detected by this driver */
-    SDL_bool (*IsDevicePresent)(Uint16 vendor_id, Uint16 product_id, Uint16 version, const char *name);
+    // Function to determine whether a device is currently detected by this driver
+    bool (*IsDevicePresent)(Uint16 vendor_id, Uint16 product_id, Uint16 version, const char *name);
 
-    /* Function to get the device-dependent name of a joystick */
+    // Function to get the device-dependent name of a joystick
     const char *(*GetDeviceName)(int device_index);
 
-    /* Function to get the device-dependent path of a joystick */
+    // Function to get the device-dependent path of a joystick
     const char *(*GetDevicePath)(int device_index);
 
-    /* Function to get the Steam virtual gamepad slot of a joystick */
+    // Function to get the Steam virtual gamepad slot of a joystick
     int (*GetDeviceSteamVirtualGamepadSlot)(int device_index);
 
-    /* Function to get the player index of a joystick */
+    // Function to get the player index of a joystick
     int (*GetDevicePlayerIndex)(int device_index);
 
-    /* Function to set the player index of a joystick */
+    // Function to set the player index of a joystick
     void (*SetDevicePlayerIndex)(int device_index, int player_index);
 
-    /* Function to return the stable GUID for a plugged in device */
-    SDL_JoystickGUID (*GetDeviceGUID)(int device_index);
+    // Function to return the stable GUID for a plugged in device
+    SDL_GUID (*GetDeviceGUID)(int device_index);
 
-    /* Function to get the current instance id of the joystick located at device_index */
+    // Function to get the current instance id of the joystick located at device_index
     SDL_JoystickID (*GetDeviceInstanceID)(int device_index);
 
     /* Function to open a joystick for use.
@@ -200,20 +197,20 @@ typedef struct SDL_JoystickDriver
        This should fill the nbuttons and naxes fields of the joystick structure.
        It returns 0, or -1 if there is an error.
      */
-    int (*Open)(SDL_Joystick *joystick, int device_index);
+    bool (*Open)(SDL_Joystick *joystick, int device_index);
 
-    /* Rumble functionality */
-    int (*Rumble)(SDL_Joystick *joystick, Uint16 low_frequency_rumble, Uint16 high_frequency_rumble);
-    int (*RumbleTriggers)(SDL_Joystick *joystick, Uint16 left_rumble, Uint16 right_rumble);
+    // Rumble functionality
+    bool (*Rumble)(SDL_Joystick *joystick, Uint16 low_frequency_rumble, Uint16 high_frequency_rumble);
+    bool (*RumbleTriggers)(SDL_Joystick *joystick, Uint16 left_rumble, Uint16 right_rumble);
 
-    /* LED functionality */
-    int (*SetLED)(SDL_Joystick *joystick, Uint8 red, Uint8 green, Uint8 blue);
+    // LED functionality
+    bool (*SetLED)(SDL_Joystick *joystick, Uint8 red, Uint8 green, Uint8 blue);
 
-    /* General effects */
-    int (*SendEffect)(SDL_Joystick *joystick, const void *data, int size);
+    // General effects
+    bool (*SendEffect)(SDL_Joystick *joystick, const void *data, int size);
 
-    /* Sensor functionality */
-    int (*SetSensorsEnabled)(SDL_Joystick *joystick, SDL_bool enabled);
+    // Sensor functionality
+    bool (*SetSensorsEnabled)(SDL_Joystick *joystick, bool enabled);
 
     /* Function to update the state of a joystick - called as a device poll.
      * This function shouldn't update the joystick structure directly,
@@ -222,18 +219,18 @@ typedef struct SDL_JoystickDriver
      */
     void (*Update)(SDL_Joystick *joystick);
 
-    /* Function to close a joystick after use */
+    // Function to close a joystick after use
     void (*Close)(SDL_Joystick *joystick);
 
-    /* Function to perform any system-specific joystick related cleanup */
+    // Function to perform any system-specific joystick related cleanup
     void (*Quit)(void);
 
-    /* Function to get the autodetected controller mapping; returns false if there isn't any. */
-    SDL_bool (*GetGamepadMapping)(int device_index, SDL_GamepadMapping *out);
+    // Function to get the autodetected controller mapping; returns false if there isn't any.
+    bool (*GetGamepadMapping)(int device_index, SDL_GamepadMapping *out);
 
 } SDL_JoystickDriver;
 
-/* Windows and Mac OSX has a limit of MAX_DWORD / 1000, Linux kernel has a limit of 0xFFFF */
+// Windows and Mac OSX has a limit of MAX_DWORD / 1000, Linux kernel has a limit of 0xFFFF
 #define SDL_MAX_RUMBLE_DURATION_MS 0xFFFF
 
 /* Dualshock4 only rumbles for about 5 seconds max, resend rumble command every 2 seconds
@@ -242,7 +239,7 @@ typedef struct SDL_JoystickDriver
 
 #define SDL_LED_MIN_REPEAT_MS 5000
 
-/* The available joystick drivers */
+// The available joystick drivers
 extern SDL_JoystickDriver SDL_ANDROID_JoystickDriver;
 extern SDL_JoystickDriver SDL_BSD_JoystickDriver;
 extern SDL_JoystickDriver SDL_DARWIN_JoystickDriver;
@@ -263,9 +260,9 @@ extern SDL_JoystickDriver SDL_VITA_JoystickDriver;
 extern SDL_JoystickDriver SDL_N3DS_JoystickDriver;
 extern SDL_JoystickDriver SDL_GAMEINPUT_JoystickDriver;
 
-/* Ends C function definitions when using C++ */
+// Ends C function definitions when using C++
 #ifdef __cplusplus
 }
 #endif
 
-#endif /* SDL_sysjoystick_h_ */
+#endif // SDL_sysjoystick_h_
