@@ -103,14 +103,14 @@ struct report
 {
 #if defined(SDL_PLATFORM_FREEBSD) && (__FreeBSD_kernel_version > 900000) || \
     defined(__DragonFly__)
-    void *buf; /* Buffer */
+    void *buf; // Buffer
 #elif defined(SDL_PLATFORM_FREEBSD) && (__FreeBSD_kernel_version > 800063)
-    struct usb_gen_descriptor *buf; /* Buffer */
+    struct usb_gen_descriptor *buf; // Buffer
 #else
-    struct usb_ctl_report *buf; /* Buffer */
+    struct usb_ctl_report *buf; // Buffer
 #endif
-    size_t size; /* Buffer size */
-    int rid;     /* Report ID */
+    size_t size; // Buffer size
+    int rid;     // Report ID
     enum
     {
         SREPORT_UNINIT,
@@ -155,8 +155,8 @@ struct joystick_hwdata
     int fd;
     enum
     {
-        BSDJOY_UHID, /* uhid(4) */
-        BSDJOY_JOY   /* joy(4) */
+        BSDJOY_UHID, // uhid(4)
+        BSDJOY_JOY   // joy(4)
     } type;
 
     int naxes;
@@ -167,13 +167,13 @@ struct joystick_hwdata
     int axis_map[JOYAXE_count]; /* map present JOYAXE_* to 0,1,.. */
 };
 
-/* A linked list of available joysticks */
+// A linked list of available joysticks
 typedef struct SDL_joylist_item
 {
     SDL_JoystickID device_instance;
-    char *path; /* "/dev/uhid0" or whatever */
-    char *name; /* "SideWinder 3D Pro" or whatever */
-    SDL_JoystickGUID guid;
+    char *path; // "/dev/uhid0" or whatever
+    char *name; // "SideWinder 3D Pro" or whatever
+    SDL_GUID guid;
     dev_t devnum;
     struct SDL_joylist_item *next;
 } SDL_joylist_item;
@@ -182,7 +182,7 @@ static SDL_joylist_item *SDL_joylist = NULL;
 static SDL_joylist_item *SDL_joylist_tail = NULL;
 static int numjoysticks = 0;
 
-static int report_alloc(struct report *, struct report_desc *, int);
+static bool report_alloc(struct report *, struct report_desc *, int);
 static void report_free(struct report *);
 
 #if defined(USBHID_UCR_DATA) || (defined(__FreeBSD_kernel__) && __FreeBSD_kernel_version <= 800063)
@@ -250,8 +250,7 @@ static void FreeHwData(struct joystick_hwdata *hw)
     SDL_free(hw);
 }
 
-static struct joystick_hwdata *
-CreateHwData(const char *path)
+static struct joystick_hwdata *CreateHwData(const char *path)
 {
     struct joystick_hwdata *hw;
     struct hid_item hitem;
@@ -302,9 +301,9 @@ CreateHwData(const char *path)
 #else
         if (ioctl(fd, USB_GET_REPORT_ID, &rep->rid) < 0) {
 #endif
-            rep->rid = -1; /* XXX */
+            rep->rid = -1; // XXX
         }
-        if (report_alloc(rep, hw->repdesc, REPORT_INPUT) < 0) {
+        if (!report_alloc(rep, hw->repdesc, REPORT_INPUT)) {
             goto usberr;
         }
         if (rep->size <= 0) {
@@ -372,10 +371,10 @@ CreateHwData(const char *path)
         }
     }
 
-    /* The poll blocks the event thread. */
+    // The poll blocks the event thread.
     fcntl(fd, F_SETFL, O_NONBLOCK);
 #ifdef SDL_PLATFORM_NETBSD
-    /* Flush pending events */
+    // Flush pending events
     if (rep) {
         while (read(fd, REP_BUF_DATA(rep), rep->size) == rep->size)
             ;
@@ -389,32 +388,32 @@ usberr:
     return NULL;
 }
 
-static int MaybeAddDevice(const char *path)
+static bool MaybeAddDevice(const char *path)
 {
     struct stat sb;
     char *name = NULL;
-    SDL_JoystickGUID guid;
+    SDL_GUID guid;
     SDL_joylist_item *item;
     struct joystick_hwdata *hw;
 
     if (!path) {
-        return -1;
+        return false;
     }
 
     if (stat(path, &sb) == -1) {
-        return -1;
+        return false;
     }
 
-    /* Check to make sure it's not already in list. */
+    // Check to make sure it's not already in list.
     for (item = SDL_joylist; item; item = item->next) {
         if (sb.st_rdev == item->devnum) {
-            return -1; /* already have this one */
+            return false; // already have this one
         }
     }
 
     hw = CreateHwData(path);
     if (!hw) {
-        return -1;
+        return false;
     }
 
     if (hw->type == BSDJOY_JOY) {
@@ -431,10 +430,10 @@ static int MaybeAddDevice(const char *path)
                 SDL_JoystickHandledByAnotherDriver(&SDL_BSD_JoystickDriver, di.udi_vendorNo, di.udi_productNo, di.udi_releaseNo, name)) {
                 SDL_free(name);
                 FreeHwData(hw);
-                return -1;
+                return false;
             }
         }
-#endif /* USB_GET_DEVICEINFO */
+#endif // USB_GET_DEVICEINFO
     }
     if (!name) {
         name = SDL_strdup(path);
@@ -445,7 +444,7 @@ static int MaybeAddDevice(const char *path)
     item = (SDL_joylist_item *)SDL_calloc(1, sizeof(SDL_joylist_item));
     if (!item) {
         SDL_free(name);
-        return -1;
+        return false;
     }
 
     item->devnum = sb.st_rdev;
@@ -455,7 +454,7 @@ static int MaybeAddDevice(const char *path)
 
     if ((!item->path) || (!item->name)) {
         FreeJoylistItem(item);
-        return -1;
+        return false;
     }
 
     item->device_instance = SDL_GetNextObjectID();
@@ -466,15 +465,15 @@ static int MaybeAddDevice(const char *path)
         SDL_joylist_tail = item;
     }
 
-    /* Need to increment the joystick count before we post the event */
+    // Need to increment the joystick count before we post the event
     ++numjoysticks;
 
     SDL_PrivateJoystickAdded(item->device_instance);
 
-    return numjoysticks;
+    return true;
 }
 
-static int BSD_JoystickInit(void)
+static bool BSD_JoystickInit(void)
 {
     char s[16];
     int i;
@@ -492,12 +491,12 @@ static int BSD_JoystickInit(void)
         SDL_snprintf(s, SDL_arraysize(s), "/dev/joy%d", i);
         MaybeAddDevice(s);
     }
-#endif /* SUPPORT_JOY_GAMEPORT */
+#endif // SUPPORT_JOY_GAMEPORT
 
-    /* Read the default USB HID usage table. */
+    // Read the default USB HID usage table.
     hid_init(NULL);
 
-    return numjoysticks;
+    return true;
 }
 
 static int BSD_JoystickGetCount(void)
@@ -509,10 +508,10 @@ static void BSD_JoystickDetect(void)
 {
 }
 
-static SDL_bool BSD_JoystickIsDevicePresent(Uint16 vendor_id, Uint16 product_id, Uint16 version, const char *name)
+static bool BSD_JoystickIsDevicePresent(Uint16 vendor_id, Uint16 product_id, Uint16 version, const char *name)
 {
-    /* We don't override any other drivers */
-    return SDL_FALSE;
+    // We don't override any other drivers
+    return false;
 }
 
 static SDL_joylist_item *GetJoystickByDevIndex(int device_index)
@@ -556,12 +555,12 @@ static void BSD_JoystickSetDevicePlayerIndex(int device_index, int player_index)
 {
 }
 
-static SDL_JoystickGUID BSD_JoystickGetDeviceGUID(int device_index)
+static SDL_GUID BSD_JoystickGetDeviceGUID(int device_index)
 {
     return GetJoystickByDevIndex(device_index)->guid;
 }
 
-/* Function to perform the mapping from device index to the instance id for this index */
+// Function to perform the mapping from device index to the instance id for this index
 static SDL_JoystickID BSD_JoystickGetDeviceInstanceID(int device_index)
 {
     return GetJoystickByDevIndex(device_index)->device_instance;
@@ -581,7 +580,7 @@ static unsigned hatval_to_sdl(Sint32 hatval)
     return result;
 }
 
-static int BSD_JoystickOpen(SDL_Joystick *joy, int device_index)
+static bool BSD_JoystickOpen(SDL_Joystick *joy, int device_index)
 {
     SDL_joylist_item *item = GetJoystickByDevIndex(device_index);
     struct joystick_hwdata *hw;
@@ -592,7 +591,7 @@ static int BSD_JoystickOpen(SDL_Joystick *joy, int device_index)
 
     hw = CreateHwData(item->path);
     if (!hw) {
-        return -1;
+        return false;
     }
 
     joy->hwdata = hw;
@@ -600,7 +599,7 @@ static int BSD_JoystickOpen(SDL_Joystick *joy, int device_index)
     joy->nbuttons = hw->nbuttons;
     joy->nhats = hw->nhats;
 
-    return 0;
+    return true;
 }
 
 static void BSD_JoystickUpdate(SDL_Joystick *joy)
@@ -651,12 +650,12 @@ static void BSD_JoystickUpdate(SDL_Joystick *joy)
                 v = (((SDL_JOYSTICK_AXIS_MAX - SDL_JOYSTICK_AXIS_MIN) * ((Sint32)y - ymin)) / (ymax - ymin)) + SDL_JOYSTICK_AXIS_MIN;
                 SDL_SendJoystickAxis(timestamp, joy, 1, v);
             }
-            SDL_SendJoystickButton(timestamp, joy, 0, gameport.b1);
-            SDL_SendJoystickButton(timestamp, joy, 1, gameport.b2);
+            SDL_SendJoystickButton(timestamp, joy, 0, (gameport.b1 != 0));
+            SDL_SendJoystickButton(timestamp, joy, 1, (gameport.b2 != 0));
         }
         return;
     }
-#endif /* SUPPORT_JOY_GAMEPORT */
+#endif // SUPPORT_JOY_GAMEPORT
 
     rep = &joy->hwdata->inreport;
 
@@ -667,7 +666,7 @@ static void BSD_JoystickUpdate(SDL_Joystick *joy)
         hdata = hid_start_parse(joy->hwdata->repdesc, 1 << hid_input);
 #endif
         if (!hdata) {
-            /*fprintf(stderr, "%s: Cannot start HID parser\n", joy->hwdata->path);*/
+            // fprintf(stderr, "%s: Cannot start HID parser\n", joy->hwdata->path);
             continue;
         }
 
@@ -681,7 +680,7 @@ static void BSD_JoystickUpdate(SDL_Joystick *joy)
                     int joyaxe = usage_to_joyaxe(usage);
                     if (joyaxe >= 0) {
                         naxe = joy->hwdata->axis_map[joyaxe];
-                        /* scaleaxe */
+                        // scaleaxe
                         v = (Sint32)hid_get_data(REP_BUF_DATA(rep), &hitem);
                         v = (((SDL_JOYSTICK_AXIS_MAX - SDL_JOYSTICK_AXIS_MIN) * (v - hitem.logical_minimum)) / (hitem.logical_maximum - hitem.logical_minimum)) + SDL_JOYSTICK_AXIS_MIN;
                         SDL_SendJoystickAxis(timestamp, joy, naxe, v);
@@ -720,8 +719,8 @@ static void BSD_JoystickUpdate(SDL_Joystick *joy)
                 }
                 case HUP_BUTTON:
                     v = (Sint32)hid_get_data(REP_BUF_DATA(rep), &hitem);
-                    nbutton = HID_USAGE(hitem.usage) - 1; /* SDL buttons are zero-based */
-                    SDL_SendJoystickButton(timestamp, joy, nbutton, v);
+                    nbutton = HID_USAGE(hitem.usage) - 1; // SDL buttons are zero-based
+                    SDL_SendJoystickButton(timestamp, joy, nbutton, (v != 0));
                     break;
                 default:
                     continue;
@@ -735,7 +734,7 @@ static void BSD_JoystickUpdate(SDL_Joystick *joy)
     }
 }
 
-/* Function to close a joystick after use */
+// Function to close a joystick after use
 static void BSD_JoystickClose(SDL_Joystick *joy)
 {
     if (joy->hwdata) {
@@ -759,7 +758,7 @@ static void BSD_JoystickQuit(void)
     numjoysticks = 0;
 }
 
-static int report_alloc(struct report *r, struct report_desc *rd, int repind)
+static bool report_alloc(struct report *r, struct report_desc *rd, int repind)
 {
     int len;
 
@@ -796,14 +795,14 @@ static int report_alloc(struct report *r, struct report_desc *rd, int repind)
                             r->size);
 #endif
         if (!r->buf) {
-            return -1;
+            return false;
         }
     } else {
         r->buf = NULL;
     }
 
     r->status = SREPORT_CLEAN;
-    return 0;
+    return true;
 }
 
 static void report_free(struct report *r)
@@ -812,32 +811,32 @@ static void report_free(struct report *r)
     r->status = SREPORT_UNINIT;
 }
 
-static int BSD_JoystickRumble(SDL_Joystick *joystick, Uint16 low_frequency_rumble, Uint16 high_frequency_rumble)
+static bool BSD_JoystickRumble(SDL_Joystick *joystick, Uint16 low_frequency_rumble, Uint16 high_frequency_rumble)
 {
     return SDL_Unsupported();
 }
 
-static int BSD_JoystickRumbleTriggers(SDL_Joystick *joystick, Uint16 left_rumble, Uint16 right_rumble)
+static bool BSD_JoystickRumbleTriggers(SDL_Joystick *joystick, Uint16 left_rumble, Uint16 right_rumble)
 {
     return SDL_Unsupported();
 }
 
-static SDL_bool BSD_JoystickGetGamepadMapping(int device_index, SDL_GamepadMapping *out)
+static bool BSD_JoystickGetGamepadMapping(int device_index, SDL_GamepadMapping *out)
 {
-    return SDL_FALSE;
+    return false;
 }
 
-static int BSD_JoystickSetLED(SDL_Joystick *joystick, Uint8 red, Uint8 green, Uint8 blue)
+static bool BSD_JoystickSetLED(SDL_Joystick *joystick, Uint8 red, Uint8 green, Uint8 blue)
 {
     return SDL_Unsupported();
 }
 
-static int BSD_JoystickSendEffect(SDL_Joystick *joystick, const void *data, int size)
+static bool BSD_JoystickSendEffect(SDL_Joystick *joystick, const void *data, int size)
 {
     return SDL_Unsupported();
 }
 
-static int BSD_JoystickSetSensorsEnabled(SDL_Joystick *joystick, SDL_bool enabled)
+static bool BSD_JoystickSetSensorsEnabled(SDL_Joystick *joystick, bool enabled)
 {
     return SDL_Unsupported();
 }
@@ -866,4 +865,4 @@ SDL_JoystickDriver SDL_BSD_JoystickDriver = {
     BSD_JoystickGetGamepadMapping
 };
 
-#endif /* SDL_JOYSTICK_USBHID */
+#endif // SDL_JOYSTICK_USBHID
