@@ -35,7 +35,7 @@
 #include <initguid.h>
 
 #ifdef ____FIReference_1_INT32_INTERFACE_DEFINED__
-/* MinGW-64 uses __FIReference_1_INT32 instead of Microsoft's __FIReference_1_int */
+// MinGW-64 uses __FIReference_1_INT32 instead of Microsoft's __FIReference_1_int
 #define __FIReference_1_int           __FIReference_1_INT32
 #define __FIReference_1_int_get_Value __FIReference_1_INT32_get_Value
 #define __FIReference_1_int_Release   __FIReference_1_INT32_Release
@@ -56,7 +56,7 @@ typedef struct WindowsGamingInputControllerState
     SDL_JoystickID instance_id;
     __x_ABI_CWindows_CGaming_CInput_CIRawGameController *controller;
     char *name;
-    SDL_JoystickGUID guid;
+    SDL_GUID guid;
     SDL_JoystickType type;
     int steam_virtual_gamepad_slot;
 } WindowsGamingInputControllerState;
@@ -88,9 +88,8 @@ static struct
     WindowsGamingInputControllerState *controllers;
 } wgi;
 
-/* WinRT headers in official Windows SDK contain only declarations, and we have to define these GUIDs ourselves.
- * https://stackoverflow.com/a/55605485/1795050
- */
+// WinRT headers in official Windows SDK contain only declarations, and we have to define these GUIDs ourselves.
+// https://stackoverflow.com/a/55605485/1795050
 DEFINE_GUID(IID___FIEventHandler_1_Windows__CGaming__CInput__CRawGameController, 0x00621c22, 0x42e8, 0x529f, 0x92, 0x70, 0x83, 0x6b, 0x32, 0x93, 0x1d, 0x72);
 DEFINE_GUID(IID___x_ABI_CWindows_CGaming_CInput_CIArcadeStickStatics, 0x5c37b8c8, 0x37b1, 0x4ad8, 0x94, 0x58, 0x20, 0x0f, 0x1a, 0x30, 0x01, 0x8e);
 DEFINE_GUID(IID___x_ABI_CWindows_CGaming_CInput_CIArcadeStickStatics2, 0x52b5d744, 0xbb86, 0x445a, 0xb5, 0x9c, 0x59, 0x6f, 0x0e, 0x2a, 0x49, 0xdf);
@@ -105,40 +104,40 @@ DEFINE_GUID(IID___x_ABI_CWindows_CGaming_CInput_CIRawGameController, 0x7cad6d91,
 DEFINE_GUID(IID___x_ABI_CWindows_CGaming_CInput_CIRawGameController2, 0x43c0c035, 0xbb73, 0x4756, 0xa7, 0x87, 0x3e, 0xd6, 0xbe, 0xa6, 0x17, 0xbd);
 DEFINE_GUID(IID___x_ABI_CWindows_CGaming_CInput_CIRawGameControllerStatics, 0xeb8d0792, 0xe95a, 0x4b19, 0xaf, 0xc7, 0x0a, 0x59, 0xf8, 0xbf, 0x75, 0x9e);
 
-extern SDL_bool SDL_XINPUT_Enabled(void);
+extern bool SDL_XINPUT_Enabled(void);
 
 
-static SDL_bool SDL_IsXInputDevice(Uint16 vendor, Uint16 product)
+static bool SDL_IsXInputDevice(Uint16 vendor, Uint16 product)
 {
 #if defined(SDL_JOYSTICK_XINPUT) || defined(SDL_JOYSTICK_RAWINPUT)
     PRAWINPUTDEVICELIST raw_devices = NULL;
     UINT i, raw_device_count = 0;
     LONG vidpid = MAKELONG(vendor, product);
 
-    /* XInput and RawInput backends will pick up XInput-compatible devices */
+    // XInput and RawInput backends will pick up XInput-compatible devices
     if (!SDL_XINPUT_Enabled()
 #ifdef SDL_JOYSTICK_RAWINPUT
         && !RAWINPUT_IsEnabled()
 #endif
     ) {
-        return SDL_FALSE;
+        return false;
     }
 
-    /* Go through RAWINPUT (WinXP and later) to find HID devices. */
+    // Go through RAWINPUT (WinXP and later) to find HID devices.
     if ((GetRawInputDeviceList(NULL, &raw_device_count, sizeof(RAWINPUTDEVICELIST)) == -1) || (!raw_device_count)) {
-        return SDL_FALSE; /* oh well. */
+        return false; // oh well.
     }
 
     raw_devices = (PRAWINPUTDEVICELIST)SDL_malloc(sizeof(RAWINPUTDEVICELIST) * raw_device_count);
     if (!raw_devices) {
-        return SDL_FALSE;
+        return false;
     }
 
     raw_device_count = GetRawInputDeviceList(raw_devices, &raw_device_count, sizeof(RAWINPUTDEVICELIST));
     if (raw_device_count == (UINT)-1) {
         SDL_free(raw_devices);
         raw_devices = NULL;
-        return SDL_FALSE; /* oh well. */
+        return false; // oh well.
     }
 
     for (i = 0; i < raw_device_count; i++) {
@@ -156,26 +155,26 @@ static SDL_bool SDL_IsXInputDevice(Uint16 vendor, Uint16 product)
             (GetRawInputDeviceInfoA(raw_devices[i].hDevice, RIDI_DEVICEINFO, &rdi, &rdiSize) == ((UINT)-1)) ||
             (GetRawInputDeviceInfoA(raw_devices[i].hDevice, RIDI_DEVICENAME, devName, &nameSize) == ((UINT)-1)) ||
             (SDL_strstr(devName, "IG_") == NULL)) {
-            /* Skip non-XInput devices */
+            // Skip non-XInput devices
             continue;
         }
 
-        /* First check for a simple VID/PID match. This will work for Xbox 360 controllers. */
+        // First check for a simple VID/PID match. This will work for Xbox 360 controllers.
         if (MAKELONG(rdi.hid.dwVendorId, rdi.hid.dwProductId) == vidpid) {
             SDL_free(raw_devices);
-            return SDL_TRUE;
+            return true;
         }
 
         /* For Xbox One controllers, Microsoft doesn't propagate the VID/PID down to the HID stack.
          * We'll have to walk the device tree upwards searching for a match for our VID/PID. */
 
-        /* Make sure the device interface string is something we know how to parse */
-        /* Example: \\?\HID#VID_045E&PID_02FF&IG_00#9&2c203035&2&0000#{4d1e55b2-f16f-11cf-88cb-001111000030} */
+        // Make sure the device interface string is something we know how to parse
+        // Example: \\?\HID#VID_045E&PID_02FF&IG_00#9&2c203035&2&0000#{4d1e55b2-f16f-11cf-88cb-001111000030}
         if ((SDL_strstr(devName, "\\\\?\\") != devName) || (SDL_strstr(devName, "#{") == NULL)) {
             continue;
         }
 
-        /* Unescape the backslashes in the string and terminate before the GUID portion */
+        // Unescape the backslashes in the string and terminate before the GUID portion
         for (j = 0; devName[j] != '\0'; j++) {
             if (devName[j] == '#') {
                 if (devName[j + 1] == '{') {
@@ -200,20 +199,20 @@ static SDL_bool SDL_IsXInputDevice(Uint16 vendor, Uint16 product)
 
             if ((CM_Get_Device_IDA(devNode, deviceId, SDL_arraysize(deviceId), 0) == CR_SUCCESS) &&
                 (SDL_strstr(deviceId, devVidPidString) != NULL)) {
-                /* The VID/PID matched a parent device */
+                // The VID/PID matched a parent device
                 SDL_free(raw_devices);
-                return SDL_TRUE;
+                return true;
             }
         }
     }
 
     SDL_free(raw_devices);
-#endif /* SDL_JOYSTICK_XINPUT || SDL_JOYSTICK_RAWINPUT */
+#endif // SDL_JOYSTICK_XINPUT || SDL_JOYSTICK_RAWINPUT
 
-    return SDL_FALSE;
+    return false;
 }
 
-static void WGI_LoadRawGameControllerStatics()
+static void WGI_LoadRawGameControllerStatics(void)
 {
     HRESULT hr;
     HSTRING_HEADER class_name_header;
@@ -228,7 +227,7 @@ static void WGI_LoadRawGameControllerStatics()
     }
 }
 
-static void WGI_LoadOtherControllerStatics()
+static void WGI_LoadOtherControllerStatics(void)
 {
     HRESULT hr;
     HSTRING_HEADER class_name_header;
@@ -334,7 +333,7 @@ static HRESULT STDMETHODCALLTYPE IEventHandler_CRawGameControllerVtbl_QueryInter
         __FIEventHandler_1_Windows__CGaming__CInput__CRawGameController_AddRef(This);
         return S_OK;
     } else if (WIN_IsEqualIID(riid, &IID_IMarshal)) {
-        /* This seems complicated. Let's hope it doesn't happen. */
+        // This seems complicated. Let's hope it doesn't happen.
         return E_OUTOFMEMORY;
     } else {
         return E_NOINTERFACE;
@@ -344,14 +343,14 @@ static HRESULT STDMETHODCALLTYPE IEventHandler_CRawGameControllerVtbl_QueryInter
 static ULONG STDMETHODCALLTYPE IEventHandler_CRawGameControllerVtbl_AddRef(__FIEventHandler_1_Windows__CGaming__CInput__CRawGameController *This)
 {
     RawGameControllerDelegate *self = (RawGameControllerDelegate *)This;
-    return SDL_AtomicAdd(&self->refcount, 1) + 1UL;
+    return SDL_AddAtomicInt(&self->refcount, 1) + 1UL;
 }
 
 static ULONG STDMETHODCALLTYPE IEventHandler_CRawGameControllerVtbl_Release(__FIEventHandler_1_Windows__CGaming__CInput__CRawGameController *This)
 {
     RawGameControllerDelegate *self = (RawGameControllerDelegate *)This;
-    int rc = SDL_AtomicAdd(&self->refcount, -1) - 1;
-    /* Should never free the static delegate objects */
+    int rc = SDL_AddAtomicInt(&self->refcount, -1) - 1;
+    // Should never free the static delegate objects
     SDL_assert(rc > 0);
     return rc;
 }
@@ -391,7 +390,7 @@ static HRESULT STDMETHODCALLTYPE IEventHandler_CRawGameControllerVtbl_InvokeAdde
 
     SDL_LockJoysticks();
 
-    /* We can get delayed calls to InvokeAdded() after WGI_JoystickQuit() */
+    // We can get delayed calls to InvokeAdded() after WGI_JoystickQuit()
     if (SDL_JoysticksQuitting() || !SDL_JoysticksInitialized()) {
         SDL_UnlockJoysticks();
         return S_OK;
@@ -400,7 +399,7 @@ static HRESULT STDMETHODCALLTYPE IEventHandler_CRawGameControllerVtbl_InvokeAdde
     hr = __x_ABI_CWindows_CGaming_CInput_CIRawGameController_QueryInterface(e, &IID___x_ABI_CWindows_CGaming_CInput_CIRawGameController, (void **)&controller);
     if (SUCCEEDED(hr)) {
         char *name = NULL;
-        SDL_JoystickGUID guid = { 0 };
+        SDL_GUID guid = { 0 };
         Uint16 bus = SDL_HARDWARE_BUS_USB;
         Uint16 vendor = 0;
         Uint16 product = 0;
@@ -408,7 +407,7 @@ static HRESULT STDMETHODCALLTYPE IEventHandler_CRawGameControllerVtbl_InvokeAdde
         SDL_JoystickType type = SDL_JOYSTICK_TYPE_UNKNOWN;
         __x_ABI_CWindows_CGaming_CInput_CIRawGameController2 *controller2 = NULL;
         __x_ABI_CWindows_CGaming_CInput_CIGameController *game_controller = NULL;
-        SDL_bool ignore_joystick = SDL_FALSE;
+        bool ignore_joystick = false;
 
         __x_ABI_CWindows_CGaming_CInput_CIRawGameController_get_HardwareVendorId(controller, &vendor);
         __x_ABI_CWindows_CGaming_CInput_CIRawGameController_get_HardwareProductId(controller, &product);
@@ -420,7 +419,7 @@ static HRESULT STDMETHODCALLTYPE IEventHandler_CRawGameControllerVtbl_InvokeAdde
             if (SUCCEEDED(hr) && wireless) {
                 bus = SDL_HARDWARE_BUS_BLUETOOTH;
 
-                /* Fixup for Wireless Xbox 360 Controller */
+                // Fixup for Wireless Xbox 360 Controller
                 if (product == 0) {
                     vendor = USB_VENDOR_MICROSOFT;
                     product = USB_PRODUCT_XBOX360_XUSB_CONTROLLER;
@@ -448,12 +447,12 @@ static HRESULT STDMETHODCALLTYPE IEventHandler_CRawGameControllerVtbl_InvokeAdde
         }
 
         if (!ignore_joystick && SDL_JoystickHandledByAnotherDriver(&SDL_WGI_JoystickDriver, vendor, product, version, name)) {
-            ignore_joystick = SDL_TRUE;
+            ignore_joystick = true;
         }
 
         if (!ignore_joystick && SDL_IsXInputDevice(vendor, product)) {
-            /* This hasn't been detected by the RAWINPUT driver yet, but it will be picked up later. */
-            ignore_joystick = SDL_TRUE;
+            // This hasn't been detected by the RAWINPUT driver yet, but it will be picked up later.
+            ignore_joystick = true;
         }
 
         if (!ignore_joystick) {
@@ -464,12 +463,12 @@ static HRESULT STDMETHODCALLTYPE IEventHandler_CRawGameControllerVtbl_InvokeAdde
             guid = SDL_CreateJoystickGUID(bus, vendor, product, version, NULL, name, 'w', (Uint8)type);
 
             if (SDL_ShouldIgnoreJoystick(name, guid)) {
-                ignore_joystick = SDL_TRUE;
+                ignore_joystick = true;
             }
         }
 
         if (!ignore_joystick) {
-            /* New device, add it */
+            // New device, add it
             WindowsGamingInputControllerState *controllers = SDL_realloc(wgi.controllers, sizeof(wgi.controllers[0]) * (wgi.controller_count + 1));
             if (controllers) {
                 WindowsGamingInputControllerState *state = &controllers[wgi.controller_count];
@@ -511,7 +510,7 @@ static HRESULT STDMETHODCALLTYPE IEventHandler_CRawGameControllerVtbl_InvokeRemo
 
     SDL_LockJoysticks();
 
-    /* Can we get delayed calls to InvokeRemoved() after WGI_JoystickQuit()? */
+    // Can we get delayed calls to InvokeRemoved() after WGI_JoystickQuit()?
     if (!SDL_JoysticksInitialized()) {
         SDL_UnlockJoysticks();
         return S_OK;
@@ -550,8 +549,8 @@ static HRESULT STDMETHODCALLTYPE IEventHandler_CRawGameControllerVtbl_InvokeRemo
 
 #ifdef _MSC_VER
 #pragma warning(push)
-#pragma warning(disable : 4028) /* formal parameter 3 different from declaration, when using older buggy WGI headers */
-#pragma warning(disable : 4113) /* formal parameter 3 different from declaration (a more specific warning added in VS 2022), when using older buggy WGI headers */
+#pragma warning(disable : 4028) // formal parameter 3 different from declaration, when using older buggy WGI headers
+#pragma warning(disable : 4113) // formal parameter 3 different from declaration (a more specific warning added in VS 2022), when using older buggy WGI headers
 #endif
 
 static __FIEventHandler_1_Windows__CGaming__CInput__CRawGameControllerVtbl controller_added_vtbl = {
@@ -580,25 +579,18 @@ static RawGameControllerDelegate controller_removed = {
 #pragma warning(pop)
 #endif
 
-static int WGI_JoystickInit(void)
+static bool WGI_JoystickInit(void)
 {
     HRESULT hr;
 
-    if (!SDL_GetHintBoolean(SDL_HINT_JOYSTICK_WGI, SDL_TRUE)) {
-        return 0;
+    if (!SDL_GetHintBoolean(SDL_HINT_JOYSTICK_WGI, true)) {
+        return true;
     }
 
     if (FAILED(WIN_RoInitialize())) {
         return SDL_SetError("RoInitialize() failed");
     }
 
-#ifdef SDL_PLATFORM_WINRT
-    wgi.CoIncrementMTAUsage = CoIncrementMTAUsage;
-    wgi.RoGetActivationFactory = RoGetActivationFactory;
-    wgi.WindowsCreateStringReference = WindowsCreateStringReference;
-    wgi.WindowsDeleteString = WindowsDeleteString;
-    wgi.WindowsGetStringRawBuffer = WindowsGetStringRawBuffer;
-#else
 #define RESOLVE(x) wgi.x = (x##_t)WIN_LoadComBaseFunction(#x); if (!wgi.x) return WIN_SetError("GetProcAddress failed for " #x);
     RESOLVE(CoIncrementMTAUsage);
     RESOLVE(RoGetActivationFactory);
@@ -606,9 +598,7 @@ static int WGI_JoystickInit(void)
     RESOLVE(WindowsDeleteString);
     RESOLVE(WindowsGetStringRawBuffer);
 #undef RESOLVE
-#endif /* SDL_PLATFORM_WINRT */
 
-#ifndef SDL_PLATFORM_WINRT
     {
         /* There seems to be a bug in Windows where a dependency of WGI can be unloaded from memory prior to WGI itself.
          * This results in Windows_Gaming_Input!GameController::~GameController() invoking an unloaded DLL and crashing.
@@ -623,7 +613,6 @@ static int WGI_JoystickInit(void)
             }
         }
     }
-#endif
 
     WGI_LoadRawGameControllerStatics();
 
@@ -661,7 +650,7 @@ static int WGI_JoystickInit(void)
         }
     }
 
-    return 0;
+    return true;
 }
 
 static int WGI_JoystickGetCount(void)
@@ -673,10 +662,10 @@ static void WGI_JoystickDetect(void)
 {
 }
 
-static SDL_bool WGI_JoystickIsDevicePresent(Uint16 vendor_id, Uint16 product_id, Uint16 version, const char *name)
+static bool WGI_JoystickIsDevicePresent(Uint16 vendor_id, Uint16 product_id, Uint16 version, const char *name)
 {
-    /* We don't override any other drivers */
-    return SDL_FALSE;
+    // We don't override any other drivers
+    return false;
 }
 
 static const char *WGI_JoystickGetDeviceName(int device_index)
@@ -696,14 +685,14 @@ static int WGI_JoystickGetDeviceSteamVirtualGamepadSlot(int device_index)
 
 static int WGI_JoystickGetDevicePlayerIndex(int device_index)
 {
-    return -1;
+    return false;
 }
 
 static void WGI_JoystickSetDevicePlayerIndex(int device_index, int player_index)
 {
 }
 
-static SDL_JoystickGUID WGI_JoystickGetDeviceGUID(int device_index)
+static SDL_GUID WGI_JoystickGetDeviceGUID(int device_index)
 {
     return wgi.controllers[device_index].guid;
 }
@@ -713,15 +702,15 @@ static SDL_JoystickID WGI_JoystickGetDeviceInstanceID(int device_index)
     return wgi.controllers[device_index].instance_id;
 }
 
-static int WGI_JoystickOpen(SDL_Joystick *joystick, int device_index)
+static bool WGI_JoystickOpen(SDL_Joystick *joystick, int device_index)
 {
     WindowsGamingInputControllerState *state = &wgi.controllers[device_index];
     struct joystick_hwdata *hwdata;
-    boolean wireless = SDL_FALSE;
+    boolean wireless = false;
 
     hwdata = (struct joystick_hwdata *)SDL_calloc(1, sizeof(*hwdata));
     if (!hwdata) {
-        return -1;
+        return false;
     }
     joystick->hwdata = hwdata;
 
@@ -738,7 +727,7 @@ static int WGI_JoystickOpen(SDL_Joystick *joystick, int device_index)
         __x_ABI_CWindows_CGaming_CInput_CIGameController_get_IsWireless(hwdata->game_controller, &wireless);
     }
 
-    /* Initialize the joystick capabilities */
+    // Initialize the joystick capabilities
     if (wireless) {
         joystick->connection_state = SDL_JOYSTICK_CONNECTION_WIRELESS;
     } else {
@@ -749,26 +738,26 @@ static int WGI_JoystickOpen(SDL_Joystick *joystick, int device_index)
     __x_ABI_CWindows_CGaming_CInput_CIRawGameController_get_SwitchCount(hwdata->controller, &joystick->nhats);
 
     if (hwdata->gamepad) {
-        /* FIXME: Can WGI even tell us if trigger rumble is supported? */
-        SDL_SetBooleanProperty(SDL_GetJoystickProperties(joystick), SDL_PROP_JOYSTICK_CAP_RUMBLE_BOOLEAN, SDL_TRUE);
-        SDL_SetBooleanProperty(SDL_GetJoystickProperties(joystick), SDL_PROP_JOYSTICK_CAP_TRIGGER_RUMBLE_BOOLEAN, SDL_TRUE);
+        // FIXME: Can WGI even tell us if trigger rumble is supported?
+        SDL_SetBooleanProperty(SDL_GetJoystickProperties(joystick), SDL_PROP_JOYSTICK_CAP_RUMBLE_BOOLEAN, true);
+        SDL_SetBooleanProperty(SDL_GetJoystickProperties(joystick), SDL_PROP_JOYSTICK_CAP_TRIGGER_RUMBLE_BOOLEAN, true);
     }
-    return 0;
+    return true;
 }
 
-static int WGI_JoystickRumble(SDL_Joystick *joystick, Uint16 low_frequency_rumble, Uint16 high_frequency_rumble)
+static bool WGI_JoystickRumble(SDL_Joystick *joystick, Uint16 low_frequency_rumble, Uint16 high_frequency_rumble)
 {
     struct joystick_hwdata *hwdata = joystick->hwdata;
 
     if (hwdata->gamepad) {
         HRESULT hr;
 
-        /* Note: reusing partially filled vibration data struct */
+        // Note: reusing partially filled vibration data struct
         hwdata->vibration.LeftMotor = (DOUBLE)low_frequency_rumble / SDL_MAX_UINT16;
         hwdata->vibration.RightMotor = (DOUBLE)high_frequency_rumble / SDL_MAX_UINT16;
         hr = __x_ABI_CWindows_CGaming_CInput_CIGamepad_put_Vibration(hwdata->gamepad, hwdata->vibration);
         if (SUCCEEDED(hr)) {
-            return 0;
+            return true;
         } else {
             return WIN_SetErrorFromHRESULT("Windows.Gaming.Input.IGamepad.put_Vibration failed", hr);
         }
@@ -777,19 +766,19 @@ static int WGI_JoystickRumble(SDL_Joystick *joystick, Uint16 low_frequency_rumbl
     }
 }
 
-static int WGI_JoystickRumbleTriggers(SDL_Joystick *joystick, Uint16 left_rumble, Uint16 right_rumble)
+static bool WGI_JoystickRumbleTriggers(SDL_Joystick *joystick, Uint16 left_rumble, Uint16 right_rumble)
 {
     struct joystick_hwdata *hwdata = joystick->hwdata;
 
     if (hwdata->gamepad) {
         HRESULT hr;
 
-        /* Note: reusing partially filled vibration data struct */
+        // Note: reusing partially filled vibration data struct
         hwdata->vibration.LeftTrigger = (DOUBLE)left_rumble / SDL_MAX_UINT16;
         hwdata->vibration.RightTrigger = (DOUBLE)right_rumble / SDL_MAX_UINT16;
         hr = __x_ABI_CWindows_CGaming_CInput_CIGamepad_put_Vibration(hwdata->gamepad, hwdata->vibration);
         if (SUCCEEDED(hr)) {
-            return 0;
+            return true;
         } else {
             return WIN_SetErrorFromHRESULT("Windows.Gaming.Input.IGamepad.put_Vibration failed", hr);
         }
@@ -798,17 +787,17 @@ static int WGI_JoystickRumbleTriggers(SDL_Joystick *joystick, Uint16 left_rumble
     }
 }
 
-static int WGI_JoystickSetLED(SDL_Joystick *joystick, Uint8 red, Uint8 green, Uint8 blue)
+static bool WGI_JoystickSetLED(SDL_Joystick *joystick, Uint8 red, Uint8 green, Uint8 blue)
 {
     return SDL_Unsupported();
 }
 
-static int WGI_JoystickSendEffect(SDL_Joystick *joystick, const void *data, int size)
+static bool WGI_JoystickSendEffect(SDL_Joystick *joystick, const void *data, int size)
 {
     return SDL_Unsupported();
 }
 
-static int WGI_JoystickSetSensorsEnabled(SDL_Joystick *joystick, SDL_bool enabled)
+static bool WGI_JoystickSetSensorsEnabled(SDL_Joystick *joystick, bool enabled)
 {
     return SDL_Unsupported();
 }
@@ -862,16 +851,16 @@ static void WGI_JoystickUpdate(SDL_Joystick *joystick)
     hr = __x_ABI_CWindows_CGaming_CInput_CIRawGameController_GetCurrentReading(hwdata->controller, nbuttons, buttons, nhats, hats, naxes, axes, &timestamp);
     if (SUCCEEDED(hr) && (!timestamp || timestamp != hwdata->timestamp)) {
         UINT32 i;
-        SDL_bool all_zero = SDL_FALSE;
+        bool all_zero = false;
 
         hwdata->timestamp = timestamp;
 
-        /* The axes are all zero when the application loses focus */
+        // The axes are all zero when the application loses focus
         if (naxes > 0) {
-            all_zero = SDL_TRUE;
+            all_zero = true;
             for (i = 0; i < naxes; ++i) {
                 if (axes[i] != 0.0f) {
-                    all_zero = SDL_FALSE;
+                    all_zero = false;
                     break;
                 }
             }
@@ -879,7 +868,7 @@ static void WGI_JoystickUpdate(SDL_Joystick *joystick)
         if (all_zero) {
             SDL_PrivateJoystickForceRecentering(joystick);
         } else {
-            /* FIXME: What units are the timestamp we get from GetCurrentReading()? */
+            // FIXME: What units are the timestamp we get from GetCurrentReading()?
             timestamp = SDL_GetTicksNS();
             for (i = 0; i < nbuttons; ++i) {
                 SDL_SendJoystickButton(timestamp, joystick, (Uint8)i, buttons[i]);
@@ -1016,9 +1005,9 @@ static void WGI_JoystickQuit(void)
     SDL_zero(wgi);
 }
 
-static SDL_bool WGI_JoystickGetGamepadMapping(int device_index, SDL_GamepadMapping *out)
+static bool WGI_JoystickGetGamepadMapping(int device_index, SDL_GamepadMapping *out)
 {
-    return SDL_FALSE;
+    return false;
 }
 
 SDL_JoystickDriver SDL_WGI_JoystickDriver = {
@@ -1045,4 +1034,4 @@ SDL_JoystickDriver SDL_WGI_JoystickDriver = {
     WGI_JoystickGetGamepadMapping
 };
 
-#endif /* SDL_JOYSTICK_WGI */
+#endif // SDL_JOYSTICK_WGI
