@@ -26,8 +26,8 @@
 
 EM_JS_DEPS(sdlsysurl, "$UTF8ToString");
 
-int SDL_SYS_OpenURL(const char *url)
+bool SDL_SYS_OpenURL(const char *url)
 {
     EM_ASM(window.open(UTF8ToString($0), "_blank"), url);
-    return 0;
+    return true;
 }
