@@ -36,7 +36,7 @@
 #include <unistd.h>
 
 #include "../../core/linux/SDL_dbus.h"
-#endif /* SDL_PLATFORM_LINUX */
+#endif // SDL_PLATFORM_LINUX
 
 #if (defined(SDL_PLATFORM_LINUX) || defined(SDL_PLATFORM_MACOS) || defined(SDL_PLATFORM_IOS)) && defined(HAVE_DLOPEN)
 #include <dlfcn.h>
@@ -55,7 +55,7 @@
 #include <kernel/OS.h>
 #endif
 
-/* List of signals to mask in the subthreads */
+// List of signals to mask in the subthreads
 static const int sig_list[] = {
     SIGHUP, SIGINT, SIGQUIT, SIGPIPE, SIGALRM, SIGTERM, SIGCHLD, SIGWINCH,
     SIGVTALRM, SIGPROF, 0
@@ -71,17 +71,19 @@ static void *RunThread(void *data)
 }
 
 #if (defined(SDL_PLATFORM_MACOS) || defined(SDL_PLATFORM_IOS)) && defined(HAVE_DLOPEN)
-static SDL_bool checked_setname = SDL_FALSE;
+static bool checked_setname = false;
 static int (*ppthread_setname_np)(const char *) = NULL;
 #elif defined(SDL_PLATFORM_LINUX) && defined(HAVE_DLOPEN)
-static SDL_bool checked_setname = SDL_FALSE;
+static bool checked_setname = false;
 static int (*ppthread_setname_np)(pthread_t, const char *) = NULL;
 #endif
-int SDL_SYS_CreateThread(SDL_Thread *thread)
+bool SDL_SYS_CreateThread(SDL_Thread *thread,
+                          SDL_FunctionPointer pfnBeginThread,
+                          SDL_FunctionPointer pfnEndThread)
 {
     pthread_attr_t type;
 
-/* do this here before any threads exist, so there's no race condition. */
+// do this here before any threads exist, so there's no race condition.
 #if (defined(SDL_PLATFORM_MACOS) || defined(SDL_PLATFORM_IOS) || defined(SDL_PLATFORM_LINUX)) && defined(HAVE_DLOPEN)
     if (!checked_setname) {
         void *fn = dlsym(RTLD_DEFAULT, "pthread_setname_np");
@@ -90,27 +92,27 @@ int SDL_SYS_CreateThread(SDL_Thread *thread)
 #elif defined(SDL_PLATFORM_LINUX)
         ppthread_setname_np = (int (*)(pthread_t, const char *))fn;
 #endif
-        checked_setname = SDL_TRUE;
+        checked_setname = true;
     }
 #endif
 
-    /* Set the thread attributes */
+    // Set the thread attributes
     if (pthread_attr_init(&type) != 0) {
         return SDL_SetError("Couldn't initialize pthread attributes");
     }
     pthread_attr_setdetachstate(&type, PTHREAD_CREATE_JOINABLE);
 
-    /* Set caller-requested stack size. Otherwise: use the system default. */
+    // Set caller-requested stack size. Otherwise: use the system default.
     if (thread->stacksize) {
         pthread_attr_setstacksize(&type, thread->stacksize);
     }
 
-    /* Create the thread and go! */
+    // Create the thread and go!
     if (pthread_create(&thread->handle, &type, RunThread, thread) != 0) {
         return SDL_SetError("Not enough resources to create thread");
     }
 
-    return 0;
+    return true;
 }
 
 void SDL_SYS_SetupThread(const char *name)
@@ -126,7 +128,7 @@ void SDL_SYS_SetupThread(const char *name)
             ppthread_setname_np(name);
 #elif defined(SDL_PLATFORM_LINUX)
             if (ppthread_setname_np(pthread_self(), name) == ERANGE) {
-                char namebuf[16]; /* Limited to 16 char */
+                char namebuf[16]; // Limited to 16 char
                 SDL_strlcpy(namebuf, name, sizeof(namebuf));
                 ppthread_setname_np(pthread_self(), namebuf);
             }
@@ -137,7 +139,7 @@ void SDL_SYS_SetupThread(const char *name)
         pthread_setname_np(pthread_self(), "%s", name);
 #else
         if (pthread_setname_np(pthread_self(), name) == ERANGE) {
-            char namebuf[16]; /* Limited to 16 char */
+            char namebuf[16]; // Limited to 16 char
             SDL_strlcpy(namebuf, name, sizeof(namebuf));
             pthread_setname_np(pthread_self(), namebuf);
         }
@@ -145,14 +147,14 @@ void SDL_SYS_SetupThread(const char *name)
 #elif defined(HAVE_PTHREAD_SET_NAME_NP)
         pthread_set_name_np(pthread_self(), name);
 #elif defined(SDL_PLATFORM_HAIKU)
-        /* The docs say the thread name can't be longer than B_OS_NAME_LENGTH. */
+        // The docs say the thread name can't be longer than B_OS_NAME_LENGTH.
         char namebuf[B_OS_NAME_LENGTH];
         SDL_strlcpy(namebuf, name, sizeof(namebuf));
         rename_thread(find_thread(NULL), namebuf);
 #endif
     }
 
-    /* Mask asynchronous signals for this thread */
+    // Mask asynchronous signals for this thread
     sigemptyset(&mask);
     for (i = 0; sig_list[i]; ++i) {
         sigaddset(&mask, sig_list[i]);
@@ -160,7 +162,7 @@ void SDL_SYS_SetupThread(const char *name)
     pthread_sigmask(SIG_BLOCK, &mask, 0);
 
 #ifdef PTHREAD_CANCEL_ASYNCHRONOUS
-    /* Allow ourselves to be asynchronously cancelled */
+    // Allow ourselves to be asynchronously cancelled
     {
         int oldstate;
         pthread_setcanceltype(PTHREAD_CANCEL_ASYNCHRONOUS, &oldstate);
@@ -173,18 +175,18 @@ SDL_ThreadID SDL_GetCurrentThreadID(void)
     return (SDL_ThreadID)pthread_self();
 }
 
-int SDL_SYS_SetThreadPriority(SDL_ThreadPriority priority)
+bool SDL_SYS_SetThreadPriority(SDL_ThreadPriority priority)
 {
 #ifdef SDL_PLATFORM_RISCOS
-    /* FIXME: Setting thread priority does not seem to be supported */
-    return 0;
+    // FIXME: Setting thread priority does not seem to be supported
+    return true;
 #else
     struct sched_param sched;
     int policy;
     int pri_policy;
     pthread_t thread = pthread_self();
     const char *policyhint = SDL_GetHint(SDL_HINT_THREAD_PRIORITY_POLICY);
-    const SDL_bool timecritical_realtime_hint = SDL_GetHintBoolean(SDL_HINT_THREAD_FORCE_REALTIME_TIME_CRITICAL, SDL_FALSE);
+    const bool timecritical_realtime_hint = SDL_GetHintBoolean(SDL_HINT_THREAD_FORCE_REALTIME_TIME_CRITICAL, false);
 
     if (pthread_getschedparam(thread, &policy, &sched) != 0) {
         return SDL_SetError("pthread_getschedparam() failed");
@@ -201,7 +203,7 @@ int SDL_SYS_SetThreadPriority(SDL_ThreadPriority priority)
     case SDL_THREAD_PRIORITY_HIGH:
     case SDL_THREAD_PRIORITY_TIME_CRITICAL:
 #if defined(SDL_PLATFORM_MACOS) || defined(SDL_PLATFORM_IOS) || defined(SDL_PLATFORM_TVOS)
-        /* Apple requires SCHED_RR for high priority threads */
+        // Apple requires SCHED_RR for high priority threads
         pri_policy = SCHED_RR;
         break;
 #else
@@ -219,7 +221,7 @@ int SDL_SYS_SetThreadPriority(SDL_ThreadPriority priority)
 
     if (policyhint) {
         if (SDL_strcmp(policyhint, "current") == 0) {
-            /* Leave current thread scheduler policy unchanged */
+            // Leave current thread scheduler policy unchanged
         } else if (SDL_strcmp(policyhint, "other") == 0) {
             policy = SCHED_OTHER;
         } else if (SDL_strcmp(policyhint, "rr") == 0) {
@@ -236,7 +238,7 @@ int SDL_SYS_SetThreadPriority(SDL_ThreadPriority priority)
 #ifdef SDL_PLATFORM_LINUX
     {
         pid_t linuxTid = syscall(SYS_gettid);
-        return SDL_LinuxSetThreadPriorityAndPolicy(linuxTid, priority, policy);
+        return SDL_SetLinuxThreadPriorityAndPolicy(linuxTid, priority, policy);
     }
 #else
     if (priority == SDL_THREAD_PRIORITY_LOW) {
@@ -249,14 +251,14 @@ int SDL_SYS_SetThreadPriority(SDL_ThreadPriority priority)
 
 #if defined(SDL_PLATFORM_MACOS) || defined(SDL_PLATFORM_IOS) || defined(SDL_PLATFORM_TVOS)
         if (min_priority == 15 && max_priority == 47) {
-            /* Apple has a specific set of thread priorities */
+            // Apple has a specific set of thread priorities
             if (priority == SDL_THREAD_PRIORITY_HIGH) {
                 sched.sched_priority = 45;
             } else {
                 sched.sched_priority = 37;
             }
         } else
-#endif /* SDL_PLATFORM_MACOS || SDL_PLATFORM_IOS || SDL_PLATFORM_TVOS */
+#endif // SDL_PLATFORM_MACOS || SDL_PLATFORM_IOS || SDL_PLATFORM_TVOS
         {
             sched.sched_priority = (min_priority + (max_priority - min_priority) / 2);
             if (priority == SDL_THREAD_PRIORITY_HIGH) {
@@ -267,9 +269,9 @@ int SDL_SYS_SetThreadPriority(SDL_ThreadPriority priority)
     if (pthread_setschedparam(thread, policy, &sched) != 0) {
         return SDL_SetError("pthread_setschedparam() failed");
     }
-    return 0;
-#endif /* linux */
-#endif /* #if SDL_PLATFORM_RISCOS */
+    return true;
+#endif // linux
+#endif // #if SDL_PLATFORM_RISCOS
 }
 
 void SDL_SYS_WaitThread(SDL_Thread *thread)
