@@ -62,7 +62,7 @@
  *
  * Encoding of surfaces with per-pixel alpha:
  *
- *   The sequence begins with a struct RLEDestFormat describing the target
+ *   The sequence begins with an SDL_PixelFormat value describing the target
  *   pixel format, to provide reliable un-encoding.
  *
  *   Each scan line is encoded twice: First all completely opaque pixels,
@@ -88,7 +88,7 @@
  */
 
 #include "SDL_sysvideo.h"
-#include "SDL_blit.h"
+#include "SDL_surface_c.h"
 #include "SDL_RLEaccel_c.h"
 
 #define PIXEL_COPY(to, from, len, bpp) \
@@ -251,7 +251,7 @@
  * care to shift before we add, not after.
  */
 
-/* helper: blend a single 16 bit pixel at 50% */
+// helper: blend a single 16 bit pixel at 50%
 #define BLEND16_50(dst, src, mask)                           \
     do {                                                     \
         Uint32 s = *src++;                                   \
@@ -260,7 +260,7 @@
                           (s & d & (~mask & 0xffff)));       \
     } while (0)
 
-/* basic 16bpp blender. mask is the pixels to keep when adding. */
+// basic 16bpp blender. mask is the pixels to keep when adding.
 #define ALPHA_BLIT16_50(to, from, length, bpp, alpha, mask)                                                                              \
     do {                                                                                                                                 \
         unsigned n = (length);                                                                                                           \
@@ -375,9 +375,9 @@
  */
 #define RLEPIXEL_FROM_RGBA(Pixel, fmt, r, g, b, a)   \
     {                                                \
-        Pixel = ((r >> fmt->Rloss) << fmt->Rshift) | \
-                ((g >> fmt->Gloss) << fmt->Gshift) | \
-                ((b >> fmt->Bloss) << fmt->Bshift) | \
+        Pixel = ((r >> (8 - fmt->Rbits)) << fmt->Rshift) | \
+                ((g >> (8 - fmt->Gbits)) << fmt->Gshift) | \
+                ((b >> (8 - fmt->Bbits)) << fmt->Bshift) | \
                 (a << 24);                           \
     }
 
@@ -434,16 +434,16 @@
 static void RLEClipBlit(int w, Uint8 *srcbuf, SDL_Surface *surf_dst,
                         Uint8 *dstbuf, const SDL_Rect *srcrect, unsigned alpha)
 {
-    SDL_PixelFormat *fmt = surf_dst->format;
+    const SDL_PixelFormatDetails *fmt = surf_dst->fmt;
 
     CHOOSE_BLIT(RLECLIPBLIT, alpha, fmt);
 }
 
 #undef RLECLIPBLIT
 
-/* blit a colorkeyed RLE surface */
-static int SDLCALL SDL_RLEBlit(SDL_Surface *surf_src, const SDL_Rect *srcrect,
-                               SDL_Surface *surf_dst, const SDL_Rect *dstrect)
+// blit a colorkeyed RLE surface
+static bool SDLCALL SDL_RLEBlit(SDL_Surface *surf_src, const SDL_Rect *srcrect,
+                                SDL_Surface *surf_dst, const SDL_Rect *dstrect)
 {
     Uint8 *dstbuf;
     Uint8 *srcbuf;
@@ -451,21 +451,21 @@ static int SDLCALL SDL_RLEBlit(SDL_Surface *surf_src, const SDL_Rect *srcrect,
     int w = surf_src->w;
     unsigned alpha;
 
-    /* Lock the destination if necessary */
+    // Lock the destination if necessary
     if (SDL_MUSTLOCK(surf_dst)) {
-        if (SDL_LockSurface(surf_dst) < 0) {
-            return -1;
+        if (!SDL_LockSurface(surf_dst)) {
+            return false;
         }
     }
 
-    /* Set up the source and destination pointers */
+    // Set up the source and destination pointers
     x = dstrect->x;
     y = dstrect->y;
-    dstbuf = (Uint8 *)surf_dst->pixels + y * surf_dst->pitch + x * surf_src->format->bytes_per_pixel;
-    srcbuf = (Uint8 *)surf_src->map->data;
+    dstbuf = (Uint8 *)surf_dst->pixels + y * surf_dst->pitch + x * surf_src->fmt->bytes_per_pixel;
+    srcbuf = (Uint8 *)surf_src->map.data + sizeof(SDL_PixelFormat);
 
     {
-        /* skip lines at the top if necessary */
+        // skip lines at the top if necessary
         int vskip = srcrect->y;
         int ofs = 0;
         if (vskip) {
@@ -488,7 +488,7 @@ static int SDLCALL SDL_RLEBlit(SDL_Surface *surf_src, const SDL_Rect *srcrect,
         }                           \
     }
 
-            switch (surf_src->format->bytes_per_pixel) {
+            switch (surf_src->fmt->bytes_per_pixel) {
             case 1:
                 RLESKIP(1, Uint8);
                 break;
@@ -507,12 +507,12 @@ static int SDLCALL SDL_RLEBlit(SDL_Surface *surf_src, const SDL_Rect *srcrect,
         }
     }
 
-    alpha = surf_src->map->info.a;
-    /* if left or right edge clipping needed, call clip blit */
+    alpha = surf_src->map.info.a;
+    // if left or right edge clipping needed, call clip blit
     if (srcrect->x || srcrect->w != surf_src->w) {
         RLEClipBlit(w, srcbuf, surf_dst, dstbuf, srcrect, alpha);
     } else {
-        SDL_PixelFormat *fmt = surf_src->format;
+        const SDL_PixelFormatDetails *fmt = surf_src->fmt;
 
 #define RLEBLIT(bpp, Type, do_blit)                                   \
     do {                                                              \
@@ -544,11 +544,11 @@ static int SDLCALL SDL_RLEBlit(SDL_Surface *surf_src, const SDL_Rect *srcrect,
     }
 
 done:
-    /* Unlock the destination if necessary */
+    // Unlock the destination if necessary
     if (SDL_MUSTLOCK(surf_dst)) {
         SDL_UnlockSurface(surf_dst);
     }
-    return 0;
+    return true;
 }
 
 #undef OPAQUE_BLIT
@@ -604,31 +604,11 @@ done:
         dst = (Uint16)(d | d >> 16);       \
     } while (0)
 
-/* used to save the destination format in the encoding. Designed to be
-   macro-compatible with SDL_PixelFormat but without the unneeded fields */
-typedef struct
-{
-    Uint8 bytes_per_pixel;
-    Uint8 padding[3];
-    Uint32 Rmask;
-    Uint32 Gmask;
-    Uint32 Bmask;
-    Uint32 Amask;
-    Uint8 Rloss;
-    Uint8 Gloss;
-    Uint8 Bloss;
-    Uint8 Aloss;
-    Uint8 Rshift;
-    Uint8 Gshift;
-    Uint8 Bshift;
-    Uint8 Ashift;
-} RLEDestFormat;
-
-/* blit a pixel-alpha RLE surface clipped at the right and/or left edges */
+// blit a pixel-alpha RLE surface clipped at the right and/or left edges
 static void RLEAlphaClipBlit(int w, Uint8 *srcbuf, SDL_Surface *surf_dst,
                              Uint8 *dstbuf, const SDL_Rect *srcrect)
 {
-    SDL_PixelFormat *df = surf_dst->format;
+    const SDL_PixelFormatDetails *df = surf_dst->fmt;
     /*
      * clipped blitter: Ptype is the destination pixel type,
      * Ctype the translucent count type, and do_blend the macro
@@ -716,36 +696,36 @@ static void RLEAlphaClipBlit(int w, Uint8 *srcbuf, SDL_Surface *surf_dst,
     }
 }
 
-/* blit a pixel-alpha RLE surface */
-static int SDLCALL SDL_RLEAlphaBlit(SDL_Surface *surf_src, const SDL_Rect *srcrect,
-                                    SDL_Surface *surf_dst, const SDL_Rect *dstrect)
+// blit a pixel-alpha RLE surface
+static bool SDLCALL SDL_RLEAlphaBlit(SDL_Surface *surf_src, const SDL_Rect *srcrect,
+                                     SDL_Surface *surf_dst, const SDL_Rect *dstrect)
 {
     int x, y;
     int w = surf_src->w;
     Uint8 *srcbuf, *dstbuf;
-    SDL_PixelFormat *df = surf_dst->format;
+    const SDL_PixelFormatDetails *df = surf_dst->fmt;
 
-    /* Lock the destination if necessary */
+    // Lock the destination if necessary
     if (SDL_MUSTLOCK(surf_dst)) {
-        if (SDL_LockSurface(surf_dst) < 0) {
-            return -1;
+        if (!SDL_LockSurface(surf_dst)) {
+            return false;
         }
     }
 
     x = dstrect->x;
     y = dstrect->y;
     dstbuf = (Uint8 *)surf_dst->pixels + y * surf_dst->pitch + x * df->bytes_per_pixel;
-    srcbuf = (Uint8 *)surf_src->map->data + sizeof(RLEDestFormat);
+    srcbuf = (Uint8 *)surf_src->map.data + sizeof(SDL_PixelFormat);
 
     {
-        /* skip lines at the top if necessary */
+        // skip lines at the top if necessary
         int vskip = srcrect->y;
         if (vskip) {
             int ofs;
             if (df->bytes_per_pixel == 2) {
-                /* the 16/32 interleaved format */
+                // the 16/32 interleaved format
                 do {
-                    /* skip opaque line */
+                    // skip opaque line
                     ofs = 0;
                     do {
                         int run;
@@ -760,10 +740,10 @@ static int SDLCALL SDL_RLEAlphaBlit(SDL_Surface *surf_src, const SDL_Rect *srcre
                         }
                     } while (ofs < w);
 
-                    /* skip padding */
+                    // skip padding
                     srcbuf += (uintptr_t)srcbuf & 2;
 
-                    /* skip translucent line */
+                    // skip translucent line
                     ofs = 0;
                     do {
                         int run;
@@ -774,8 +754,8 @@ static int SDLCALL SDL_RLEAlphaBlit(SDL_Surface *surf_src, const SDL_Rect *srcre
                     } while (ofs < w);
                 } while (--vskip);
             } else {
-                /* the 32/32 interleaved format */
-                vskip <<= 1; /* opaque and translucent have same format */
+                // the 32/32 interleaved format
+                vskip <<= 1; // opaque and translucent have same format
                 do {
                     ofs = 0;
                     do {
@@ -795,7 +775,7 @@ static int SDLCALL SDL_RLEAlphaBlit(SDL_Surface *surf_src, const SDL_Rect *srcre
         }
     }
 
-    /* if left or right edge clipping needed, call clip blit */
+    // if left or right edge clipping needed, call clip blit
     if (srcrect->x || srcrect->w != surf_src->w) {
         RLEAlphaClipBlit(w, srcbuf, surf_dst, dstbuf, srcrect);
     } else {
@@ -865,11 +845,11 @@ static int SDLCALL SDL_RLEAlphaBlit(SDL_Surface *surf_src, const SDL_Rect *srcre
     }
 
 done:
-    /* Unlock the destination if necessary */
+    // Unlock the destination if necessary
     if (SDL_MUSTLOCK(surf_dst)) {
         SDL_UnlockSurface(surf_dst);
     }
-    return 0;
+    return true;
 }
 
 /*
@@ -882,9 +862,9 @@ done:
  * highly optimised.
  */
 
-/* encode 32bpp rgb + a into 16bpp rgb, losing alpha */
+// encode 32bpp rgb + a into 16bpp rgb, losing alpha
 static int copy_opaque_16(void *dst, const Uint32 *src, int n,
-                          SDL_PixelFormat *sfmt, SDL_PixelFormat *dfmt)
+                          const SDL_PixelFormatDetails *sfmt, const SDL_PixelFormatDetails *dfmt)
 {
     int i;
     Uint16 *d = (Uint16 *)dst;
@@ -898,9 +878,9 @@ static int copy_opaque_16(void *dst, const Uint32 *src, int n,
     return n * 2;
 }
 
-/* decode opaque pixels from 16bpp to 32bpp rgb + a */
+// decode opaque pixels from 16bpp to 32bpp rgb + a
 static int uncopy_opaque_16(Uint32 *dst, const void *src, int n,
-                            RLEDestFormat *sfmt, SDL_PixelFormat *dfmt)
+                            const SDL_PixelFormatDetails *sfmt, const SDL_PixelFormatDetails *dfmt)
 {
     int i;
     const Uint16 *s = (const Uint16 *)src;
@@ -915,9 +895,9 @@ static int uncopy_opaque_16(Uint32 *dst, const void *src, int n,
     return n * 2;
 }
 
-/* encode 32bpp rgb + a into 32bpp G0RAB format for blitting into 565 */
+// encode 32bpp rgb + a into 32bpp G0RAB format for blitting into 565
 static int copy_transl_565(void *dst, const Uint32 *src, int n,
-                           SDL_PixelFormat *sfmt, SDL_PixelFormat *dfmt)
+                           const SDL_PixelFormatDetails *sfmt, const SDL_PixelFormatDetails *dfmt)
 {
     int i;
     Uint32 *d = (Uint32 *)dst;
@@ -933,9 +913,9 @@ static int copy_transl_565(void *dst, const Uint32 *src, int n,
     return n * 4;
 }
 
-/* encode 32bpp rgb + a into 32bpp G0RAB format for blitting into 555 */
+// encode 32bpp rgb + a into 32bpp G0RAB format for blitting into 555
 static int copy_transl_555(void *dst, const Uint32 *src, int n,
-                           SDL_PixelFormat *sfmt, SDL_PixelFormat *dfmt)
+                           const SDL_PixelFormatDetails *sfmt, const SDL_PixelFormatDetails *dfmt)
 {
     int i;
     Uint32 *d = (Uint32 *)dst;
@@ -951,9 +931,9 @@ static int copy_transl_555(void *dst, const Uint32 *src, int n,
     return n * 4;
 }
 
-/* decode translucent pixels from 32bpp GORAB to 32bpp rgb + a */
+// decode translucent pixels from 32bpp GORAB to 32bpp rgb + a
 static int uncopy_transl_16(Uint32 *dst, const void *src, int n,
-                            RLEDestFormat *sfmt, SDL_PixelFormat *dfmt)
+                            const SDL_PixelFormatDetails *sfmt, const SDL_PixelFormatDetails *dfmt)
 {
     int i;
     const Uint32 *s = (const Uint32 *)src;
@@ -969,9 +949,9 @@ static int uncopy_transl_16(Uint32 *dst, const void *src, int n,
     return n * 4;
 }
 
-/* encode 32bpp rgba into 32bpp rgba, keeping alpha (dual purpose) */
+// encode 32bpp rgba into 32bpp rgba, keeping alpha (dual purpose)
 static int copy_32(void *dst, const Uint32 *src, int n,
-                   SDL_PixelFormat *sfmt, SDL_PixelFormat *dfmt)
+                   const SDL_PixelFormatDetails *sfmt, const SDL_PixelFormatDetails *dfmt)
 {
     int i;
     Uint32 *d = (Uint32 *)dst;
@@ -985,9 +965,9 @@ static int copy_32(void *dst, const Uint32 *src, int n,
     return n * 4;
 }
 
-/* decode 32bpp rgba into 32bpp rgba, keeping alpha (dual purpose) */
+// decode 32bpp rgba into 32bpp rgba, keeping alpha (dual purpose)
 static int uncopy_32(Uint32 *dst, const void *src, int n,
-                     RLEDestFormat *sfmt, SDL_PixelFormat *dfmt)
+                     const SDL_PixelFormatDetails *sfmt, const SDL_PixelFormatDetails *dfmt)
 {
     int i;
     const Uint32 *s = (const Uint32 *)src;
@@ -1007,28 +987,28 @@ static int uncopy_32(Uint32 *dst, const void *src, int n,
 #define ISTRANSL(pixel, fmt) \
     ((unsigned)((((pixel)&fmt->Amask) >> fmt->Ashift) - 1U) < 254U)
 
-/* convert surface to be quickly alpha-blittable onto dest, if possible */
-static int RLEAlphaSurface(SDL_Surface *surface)
+// convert surface to be quickly alpha-blittable onto dest, if possible
+static bool RLEAlphaSurface(SDL_Surface *surface)
 {
     SDL_Surface *dest;
-    SDL_PixelFormat *df;
+    const SDL_PixelFormatDetails *df;
     int maxsize = 0;
     int max_opaque_run;
     int max_transl_run = 65535;
     unsigned masksum;
     Uint8 *rlebuf, *dst;
     int (*copy_opaque)(void *, const Uint32 *, int,
-                       SDL_PixelFormat *, SDL_PixelFormat *);
+                       const SDL_PixelFormatDetails *, const SDL_PixelFormatDetails *);
     int (*copy_transl)(void *, const Uint32 *, int,
-                       SDL_PixelFormat *, SDL_PixelFormat *);
+                       const SDL_PixelFormatDetails *, const SDL_PixelFormatDetails *);
 
-    dest = surface->map->dst;
+    dest = surface->map.info.dst_surface;
     if (!dest) {
-        return -1;
+        return false;
     }
-    df = dest->format;
-    if (surface->format->bits_per_pixel != 32) {
-        return -1; /* only 32bpp source supported */
+    df = dest->fmt;
+    if (surface->fmt->bits_per_pixel != 32) {
+        return false; // only 32bpp source supported
     }
 
     /* find out whether the destination is one we support,
@@ -1036,14 +1016,14 @@ static int RLEAlphaSurface(SDL_Surface *surface)
     masksum = df->Rmask | df->Gmask | df->Bmask;
     switch (df->bytes_per_pixel) {
     case 2:
-        /* 16bpp: only support 565 and 555 formats */
+        // 16bpp: only support 565 and 555 formats
         switch (masksum) {
         case 0xffff:
             if (df->Gmask == 0x07e0 || df->Rmask == 0x07e0 || df->Bmask == 0x07e0) {
                 copy_opaque = copy_opaque_16;
                 copy_transl = copy_transl_565;
             } else {
-                return -1;
+                return false;
             }
             break;
         case 0x7fff:
@@ -1051,13 +1031,13 @@ static int RLEAlphaSurface(SDL_Surface *surface)
                 copy_opaque = copy_opaque_16;
                 copy_transl = copy_transl_555;
             } else {
-                return -1;
+                return false;
             }
             break;
         default:
-            return -1;
+            return false;
         }
-        max_opaque_run = 255; /* runs stored as bytes */
+        max_opaque_run = 255; // runs stored as bytes
 
         /* worst case is alternating opaque and translucent pixels,
            with room for alignment padding between lines */
@@ -1065,52 +1045,37 @@ static int RLEAlphaSurface(SDL_Surface *surface)
         break;
     case 4:
         if (masksum != 0x00ffffff) {
-            return -1; /* requires unused high byte */
+            return false; // requires unused high byte
         }
         copy_opaque = copy_32;
         copy_transl = copy_32;
-        max_opaque_run = 255; /* runs stored as short ints */
+        max_opaque_run = 255; // runs stored as short ints
 
-        /* worst case is alternating opaque and translucent pixels */
+        // worst case is alternating opaque and translucent pixels
         maxsize = surface->h * 2 * 4 * (surface->w + 1) + 4;
         break;
     default:
-        return -1; /* anything else unsupported right now */
+        return false; // anything else unsupported right now
     }
 
-    maxsize += sizeof(RLEDestFormat);
+    maxsize += sizeof(SDL_PixelFormat);
     rlebuf = (Uint8 *)SDL_malloc(maxsize);
     if (!rlebuf) {
-        return -1;
+        return false;
     }
-    {
-        /* save the destination format so we can undo the encoding later */
-        RLEDestFormat *r = (RLEDestFormat *)rlebuf;
-        r->bytes_per_pixel = df->bytes_per_pixel;
-        r->Rmask = df->Rmask;
-        r->Gmask = df->Gmask;
-        r->Bmask = df->Bmask;
-        r->Amask = df->Amask;
-        r->Rloss = df->Rloss;
-        r->Gloss = df->Gloss;
-        r->Bloss = df->Bloss;
-        r->Aloss = df->Aloss;
-        r->Rshift = df->Rshift;
-        r->Gshift = df->Gshift;
-        r->Bshift = df->Bshift;
-        r->Ashift = df->Ashift;
-    }
-    dst = rlebuf + sizeof(RLEDestFormat);
+    // save the destination format so we can undo the encoding later
+    *(SDL_PixelFormat *)rlebuf = df->format;
+    dst = rlebuf + sizeof(SDL_PixelFormat);
 
-    /* Do the actual encoding */
+    // Do the actual encoding
     {
         int x, y;
         int h = surface->h, w = surface->w;
-        SDL_PixelFormat *sf = surface->format;
+        const SDL_PixelFormatDetails *sf = surface->fmt;
         Uint32 *src = (Uint32 *)surface->pixels;
-        Uint8 *lastline = dst; /* end of last non-blank line */
+        Uint8 *lastline = dst; // end of last non-blank line
 
-        /* opaque counts are 8 or 16 bits, depending on target depth */
+        // opaque counts are 8 or 16 bits, depending on target depth
 #define ADD_OPAQUE_COUNTS(n, m)           \
     if (df->bytes_per_pixel == 4) {         \
         ((Uint16 *)dst)[0] = (Uint16)n;   \
@@ -1122,14 +1087,14 @@ static int RLEAlphaSurface(SDL_Surface *surface)
         dst += 2;                         \
     }
 
-        /* translucent counts are always 16 bit */
+        // translucent counts are always 16 bit
 #define ADD_TRANSL_COUNTS(n, m) \
     (((Uint16 *)dst)[0] = (Uint16)n, ((Uint16 *)dst)[1] = (Uint16)m, dst += 4)
 
         for (y = 0; y < h; y++) {
             int runstart, skipstart;
             int blankline = 0;
-            /* First encode all opaque pixels of a scan line */
+            // First encode all opaque pixels of a scan line
             x = 0;
             do {
                 int run, skip, len;
@@ -1164,10 +1129,10 @@ static int RLEAlphaSurface(SDL_Surface *surface)
                 }
             } while (x < w);
 
-            /* Make sure the next output address is 32-bit aligned */
+            // Make sure the next output address is 32-bit aligned
             dst += (uintptr_t)dst & 2;
 
-            /* Next, encode all translucent pixels of the same scan line */
+            // Next, encode all translucent pixels of the same scan line
             x = 0;
             do {
                 int run, skip, len;
@@ -1205,34 +1170,34 @@ static int RLEAlphaSurface(SDL_Surface *surface)
 
             src += surface->pitch >> 2;
         }
-        dst = lastline; /* back up past trailing blank lines */
+        dst = lastline; // back up past trailing blank lines
         ADD_OPAQUE_COUNTS(0, 0);
     }
 
 #undef ADD_OPAQUE_COUNTS
 #undef ADD_TRANSL_COUNTS
 
-    /* Now that we have it encoded, release the original pixels */
-    if (!(surface->flags & SDL_PREALLOC)) {
-        if (surface->flags & SDL_SIMD_ALIGNED) {
+    // Now that we have it encoded, release the original pixels
+    if (!(surface->flags & SDL_SURFACE_PREALLOCATED)) {
+        if (surface->flags & SDL_SURFACE_SIMD_ALIGNED) {
             SDL_aligned_free(surface->pixels);
-            surface->flags &= ~SDL_SIMD_ALIGNED;
+            surface->flags &= ~SDL_SURFACE_SIMD_ALIGNED;
         } else {
             SDL_free(surface->pixels);
         }
         surface->pixels = NULL;
     }
 
-    /* reallocate the buffer to release unused memory */
+    // reallocate the buffer to release unused memory
     {
         Uint8 *p = (Uint8 *)SDL_realloc(rlebuf, dst - rlebuf);
         if (!p) {
             p = rlebuf;
         }
-        surface->map->data = p;
+        surface->map.data = p;
     }
 
-    return 0;
+    return true;
 }
 
 static Uint32 getpix_8(const Uint8 *srcbuf)
@@ -1265,19 +1230,19 @@ static const getpix_func getpixes[4] = {
     getpix_8, getpix_16, getpix_24, getpix_32
 };
 
-static int RLEColorkeySurface(SDL_Surface *surface)
+static bool RLEColorkeySurface(SDL_Surface *surface)
 {
     Uint8 *rlebuf, *dst;
     int maxn;
     int y;
     Uint8 *srcbuf, *lastline;
     int maxsize = 0;
-    const int bpp = surface->format->bytes_per_pixel;
+    const int bpp = surface->fmt->bytes_per_pixel;
     getpix_func getpix;
     Uint32 ckey, rgbmask;
     int w, h;
 
-    /* calculate the worst case size for the compressed surface */
+    // calculate the worst case size for the compressed surface
     switch (bpp) {
     case 1:
         /* worst case is alternating opaque and transparent pixels,
@@ -1286,29 +1251,29 @@ static int RLEColorkeySurface(SDL_Surface *surface)
         break;
     case 2:
     case 3:
-        /* worst case is solid runs, at most 255 pixels wide */
+        // worst case is solid runs, at most 255 pixels wide
         maxsize = surface->h * (2 * (surface->w / 255 + 1) + surface->w * bpp) + 2;
         break;
     case 4:
-        /* worst case is solid runs, at most 65535 pixels wide */
+        // worst case is solid runs, at most 65535 pixels wide
         maxsize = surface->h * (4 * (surface->w / 65535 + 1) + surface->w * 4) + 4;
         break;
 
     default:
-        return -1;
+        return false;
     }
 
     rlebuf = (Uint8 *)SDL_malloc(maxsize);
     if (!rlebuf) {
-        return -1;
+        return false;
     }
 
-    /* Set up the conversion */
+    // Set up the conversion
     srcbuf = (Uint8 *)surface->pixels;
     maxn = bpp == 4 ? 65535 : 255;
     dst = rlebuf;
-    rgbmask = ~surface->format->Amask;
-    ckey = surface->map->info.colorkey & rgbmask;
+    rgbmask = ~surface->fmt->Amask;
+    ckey = surface->map.info.colorkey & rgbmask;
     lastline = dst;
     getpix = getpixes[bpp - 1];
     w = surface->w;
@@ -1334,7 +1299,7 @@ static int RLEColorkeySurface(SDL_Surface *surface)
             int runstart;
             int skipstart = x;
 
-            /* find run of transparent, then opaque pixels */
+            // find run of transparent, then opaque pixels
             while (x < w && (getpix(srcbuf + x * bpp) & rgbmask) == ckey) {
                 x++;
             }
@@ -1348,7 +1313,7 @@ static int RLEColorkeySurface(SDL_Surface *surface)
             }
             run = x - runstart;
 
-            /* encode segment */
+            // encode segment
             while (skip > maxn) {
                 ADD_COUNTS(maxn, 0);
                 skip -= maxn;
@@ -1374,94 +1339,94 @@ static int RLEColorkeySurface(SDL_Surface *surface)
 
         srcbuf += surface->pitch;
     }
-    dst = lastline; /* back up bast trailing blank lines */
+    dst = lastline; // back up bast trailing blank lines
     ADD_COUNTS(0, 0);
 
 #undef ADD_COUNTS
 
-    /* Now that we have it encoded, release the original pixels */
-    if (!(surface->flags & SDL_PREALLOC)) {
-        if (surface->flags & SDL_SIMD_ALIGNED) {
+    // Now that we have it encoded, release the original pixels
+    if (!(surface->flags & SDL_SURFACE_PREALLOCATED)) {
+        if (surface->flags & SDL_SURFACE_SIMD_ALIGNED) {
             SDL_aligned_free(surface->pixels);
-            surface->flags &= ~SDL_SIMD_ALIGNED;
+            surface->flags &= ~SDL_SURFACE_SIMD_ALIGNED;
         } else {
             SDL_free(surface->pixels);
         }
         surface->pixels = NULL;
     }
 
-    /* reallocate the buffer to release unused memory */
+    // reallocate the buffer to release unused memory
     {
-        /* If SDL_realloc returns NULL, the original block is left intact */
+        // If SDL_realloc returns NULL, the original block is left intact
         Uint8 *p = (Uint8 *)SDL_realloc(rlebuf, dst - rlebuf);
         if (!p) {
             p = rlebuf;
         }
-        surface->map->data = p;
+        surface->map.data = p;
     }
 
-    return 0;
+    return true;
 }
 
-int SDL_RLESurface(SDL_Surface *surface)
+bool SDL_RLESurface(SDL_Surface *surface)
 {
     int flags;
 
-    /* Clear any previous RLE conversion */
-    if ((surface->flags & SDL_RLEACCEL) == SDL_RLEACCEL) {
-        SDL_UnRLESurface(surface, 1);
+    // Clear any previous RLE conversion
+    if (surface->internal_flags & SDL_INTERNAL_SURFACE_RLEACCEL) {
+        SDL_UnRLESurface(surface, true);
     }
 
-    /* We don't support RLE encoding of bitmaps */
-    if (surface->format->bits_per_pixel < 8) {
-        return -1;
+    // We don't support RLE encoding of bitmaps
+    if (SDL_BITSPERPIXEL(surface->format) < 8) {
+        return false;
     }
 
-    /* Make sure the pixels are available */
+    // Make sure the pixels are available
     if (!surface->pixels) {
-        return -1;
+        return false;
     }
 
-    flags = surface->map->info.flags;
+    flags = surface->map.info.flags;
     if (flags & SDL_COPY_COLORKEY) {
-        /* ok */
-    } else if ((flags & SDL_COPY_BLEND) && surface->format->Amask) {
-        /* ok */
+        // ok
+    } else if ((flags & SDL_COPY_BLEND) && SDL_ISPIXELFORMAT_ALPHA(surface->format)) {
+        // ok
     } else {
-        /* If we don't have colorkey or blending, nothing to do... */
-        return -1;
+        // If we don't have colorkey or blending, nothing to do...
+        return false;
     }
 
-    /* Pass on combinations not supported */
+    // Pass on combinations not supported
     if ((flags & SDL_COPY_MODULATE_COLOR) ||
-        ((flags & SDL_COPY_MODULATE_ALPHA) && surface->format->Amask) ||
-        (flags & (SDL_COPY_ADD | SDL_COPY_MOD | SDL_COPY_MUL)) ||
+        ((flags & SDL_COPY_MODULATE_ALPHA) && SDL_ISPIXELFORMAT_ALPHA(surface->format)) ||
+        (flags & (SDL_COPY_BLEND_PREMULTIPLIED | SDL_COPY_ADD | SDL_COPY_ADD_PREMULTIPLIED | SDL_COPY_MOD | SDL_COPY_MUL)) ||
         (flags & SDL_COPY_NEAREST)) {
-        return -1;
+        return false;
     }
 
-    /* Encode and set up the blit */
-    if (!surface->format->Amask || !(flags & SDL_COPY_BLEND)) {
-        if (!surface->map->identity) {
-            return -1;
+    // Encode and set up the blit
+    if (!SDL_ISPIXELFORMAT_ALPHA(surface->format) || !(flags & SDL_COPY_BLEND)) {
+        if (!surface->map.identity) {
+            return false;
         }
-        if (RLEColorkeySurface(surface) < 0) {
-            return -1;
+        if (!RLEColorkeySurface(surface)) {
+            return false;
         }
-        surface->map->blit = SDL_RLEBlit;
-        surface->map->info.flags |= SDL_COPY_RLE_COLORKEY;
+        surface->map.blit = SDL_RLEBlit;
+        surface->map.info.flags |= SDL_COPY_RLE_COLORKEY;
     } else {
-        if (RLEAlphaSurface(surface) < 0) {
-            return -1;
+        if (!RLEAlphaSurface(surface)) {
+            return false;
         }
-        surface->map->blit = SDL_RLEAlphaBlit;
-        surface->map->info.flags |= SDL_COPY_RLE_ALPHAKEY;
+        surface->map.blit = SDL_RLEAlphaBlit;
+        surface->map.info.flags |= SDL_COPY_RLE_ALPHAKEY;
     }
 
-    /* The surface is now accelerated */
-    surface->flags |= SDL_RLEACCEL;
+    // The surface is now accelerated
+    surface->internal_flags |= SDL_INTERNAL_SURFACE_RLEACCEL;
 
-    return 0;
+    return true;
 }
 
 /*
@@ -1470,16 +1435,16 @@ int SDL_RLESurface(SDL_Surface *surface)
  * completely transparent pixels will be lost, and color and alpha depth
  * may have been reduced (when encoding for 16bpp targets).
  */
-static SDL_bool UnRLEAlpha(SDL_Surface *surface)
+static bool UnRLEAlpha(SDL_Surface *surface)
 {
     Uint8 *srcbuf;
     Uint32 *dst;
-    SDL_PixelFormat *sf = surface->format;
-    RLEDestFormat *df = (RLEDestFormat *)surface->map->data;
+    const SDL_PixelFormatDetails *sf = surface->fmt;
+    const SDL_PixelFormatDetails *df = SDL_GetPixelFormatDetails(*(SDL_PixelFormat *)surface->map.data);
     int (*uncopy_opaque)(Uint32 *, const void *, int,
-                         RLEDestFormat *, SDL_PixelFormat *);
+                         const SDL_PixelFormatDetails *, const SDL_PixelFormatDetails *);
     int (*uncopy_transl)(Uint32 *, const void *, int,
-                         RLEDestFormat *, SDL_PixelFormat *);
+                         const SDL_PixelFormatDetails *, const SDL_PixelFormatDetails *);
     int w = surface->w;
     int bpp = df->bytes_per_pixel;
     size_t size;
@@ -1491,22 +1456,22 @@ static SDL_bool UnRLEAlpha(SDL_Surface *surface)
         uncopy_opaque = uncopy_transl = uncopy_32;
     }
 
-    if (SDL_size_mul_overflow(surface->h, surface->pitch, &size)) {
-        return SDL_FALSE;
+    if (!SDL_size_mul_check_overflow(surface->h, surface->pitch, &size)) {
+        return false;
     }
 
-    surface->pixels = SDL_aligned_alloc(SDL_SIMDGetAlignment(), size);
+    surface->pixels = SDL_aligned_alloc(SDL_GetSIMDAlignment(), size);
     if (!surface->pixels) {
-        return SDL_FALSE;
+        return false;
     }
-    surface->flags |= SDL_SIMD_ALIGNED;
-    /* fill background with transparent pixels */
+    surface->flags |= SDL_SURFACE_SIMD_ALIGNED;
+    // fill background with transparent pixels
     SDL_memset(surface->pixels, 0, (size_t)surface->h * surface->pitch);
 
     dst = (Uint32 *)surface->pixels;
-    srcbuf = (Uint8 *)(df + 1);
+    srcbuf = (Uint8 *)surface->map.data + sizeof(SDL_PixelFormat);
     for (;;) {
-        /* copy opaque pixels */
+        // copy opaque pixels
         int ofs = 0;
         do {
             unsigned run;
@@ -1527,12 +1492,12 @@ static SDL_bool UnRLEAlpha(SDL_Surface *surface)
             }
         } while (ofs < w);
 
-        /* skip padding if needed */
+        // skip padding if needed
         if (bpp == 2) {
             srcbuf += (uintptr_t)srcbuf & 2;
         }
 
-        /* copy translucent pixels */
+        // copy translucent pixels
         ofs = 0;
         do {
             unsigned run;
@@ -1548,55 +1513,55 @@ static SDL_bool UnRLEAlpha(SDL_Surface *surface)
     }
 
 end_function:
-    return SDL_TRUE;
+    return true;
 }
 
-void SDL_UnRLESurface(SDL_Surface *surface, int recode)
+void SDL_UnRLESurface(SDL_Surface *surface, bool recode)
 {
-    if (surface->flags & SDL_RLEACCEL) {
-        surface->flags &= ~SDL_RLEACCEL;
+    if (surface->internal_flags & SDL_INTERNAL_SURFACE_RLEACCEL) {
+        surface->internal_flags &= ~SDL_INTERNAL_SURFACE_RLEACCEL;
 
-        if (recode && !(surface->flags & SDL_PREALLOC)) {
-            if (surface->map->info.flags & SDL_COPY_RLE_COLORKEY) {
+        if (recode && !(surface->flags & SDL_SURFACE_PREALLOCATED)) {
+            if (surface->map.info.flags & SDL_COPY_RLE_COLORKEY) {
                 SDL_Rect full;
                 size_t size;
 
-                /* re-create the original surface */
-                if (SDL_size_mul_overflow(surface->h, surface->pitch, &size)) {
-                    /* Memory corruption? */
-                    surface->flags |= SDL_RLEACCEL;
+                // re-create the original surface
+                if (!SDL_size_mul_check_overflow(surface->h, surface->pitch, &size)) {
+                    // Memory corruption?
+                    surface->internal_flags |= SDL_INTERNAL_SURFACE_RLEACCEL;
                     return;
                 }
-                surface->pixels = SDL_aligned_alloc(SDL_SIMDGetAlignment(), size);
+                surface->pixels = SDL_aligned_alloc(SDL_GetSIMDAlignment(), size);
                 if (!surface->pixels) {
-                    /* Oh crap... */
-                    surface->flags |= SDL_RLEACCEL;
+                    // Oh crap...
+                    surface->internal_flags |= SDL_INTERNAL_SURFACE_RLEACCEL;
                     return;
                 }
-                surface->flags |= SDL_SIMD_ALIGNED;
+                surface->flags |= SDL_SURFACE_SIMD_ALIGNED;
 
-                /* fill it with the background color */
-                SDL_FillSurfaceRect(surface, NULL, surface->map->info.colorkey);
+                // fill it with the background color
+                SDL_FillSurfaceRect(surface, NULL, surface->map.info.colorkey);
 
-                /* now render the encoded surface */
+                // now render the encoded surface
                 full.x = full.y = 0;
                 full.w = surface->w;
                 full.h = surface->h;
                 SDL_RLEBlit(surface, &full, surface, &full);
             } else {
                 if (!UnRLEAlpha(surface)) {
-                    /* Oh crap... */
-                    surface->flags |= SDL_RLEACCEL;
+                    // Oh crap...
+                    surface->internal_flags |= SDL_INTERNAL_SURFACE_RLEACCEL;
                     return;
                 }
             }
         }
-        surface->map->info.flags &=
+        surface->map.info.flags &=
             ~(SDL_COPY_RLE_COLORKEY | SDL_COPY_RLE_ALPHAKEY);
 
-        SDL_free(surface->map->data);
-        surface->map->data = NULL;
+        SDL_free(surface->map.data);
+        surface->map.data = NULL;
     }
 }
 
-#endif /* SDL_HAVE_RLE */
+#endif // SDL_HAVE_RLE
