@@ -22,9 +22,9 @@
 
 #if SDL_HAVE_BLIT_0
 
-#include "SDL_blit.h"
+#include "SDL_surface_c.h"
 
-/* Functions to blit from bitmaps to other surfaces */
+// Functions to blit from bitmaps to other surfaces
 
 SDL_FORCE_INLINE void BlitBto1(SDL_BlitInfo *info, const Uint32 srcbpp)
 {
@@ -36,7 +36,7 @@ SDL_FORCE_INLINE void BlitBto1(SDL_BlitInfo *info, const Uint32 srcbpp)
     Uint8 *src, *map, *dst;
     int srcskip, dstskip;
 
-    /* Set up some basic variables */
+    // Set up some basic variables
     width = info->dst_w;
     height = info->dst_h;
     src = info->src;
@@ -138,7 +138,7 @@ SDL_FORCE_INLINE void BlitBto2(SDL_BlitInfo *info, const Uint32 srcbpp)
     Uint16 *map, *dst;
     int srcskip, dstskip;
 
-    /* Set up some basic variables */
+    // Set up some basic variables
     width = info->dst_w;
     height = info->dst_h;
     src = info->src;
@@ -201,7 +201,7 @@ SDL_FORCE_INLINE void BlitBto3(SDL_BlitInfo *info, const Uint32 srcbpp)
     Uint8 *src, *map, *dst;
     int srcskip, dstskip;
 
-    /* Set up some basic variables */
+    // Set up some basic variables
     width = info->dst_w;
     height = info->dst_h;
     src = info->src;
@@ -271,7 +271,7 @@ SDL_FORCE_INLINE void BlitBto4(SDL_BlitInfo *info, const Uint32 srcbpp)
     int srcskip, dstskip;
     int c;
 
-    /* Set up some basic variables */
+    // Set up some basic variables
     width = info->dst_w;
     height = info->dst_h;
     src = info->src;
@@ -339,7 +339,7 @@ SDL_FORCE_INLINE void BlitBto1Key(SDL_BlitInfo *info, const Uint32 srcbpp)
     Uint8 *palmap = info->table;
     int c;
 
-    /* Set up some basic variables */
+    // Set up some basic variables
     if (srcbpp == 4)
         srcskip += width - (width + 1) / 2;
     else if (srcbpp == 2)
@@ -437,7 +437,7 @@ SDL_FORCE_INLINE void BlitBto2Key(SDL_BlitInfo *info, const Uint32 srcbpp)
     Uint8 *palmap = info->table;
     int c;
 
-    /* Set up some basic variables */
+    // Set up some basic variables
     if (srcbpp == 4)
         srcskip += width - (width + 1) / 2;
     else if (srcbpp == 2)
@@ -498,7 +498,7 @@ SDL_FORCE_INLINE void BlitBto3Key(SDL_BlitInfo *info, const Uint32 srcbpp)
     Uint8 *palmap = info->table;
     int c;
 
-    /* Set up some basic variables */
+    // Set up some basic variables
     if (srcbpp == 4)
         srcskip += width - (width + 1) / 2;
     else if (srcbpp == 2)
@@ -558,7 +558,7 @@ SDL_FORCE_INLINE void BlitBto4Key(SDL_BlitInfo *info, const Uint32 srcbpp)
     Uint8 *palmap = info->table;
     int c;
 
-    /* Set up some basic variables */
+    // Set up some basic variables
     if (srcbpp == 4)
         srcskip += width - (width + 1) / 2;
     else if (srcbpp == 2)
@@ -615,8 +615,8 @@ SDL_FORCE_INLINE void BlitBtoNAlpha(SDL_BlitInfo *info, const Uint32 srcbpp)
     Uint8 *dst = info->dst;
     int srcskip = info->src_skip;
     int dstskip = info->dst_skip;
-    const SDL_Color *srcpal = info->src_fmt->palette->colors;
-    SDL_PixelFormat *dstfmt = info->dst_fmt;
+    const SDL_Color *srcpal = info->src_pal->colors;
+    const SDL_PixelFormatDetails *dstfmt = info->dst_fmt;
     int dstbpp;
     int c;
     Uint32 pixel;
@@ -624,7 +624,7 @@ SDL_FORCE_INLINE void BlitBtoNAlpha(SDL_BlitInfo *info, const Uint32 srcbpp)
     unsigned dR, dG, dB, dA;
     const unsigned A = info->a;
 
-    /* Set up some basic variables */
+    // Set up some basic variables
     dstbpp = dstfmt->bytes_per_pixel;
     if (srcbpp == 4)
         srcskip += width - (width + 1) / 2;
@@ -691,9 +691,8 @@ SDL_FORCE_INLINE void BlitBtoNAlphaKey(SDL_BlitInfo *info, const Uint32 srcbpp)
     Uint8 *dst = info->dst;
     int srcskip = info->src_skip;
     int dstskip = info->dst_skip;
-    SDL_PixelFormat *srcfmt = info->src_fmt;
-    SDL_PixelFormat *dstfmt = info->dst_fmt;
-    const SDL_Color *srcpal = srcfmt->palette->colors;
+    const SDL_PixelFormatDetails *dstfmt = info->dst_fmt;
+    const SDL_Color *srcpal = info->src_pal->colors;
     int dstbpp;
     int c;
     Uint32 pixel;
@@ -702,7 +701,7 @@ SDL_FORCE_INLINE void BlitBtoNAlphaKey(SDL_BlitInfo *info, const Uint32 srcbpp)
     const unsigned A = info->a;
     Uint32 ckey = info->colorkey;
 
-    /* Set up some basic variables */
+    // Set up some basic variables
     dstbpp = dstfmt->bytes_per_pixel;
     if (srcbpp == 4)
         srcskip += width - (width + 1) / 2;
@@ -920,19 +919,25 @@ SDL_BlitFunc SDL_CalculateBlit0(SDL_Surface *surface)
 {
     int which;
 
-    if (surface->map->dst->format->bits_per_pixel < 8) {
+    if (SDL_BITSPERPIXEL(surface->map.info.dst_fmt->format) < 8) {
         which = 0;
     } else {
-        which = surface->map->dst->format->bytes_per_pixel;
+        which = SDL_BYTESPERPIXEL(surface->map.info.dst_fmt->format);
     }
 
-    if (SDL_PIXELTYPE(surface->format->format) == SDL_PIXELTYPE_INDEX1) {
-        switch (surface->map->info.flags & ~SDL_COPY_RLE_MASK) {
+    if (SDL_PIXELTYPE(surface->format) == SDL_PIXELTYPE_INDEX1) {
+        switch (surface->map.info.flags & ~SDL_COPY_RLE_MASK) {
         case 0:
-            return bitmap_blit_1b[which];
+            if (which < SDL_arraysize(bitmap_blit_1b)) {
+                return bitmap_blit_1b[which];
+            }
+            break;
 
         case SDL_COPY_COLORKEY:
-            return colorkey_blit_1b[which];
+            if (which < SDL_arraysize(colorkey_blit_1b)) {
+                return colorkey_blit_1b[which];
+            }
+            break;
 
         case SDL_COPY_MODULATE_ALPHA | SDL_COPY_BLEND:
             return which >= 2 ? Blit1btoNAlpha : (SDL_BlitFunc)NULL;
@@ -943,13 +948,19 @@ SDL_BlitFunc SDL_CalculateBlit0(SDL_Surface *surface)
         return NULL;
     }
 
-    if (SDL_PIXELTYPE(surface->format->format) == SDL_PIXELTYPE_INDEX2) {
-        switch (surface->map->info.flags & ~SDL_COPY_RLE_MASK) {
+    if (SDL_PIXELTYPE(surface->format) == SDL_PIXELTYPE_INDEX2) {
+        switch (surface->map.info.flags & ~SDL_COPY_RLE_MASK) {
         case 0:
-            return bitmap_blit_2b[which];
+            if (which < SDL_arraysize(bitmap_blit_2b)) {
+                return bitmap_blit_2b[which];
+            }
+            break;
 
         case SDL_COPY_COLORKEY:
-            return colorkey_blit_2b[which];
+            if (which < SDL_arraysize(colorkey_blit_2b)) {
+                return colorkey_blit_2b[which];
+            }
+            break;
 
         case SDL_COPY_MODULATE_ALPHA | SDL_COPY_BLEND:
             return which >= 2 ? Blit2btoNAlpha : (SDL_BlitFunc)NULL;
@@ -960,13 +971,19 @@ SDL_BlitFunc SDL_CalculateBlit0(SDL_Surface *surface)
         return NULL;
     }
 
-    if (SDL_PIXELTYPE(surface->format->format) == SDL_PIXELTYPE_INDEX4) {
-        switch (surface->map->info.flags & ~SDL_COPY_RLE_MASK) {
+    if (SDL_PIXELTYPE(surface->format) == SDL_PIXELTYPE_INDEX4) {
+        switch (surface->map.info.flags & ~SDL_COPY_RLE_MASK) {
         case 0:
-            return bitmap_blit_4b[which];
+            if (which < SDL_arraysize(bitmap_blit_4b)) {
+                return bitmap_blit_4b[which];
+            }
+            break;
 
         case SDL_COPY_COLORKEY:
-            return colorkey_blit_4b[which];
+            if (which < SDL_arraysize(colorkey_blit_4b)) {
+                return colorkey_blit_4b[which];
+            }
+            break;
 
         case SDL_COPY_MODULATE_ALPHA | SDL_COPY_BLEND:
             return which >= 2 ? Blit4btoNAlpha : (SDL_BlitFunc)NULL;
@@ -980,4 +997,4 @@ SDL_BlitFunc SDL_CalculateBlit0(SDL_Surface *surface)
     return NULL;
 }
 
-#endif /* SDL_HAVE_BLIT_0 */
+#endif // SDL_HAVE_BLIT_0
