@@ -33,10 +33,11 @@
 */
 
 #include "SDL_pixels_c.h"
+#include "SDL_surface_c.h"
 
 #define SAVE_32BIT_BMP
 
-/* Compression encodings for BMP files */
+// Compression encodings for BMP files
 #ifndef BI_RGB
 #define BI_RGB       0
 #define BI_RLE8      1
@@ -44,13 +45,13 @@
 #define BI_BITFIELDS 3
 #endif
 
-/* Logical color space values for BMP files */
+// Logical color space values for BMP files
 #ifndef LCS_WINDOWS_COLOR_SPACE
-/* 0x57696E20 == "Win " */
+// 0x57696E20 == "Win "
 #define LCS_WINDOWS_COLOR_SPACE 0x57696E20
 #endif
 
-static SDL_bool readRlePixels(SDL_Surface *surface, SDL_IOStream *src, int isRle8)
+static bool readRlePixels(SDL_Surface *surface, SDL_IOStream *src, int isRle8)
 {
     /*
     | Sets the surface pixels from src.  A bmp image is upside down.
@@ -69,10 +70,10 @@ static SDL_bool readRlePixels(SDL_Surface *surface, SDL_IOStream *src, int isRle
     if (spot >= start && spot < end) \
     *spot = (x)
 
-    /* !!! FIXME: for all these reads, handle error vs eof? handle -2 if non-blocking? */
+    // !!! FIXME: for all these reads, handle error vs eof? handle -2 if non-blocking?
     for (;;) {
         if (!SDL_ReadU8(src, &ch)) {
-            return SDL_TRUE;
+            return true;
         }
         /*
         | encoded mode starts with a run length, and then a byte
@@ -81,21 +82,21 @@ static SDL_bool readRlePixels(SDL_Surface *surface, SDL_IOStream *src, int isRle
         if (ch) {
             Uint8 pixel;
             if (!SDL_ReadU8(src, &pixel)) {
-                return SDL_TRUE;
+                return true;
             }
-            if (isRle8) { /* 256-color bitmap, compressed */
+            if (isRle8) { // 256-color bitmap, compressed
                 do {
                     COPY_PIXEL(pixel);
                 } while (--ch);
-            } else { /* 16-color bitmap, compressed */
+            } else { // 16-color bitmap, compressed
                 Uint8 pixel0 = pixel >> 4;
                 Uint8 pixel1 = pixel & 0x0F;
                 for (;;) {
-                    COPY_PIXEL(pixel0); /* even count, high nibble */
+                    COPY_PIXEL(pixel0); // even count, high nibble
                     if (!--ch) {
                         break;
                     }
-                    COPY_PIXEL(pixel1); /* odd count, low nibble */
+                    COPY_PIXEL(pixel1); // odd count, low nibble
                     if (!--ch) {
                         break;
                     }
@@ -108,41 +109,41 @@ static SDL_bool readRlePixels(SDL_Surface *surface, SDL_IOStream *src, int isRle
             | zero tag may be absolute mode or an escape
             */
             if (!SDL_ReadU8(src, &ch)) {
-                return SDL_TRUE;
+                return true;
             }
             switch (ch) {
-            case 0: /* end of line */
+            case 0: // end of line
                 ofs = 0;
-                bits -= pitch; /* go to previous */
+                bits -= pitch; // go to previous
                 break;
-            case 1:               /* end of bitmap */
-                return SDL_FALSE; /* success! */
-            case 2:               /* delta */
+            case 1:               // end of bitmap
+                return false; // success!
+            case 2:               // delta
                 if (!SDL_ReadU8(src, &ch)) {
-                    return SDL_TRUE;
+                    return true;
                 }
                 ofs += ch;
                 if (!SDL_ReadU8(src, &ch)) {
-                    return SDL_TRUE;
+                    return true;
                 }
                 bits -= (ch * pitch);
                 break;
-            default: /* no compression */
+            default: // no compression
                 if (isRle8) {
                     needsPad = (ch & 1);
                     do {
                         Uint8 pixel;
                         if (!SDL_ReadU8(src, &pixel)) {
-                            return SDL_TRUE;
+                            return true;
                         }
                         COPY_PIXEL(pixel);
                     } while (--ch);
                 } else {
-                    needsPad = (((ch + 1) >> 1) & 1); /* (ch+1)>>1: bytes size */
+                    needsPad = (((ch + 1) >> 1) & 1); // (ch+1)>>1: bytes size
                     for (;;) {
                         Uint8 pixel;
                         if (!SDL_ReadU8(src, &pixel)) {
-                            return SDL_TRUE;
+                            return true;
                         }
                         COPY_PIXEL(pixel >> 4);
                         if (!--ch) {
@@ -154,9 +155,9 @@ static SDL_bool readRlePixels(SDL_Surface *surface, SDL_IOStream *src, int isRle
                         }
                     }
                 }
-                /* pad at even boundary */
+                // pad at even boundary
                 if (needsPad && !SDL_ReadU8(src, &ch)) {
-                    return SDL_TRUE;
+                    return true;
                 }
                 break;
             }
@@ -166,8 +167,8 @@ static SDL_bool readRlePixels(SDL_Surface *surface, SDL_IOStream *src, int isRle
 
 static void CorrectAlphaChannel(SDL_Surface *surface)
 {
-    /* Check to see if there is any alpha channel data */
-    SDL_bool hasAlpha = SDL_FALSE;
+    // Check to see if there is any alpha channel data
+    bool hasAlpha = false;
 #if SDL_BYTEORDER == SDL_BIG_ENDIAN
     int alphaChannelOffset = 0;
 #else
@@ -178,7 +179,7 @@ static void CorrectAlphaChannel(SDL_Surface *surface)
 
     while (alpha < end) {
         if (*alpha != 0) {
-            hasAlpha = SDL_TRUE;
+            hasAlpha = true;
             break;
         }
         alpha += 4;
@@ -193,9 +194,9 @@ static void CorrectAlphaChannel(SDL_Surface *surface)
     }
 }
 
-SDL_Surface *SDL_LoadBMP_IO(SDL_IOStream *src, SDL_bool closeio)
+SDL_Surface *SDL_LoadBMP_IO(SDL_IOStream *src, bool closeio)
 {
-    SDL_bool was_error = SDL_TRUE;
+    bool was_error = true;
     Sint64 fp_offset = 0;
     int i, pad;
     SDL_Surface *surface;
@@ -203,42 +204,41 @@ SDL_Surface *SDL_LoadBMP_IO(SDL_IOStream *src, SDL_bool closeio)
     Uint32 Gmask = 0;
     Uint32 Bmask = 0;
     Uint32 Amask = 0;
-    SDL_Palette *palette;
     Uint8 *bits;
     Uint8 *top, *end;
-    SDL_bool topDown;
-    SDL_bool haveRGBMasks = SDL_FALSE;
-    SDL_bool haveAlphaMask = SDL_FALSE;
-    SDL_bool correctAlpha = SDL_FALSE;
+    bool topDown;
+    bool haveRGBMasks = false;
+    bool haveAlphaMask = false;
+    bool correctAlpha = false;
 
-    /* The Win32 BMP file header (14 bytes) */
+    // The Win32 BMP file header (14 bytes)
     char magic[2];
-    /* Uint32 bfSize; */
-    /* Uint16 bfReserved1; */
-    /* Uint16 bfReserved2; */
+    // Uint32 bfSize;
+    // Uint16 bfReserved1;
+    // Uint16 bfReserved2;
     Uint32 bfOffBits;
 
-    /* The Win32 BITMAPINFOHEADER struct (40 bytes) */
+    // The Win32 BITMAPINFOHEADER struct (40 bytes)
     Uint32 biSize;
     Sint32 biWidth = 0;
     Sint32 biHeight = 0;
-    /* Uint16 biPlanes; */
+    // Uint16 biPlanes;
     Uint16 biBitCount = 0;
     Uint32 biCompression = 0;
-    /* Uint32 biSizeImage; */
-    /* Sint32 biXPelsPerMeter; */
-    /* Sint32 biYPelsPerMeter; */
+    // Uint32 biSizeImage;
+    // Sint32 biXPelsPerMeter;
+    // Sint32 biYPelsPerMeter;
     Uint32 biClrUsed = 0;
-    /* Uint32 biClrImportant; */
+    // Uint32 biClrImportant;
 
-    /* Make sure we are passed a valid data source */
+    // Make sure we are passed a valid data source
     surface = NULL;
     if (!src) {
         SDL_InvalidParamError("src");
         goto done;
     }
 
-    /* Read in the BMP file header */
+    // Read in the BMP file header
     fp_offset = SDL_TellIO(src);
     if (fp_offset < 0) {
         goto done;
@@ -258,11 +258,11 @@ SDL_Surface *SDL_LoadBMP_IO(SDL_IOStream *src, SDL_bool closeio)
         goto done;
     }
 
-    /* Read the Win32 BITMAPINFOHEADER */
+    // Read the Win32 BITMAPINFOHEADER
     if (!SDL_ReadU32LE(src, &biSize)) {
         goto done;
     }
-    if (biSize == 12) { /* really old BITMAPCOREHEADER */
+    if (biSize == 12) { // really old BITMAPCOREHEADER
         Uint16 biWidth16, biHeight16;
         if (!SDL_ReadU16LE(src, &biWidth16) ||
             !SDL_ReadU16LE(src, &biHeight16) ||
@@ -273,12 +273,12 @@ SDL_Surface *SDL_LoadBMP_IO(SDL_IOStream *src, SDL_bool closeio)
         biWidth = biWidth16;
         biHeight = biHeight16;
         biCompression = BI_RGB;
-        /* biSizeImage = 0; */
-        /* biXPelsPerMeter = 0; */
-        /* biYPelsPerMeter = 0; */
+        // biSizeImage = 0;
+        // biXPelsPerMeter = 0;
+        // biYPelsPerMeter = 0;
         biClrUsed = 0;
-        /* biClrImportant = 0; */
-    } else if (biSize >= 40) { /* some version of BITMAPINFOHEADER */
+        // biClrImportant = 0;
+    } else if (biSize >= 40) { // some version of BITMAPINFOHEADER
         Uint32 headerSize;
         if (!SDL_ReadS32LE(src, &biWidth) ||
             !SDL_ReadS32LE(src, &biHeight) ||
@@ -293,7 +293,7 @@ SDL_Surface *SDL_LoadBMP_IO(SDL_IOStream *src, SDL_bool closeio)
             goto done;
         }
 
-        /* 64 == BITMAPCOREHEADER2, an incompatible OS/2 2.x extension. Skip this stuff for now. */
+        // 64 == BITMAPCOREHEADER2, an incompatible OS/2 2.x extension. Skip this stuff for now.
         if (biSize != 64) {
             /* This is complicated. If compression is BI_BITFIELDS, then
                we have 3 DWORDS that specify the RGB masks. This is either
@@ -303,30 +303,30 @@ SDL_Surface *SDL_LoadBMP_IO(SDL_IOStream *src, SDL_bool closeio)
                speaking, this is the bmiColors field in BITMAPINFO immediately
                following the legacy v1 info header, just past biSize. */
             if (biCompression == BI_BITFIELDS) {
-                haveRGBMasks = SDL_TRUE;
+                haveRGBMasks = true;
                 if (!SDL_ReadU32LE(src, &Rmask) ||
                     !SDL_ReadU32LE(src, &Gmask) ||
                     !SDL_ReadU32LE(src, &Bmask)) {
                     goto done;
                 }
 
-                /* ...v3 adds an alpha mask. */
-                if (biSize >= 56) { /* BITMAPV3INFOHEADER; adds alpha mask */
-                    haveAlphaMask = SDL_TRUE;
+                // ...v3 adds an alpha mask.
+                if (biSize >= 56) { // BITMAPV3INFOHEADER; adds alpha mask
+                    haveAlphaMask = true;
                     if (!SDL_ReadU32LE(src, &Amask)) {
                         goto done;
                     }
                 }
             } else {
-                /* the mask fields are ignored for v2+ headers if not BI_BITFIELD. */
-                if (biSize >= 52) { /* BITMAPV2INFOHEADER; adds RGB masks */
+                // the mask fields are ignored for v2+ headers if not BI_BITFIELD.
+                if (biSize >= 52) { // BITMAPV2INFOHEADER; adds RGB masks
                     if (!SDL_ReadU32LE(src, NULL /* Rmask */) ||
                         !SDL_ReadU32LE(src, NULL /* Gmask */) ||
                         !SDL_ReadU32LE(src, NULL /* Bmask */)) {
                         goto done;
                     }
                 }
-                if (biSize >= 56) { /* BITMAPV3INFOHEADER; adds alpha mask */
+                if (biSize >= 56) { // BITMAPV3INFOHEADER; adds alpha mask
                     if (!SDL_ReadU32LE(src, NULL /* Amask */)) {
                         goto done;
                     }
@@ -339,7 +339,7 @@ SDL_Surface *SDL_LoadBMP_IO(SDL_IOStream *src, SDL_bool closeio)
                currently parse up to v3 correctly (hopefully!). */
         }
 
-        /* skip any header bytes we didn't handle... */
+        // skip any header bytes we didn't handle...
         headerSize = (Uint32)(SDL_TellIO(src) - (fp_offset + 14));
         if (biSize > headerSize) {
             if (SDL_SeekIO(src, (biSize - headerSize), SDL_IO_SEEK_CUR) < 0) {
@@ -352,18 +352,18 @@ SDL_Surface *SDL_LoadBMP_IO(SDL_IOStream *src, SDL_bool closeio)
         goto done;
     }
     if (biHeight < 0) {
-        topDown = SDL_TRUE;
+        topDown = true;
         biHeight = -biHeight;
     } else {
-        topDown = SDL_FALSE;
+        topDown = false;
     }
 
-    /* Check for read error */
+    // Check for read error
     if (SDL_strcmp(SDL_GetError(), "") != 0) {
         goto done;
     }
 
-    /* Reject invalid bit depths */
+    // Reject invalid bit depths
     switch (biBitCount) {
     case 0:
     case 3:
@@ -376,38 +376,38 @@ SDL_Surface *SDL_LoadBMP_IO(SDL_IOStream *src, SDL_bool closeio)
         break;
     }
 
-    /* RLE4 and RLE8 BMP compression is supported */
+    // RLE4 and RLE8 BMP compression is supported
     switch (biCompression) {
     case BI_RGB:
-        /* If there are no masks, use the defaults */
+        // If there are no masks, use the defaults
         SDL_assert(!haveRGBMasks);
         SDL_assert(!haveAlphaMask);
-        /* Default values for the BMP format */
+        // Default values for the BMP format
         switch (biBitCount) {
         case 15:
         case 16:
-            /* SDL_PIXELFORMAT_RGB555 or SDL_PIXELFORMAT_ARGB1555 if Amask */
+            // SDL_PIXELFORMAT_XRGB1555 or SDL_PIXELFORMAT_ARGB1555 if Amask
             Rmask = 0x7C00;
             Gmask = 0x03E0;
             Bmask = 0x001F;
             break;
         case 24:
 #if SDL_BYTEORDER == SDL_BIG_ENDIAN
-            /* SDL_PIXELFORMAT_RGB24 */
+            // SDL_PIXELFORMAT_RGB24
             Rmask = 0x000000FF;
             Gmask = 0x0000FF00;
             Bmask = 0x00FF0000;
 #else
-            /* SDL_PIXELFORMAT_BGR24 */
+            // SDL_PIXELFORMAT_BGR24
             Rmask = 0x00FF0000;
             Gmask = 0x0000FF00;
             Bmask = 0x000000FF;
 #endif
             break;
         case 32:
-            /* We don't know if this has alpha channel or not */
-            correctAlpha = SDL_TRUE;
-            /* SDL_PIXELFORMAT_RGBA8888 */
+            // We don't know if this has alpha channel or not
+            correctAlpha = true;
+            // SDL_PIXELFORMAT_RGBA8888
             Amask = 0xFF000000;
             Rmask = 0x00FF0000;
             Gmask = 0x0000FF00;
@@ -419,18 +419,18 @@ SDL_Surface *SDL_LoadBMP_IO(SDL_IOStream *src, SDL_bool closeio)
         break;
 
     case BI_BITFIELDS:
-        break; /* we handled this in the info header. */
+        break; // we handled this in the info header.
 
     default:
         break;
     }
 
-    /* Create a compatible surface, note that the colors are RGB ordered */
+    // Create a compatible surface, note that the colors are RGB ordered
     {
-        SDL_PixelFormatEnum format;
+        SDL_PixelFormat format;
 
-        /* Get the pixel format */
-        format = SDL_GetPixelFormatEnumForMasks(biBitCount, Rmask, Gmask, Bmask, Amask);
+        // Get the pixel format
+        format = SDL_GetPixelFormatForMasks(biBitCount, Rmask, Gmask, Bmask, Amask);
         surface = SDL_CreateSurface(biWidth, biHeight, format);
 
         if (!surface) {
@@ -438,15 +438,19 @@ SDL_Surface *SDL_LoadBMP_IO(SDL_IOStream *src, SDL_bool closeio)
         }
     }
 
-    /* Load the palette, if any */
-    palette = (surface->format)->palette;
-    if (palette) {
-        if (SDL_SeekIO(src, fp_offset + 14 + biSize, SDL_IO_SEEK_SET) < 0) {
-            SDL_Error(SDL_EFSEEK);
+    // Load the palette, if any
+    if (SDL_ISPIXELFORMAT_INDEXED(surface->format)) {
+        SDL_Palette *palette = SDL_CreateSurfacePalette(surface);
+        if (!palette) {
             goto done;
         }
 
-        if (biBitCount >= 32) { /* we shift biClrUsed by this value later. */
+        if (SDL_SeekIO(src, fp_offset + 14 + biSize, SDL_IO_SEEK_SET) < 0) {
+            SDL_SetError("Error seeking in datastream");
+            goto done;
+        }
+
+        if (biBitCount >= 32) { // we shift biClrUsed by this value later.
             SDL_SetError("Unsupported or incorrect biBitCount field");
             goto done;
         }
@@ -456,15 +460,16 @@ SDL_Surface *SDL_LoadBMP_IO(SDL_IOStream *src, SDL_bool closeio)
         }
 
         if (biClrUsed > (Uint32)palette->ncolors) {
-            biClrUsed = 1 << biBitCount; /* try forcing it? */
+            biClrUsed = 1 << biBitCount; // try forcing it?
             if (biClrUsed > (Uint32)palette->ncolors) {
                 SDL_SetError("Unsupported or incorrect biClrUsed field");
                 goto done;
             }
         }
+        palette->ncolors = biClrUsed;
 
         if (biSize == 12) {
-            for (i = 0; i < (int)biClrUsed; ++i) {
+            for (i = 0; i < palette->ncolors; ++i) {
                 if (!SDL_ReadU8(src, &palette->colors[i].b) ||
                     !SDL_ReadU8(src, &palette->colors[i].g) ||
                     !SDL_ReadU8(src, &palette->colors[i].r)) {
@@ -473,7 +478,7 @@ SDL_Surface *SDL_LoadBMP_IO(SDL_IOStream *src, SDL_bool closeio)
                 palette->colors[i].a = SDL_ALPHA_OPAQUE;
             }
         } else {
-            for (i = 0; i < (int)biClrUsed; ++i) {
+            for (i = 0; i < palette->ncolors; ++i) {
                 if (!SDL_ReadU8(src, &palette->colors[i].b) ||
                     !SDL_ReadU8(src, &palette->colors[i].g) ||
                     !SDL_ReadU8(src, &palette->colors[i].r) ||
@@ -488,18 +493,17 @@ SDL_Surface *SDL_LoadBMP_IO(SDL_IOStream *src, SDL_bool closeio)
                 palette->colors[i].a = SDL_ALPHA_OPAQUE;
             }
         }
-        palette->ncolors = biClrUsed;
     }
 
-    /* Read the surface pixels.  Note that the bmp image is upside down */
+    // Read the surface pixels.  Note that the bmp image is upside down
     if (SDL_SeekIO(src, fp_offset + bfOffBits, SDL_IO_SEEK_SET) < 0) {
-        SDL_Error(SDL_EFSEEK);
+        SDL_SetError("Error seeking in datastream");
         goto done;
     }
     if ((biCompression == BI_RLE4) || (biCompression == BI_RLE8)) {
         was_error = readRlePixels(surface, src, biCompression == BI_RLE8);
         if (was_error) {
-            SDL_Error(SDL_EFREAD);
+            SDL_SetError("Error reading from datastream");
         }
         goto done;
     }
@@ -515,7 +519,7 @@ SDL_Surface *SDL_LoadBMP_IO(SDL_IOStream *src, SDL_bool closeio)
         if (SDL_ReadIO(src, bits, surface->pitch) != (size_t)surface->pitch) {
             goto done;
         }
-        if (biBitCount == 8 && palette && biClrUsed < (1u << biBitCount)) {
+        if (biBitCount == 8 && surface->palette && biClrUsed < (1u << biBitCount)) {
             for (i = 0; i < surface->w; ++i) {
                 if (bits[i] >= biClrUsed) {
                     SDL_SetError("A BMP image contains a pixel with a color out of the palette");
@@ -548,7 +552,7 @@ SDL_Surface *SDL_LoadBMP_IO(SDL_IOStream *src, SDL_bool closeio)
         }
 #endif
 
-        /* Skip padding bytes, ugh */
+        // Skip padding bytes, ugh
         if (pad) {
             Uint8 padbyte;
             for (i = 0; i < pad; ++i) {
@@ -567,7 +571,7 @@ SDL_Surface *SDL_LoadBMP_IO(SDL_IOStream *src, SDL_bool closeio)
         CorrectAlphaChannel(surface);
     }
 
-    was_error = SDL_FALSE;
+    was_error = false;
 
 done:
     if (was_error) {
@@ -588,24 +592,24 @@ SDL_Surface *SDL_LoadBMP(const char *file)
     return SDL_LoadBMP_IO(SDL_IOFromFile(file, "rb"), 1);
 }
 
-int SDL_SaveBMP_IO(SDL_Surface *surface, SDL_IOStream *dst, SDL_bool closeio)
+bool SDL_SaveBMP_IO(SDL_Surface *surface, SDL_IOStream *dst, bool closeio)
 {
-    SDL_bool was_error = SDL_TRUE;
+    bool was_error = true;
     Sint64 fp_offset, new_offset;
     int i, pad;
     SDL_Surface *intermediate_surface;
     Uint8 *bits;
-    SDL_bool save32bit = SDL_FALSE;
-    SDL_bool saveLegacyBMP = SDL_FALSE;
+    bool save32bit = false;
+    bool saveLegacyBMP = false;
 
-    /* The Win32 BMP file header (14 bytes) */
+    // The Win32 BMP file header (14 bytes)
     char magic[2] = { 'B', 'M' };
     Uint32 bfSize;
     Uint16 bfReserved1;
     Uint16 bfReserved2;
     Uint32 bfOffBits;
 
-    /* The Win32 BITMAPINFOHEADER struct (40 bytes) */
+    // The Win32 BITMAPINFOHEADER struct (40 bytes)
     Uint32 biSize;
     Sint32 biWidth;
     Sint32 biHeight;
@@ -618,7 +622,7 @@ int SDL_SaveBMP_IO(SDL_Surface *surface, SDL_IOStream *dst, SDL_bool closeio)
     Uint32 biClrUsed;
     Uint32 biClrImportant;
 
-    /* The additional header members from the Win32 BITMAPV4HEADER struct (108 bytes in total) */
+    // The additional header members from the Win32 BITMAPV4HEADER struct (108 bytes in total)
     Uint32 bV4RedMask = 0;
     Uint32 bV4GreenMask = 0;
     Uint32 bV4BlueMask = 0;
@@ -629,45 +633,45 @@ int SDL_SaveBMP_IO(SDL_Surface *surface, SDL_IOStream *dst, SDL_bool closeio)
     Uint32 bV4GammaGreen = 0;
     Uint32 bV4GammaBlue = 0;
 
-    /* Make sure we have somewhere to save */
+    // Make sure we have somewhere to save
     intermediate_surface = NULL;
     if (dst) {
-        if (!surface) {
+        if (!SDL_SurfaceValid(surface)) {
             SDL_InvalidParamError("surface");
             goto done;
         }
 
 #ifdef SAVE_32BIT_BMP
-        /* We can save alpha information in a 32-bit BMP */
-        if (surface->format->bits_per_pixel >= 8 &&
-            (surface->format->Amask != 0 ||
-             surface->map->info.flags & SDL_COPY_COLORKEY)) {
-            save32bit = SDL_TRUE;
+        // We can save alpha information in a 32-bit BMP
+        if (SDL_BITSPERPIXEL(surface->format) >= 8 &&
+            (SDL_ISPIXELFORMAT_ALPHA(surface->format) ||
+             surface->map.info.flags & SDL_COPY_COLORKEY)) {
+            save32bit = true;
         }
-#endif /* SAVE_32BIT_BMP */
+#endif // SAVE_32BIT_BMP
 
-        if (surface->format->palette && !save32bit) {
-            if (surface->format->bits_per_pixel == 8) {
+        if (surface->palette && !save32bit) {
+            if (SDL_BITSPERPIXEL(surface->format) == 8) {
                 intermediate_surface = surface;
             } else {
                 SDL_SetError("%u bpp BMP files not supported",
-                             surface->format->bits_per_pixel);
+                             SDL_BITSPERPIXEL(surface->format));
                 goto done;
             }
-        } else if ((surface->format->bits_per_pixel == 24) && !save32bit &&
+        } else if ((SDL_BITSPERPIXEL(surface->format) == 24) && !save32bit &&
 #if SDL_BYTEORDER == SDL_LIL_ENDIAN
-                   (surface->format->Rmask == 0x00FF0000) &&
-                   (surface->format->Gmask == 0x0000FF00) &&
-                   (surface->format->Bmask == 0x000000FF)
+                   (surface->fmt->Rmask == 0x00FF0000) &&
+                   (surface->fmt->Gmask == 0x0000FF00) &&
+                   (surface->fmt->Bmask == 0x000000FF)
 #else
-                   (surface->format->Rmask == 0x000000FF) &&
-                   (surface->format->Gmask == 0x0000FF00) &&
-                   (surface->format->Bmask == 0x00FF0000)
+                   (surface->fmt->Rmask == 0x000000FF) &&
+                   (surface->fmt->Gmask == 0x0000FF00) &&
+                   (surface->fmt->Bmask == 0x00FF0000)
 #endif
         ) {
             intermediate_surface = surface;
         } else {
-            SDL_PixelFormatEnum pixel_format;
+            SDL_PixelFormat pixel_format;
 
             /* If the surface has a colorkey or alpha channel we'll save a
                32-bit BMP with alpha channel, otherwise save a 24-bit BMP. */
@@ -676,7 +680,7 @@ int SDL_SaveBMP_IO(SDL_Surface *surface, SDL_IOStream *dst, SDL_bool closeio)
             } else {
                 pixel_format = SDL_PIXELFORMAT_BGR24;
             }
-            intermediate_surface = SDL_ConvertSurfaceFormat(surface, pixel_format);
+            intermediate_surface = SDL_ConvertSurface(surface, pixel_format);
             if (!intermediate_surface) {
                 SDL_SetError("Couldn't convert image to %d bpp",
                              (int)SDL_BITSPERPIXEL(pixel_format));
@@ -690,19 +694,19 @@ int SDL_SaveBMP_IO(SDL_Surface *surface, SDL_IOStream *dst, SDL_bool closeio)
     }
 
     if (save32bit) {
-        saveLegacyBMP = SDL_GetHintBoolean(SDL_HINT_BMP_SAVE_LEGACY_FORMAT, SDL_FALSE);
+        saveLegacyBMP = SDL_GetHintBoolean(SDL_HINT_BMP_SAVE_LEGACY_FORMAT, false);
     }
 
-    if (SDL_LockSurface(intermediate_surface) == 0) {
-        const size_t bw = intermediate_surface->w * intermediate_surface->format->bytes_per_pixel;
+    if (SDL_LockSurface(intermediate_surface)) {
+        const size_t bw = intermediate_surface->w * intermediate_surface->fmt->bytes_per_pixel;
 
-        /* Set the BMP file header values */
-        bfSize = 0; /* We'll write this when we're done */
+        // Set the BMP file header values
+        bfSize = 0; // We'll write this when we're done
         bfReserved1 = 0;
         bfReserved2 = 0;
-        bfOffBits = 0; /* We'll write this when we're done */
+        bfOffBits = 0; // We'll write this when we're done
 
-        /* Write the BMP file header values */
+        // Write the BMP file header values
         fp_offset = SDL_TellIO(dst);
         if (fp_offset < 0) {
             goto done;
@@ -715,28 +719,28 @@ int SDL_SaveBMP_IO(SDL_Surface *surface, SDL_IOStream *dst, SDL_bool closeio)
             goto done;
         }
 
-        /* Set the BMP info values */
+        // Set the BMP info values
         biSize = 40;
         biWidth = intermediate_surface->w;
         biHeight = intermediate_surface->h;
         biPlanes = 1;
-        biBitCount = intermediate_surface->format->bits_per_pixel;
+        biBitCount = intermediate_surface->fmt->bits_per_pixel;
         biCompression = BI_RGB;
         biSizeImage = intermediate_surface->h * intermediate_surface->pitch;
         biXPelsPerMeter = 0;
         biYPelsPerMeter = 0;
-        if (intermediate_surface->format->palette) {
-            biClrUsed = intermediate_surface->format->palette->ncolors;
+        if (intermediate_surface->palette) {
+            biClrUsed = intermediate_surface->palette->ncolors;
         } else {
             biClrUsed = 0;
         }
         biClrImportant = 0;
 
-        /* Set the BMP info values for the version 4 header */
+        // Set the BMP info values for the version 4 header
         if (save32bit && !saveLegacyBMP) {
             biSize = 108;
             biCompression = BI_BITFIELDS;
-            /* The BMP format is always little endian, these masks stay the same */
+            // The BMP format is always little endian, these masks stay the same
             bV4RedMask = 0x00ff0000;
             bV4GreenMask = 0x0000ff00;
             bV4BlueMask = 0x000000ff;
@@ -747,7 +751,7 @@ int SDL_SaveBMP_IO(SDL_Surface *surface, SDL_IOStream *dst, SDL_bool closeio)
             bV4GammaBlue = 0;
         }
 
-        /* Write the BMP info values */
+        // Write the BMP info values
         if (!SDL_WriteU32LE(dst, biSize) ||
             !SDL_WriteS32LE(dst, biWidth) ||
             !SDL_WriteS32LE(dst, biHeight) ||
@@ -762,7 +766,7 @@ int SDL_SaveBMP_IO(SDL_Surface *surface, SDL_IOStream *dst, SDL_bool closeio)
             goto done;
         }
 
-        /* Write the BMP info values for the version 4 header */
+        // Write the BMP info values for the version 4 header
         if (save32bit && !saveLegacyBMP) {
             if (!SDL_WriteU32LE(dst, bV4RedMask) ||
                 !SDL_WriteU32LE(dst, bV4GreenMask) ||
@@ -783,13 +787,13 @@ int SDL_SaveBMP_IO(SDL_Surface *surface, SDL_IOStream *dst, SDL_bool closeio)
             }
         }
 
-        /* Write the palette (in BGR color order) */
-        if (intermediate_surface->format->palette) {
+        // Write the palette (in BGR color order)
+        if (intermediate_surface->palette) {
             SDL_Color *colors;
             int ncolors;
 
-            colors = intermediate_surface->format->palette->colors;
-            ncolors = intermediate_surface->format->palette->ncolors;
+            colors = intermediate_surface->palette->colors;
+            ncolors = intermediate_surface->palette->ncolors;
             for (i = 0; i < ncolors; ++i) {
                 if (!SDL_WriteU8(dst, colors[i].b) ||
                     !SDL_WriteU8(dst, colors[i].g) ||
@@ -800,7 +804,7 @@ int SDL_SaveBMP_IO(SDL_Surface *surface, SDL_IOStream *dst, SDL_bool closeio)
             }
         }
 
-        /* Write the bitmap offset */
+        // Write the bitmap offset
         bfOffBits = (Uint32)(SDL_TellIO(dst) - fp_offset);
         if (SDL_SeekIO(dst, fp_offset + 10, SDL_IO_SEEK_SET) < 0) {
             goto done;
@@ -812,7 +816,7 @@ int SDL_SaveBMP_IO(SDL_Surface *surface, SDL_IOStream *dst, SDL_bool closeio)
             goto done;
         }
 
-        /* Write the bitmap image upside down */
+        // Write the bitmap image upside down
         bits = (Uint8 *)intermediate_surface->pixels + (intermediate_surface->h * intermediate_surface->pitch);
         pad = ((bw % 4) ? (4 - (bw % 4)) : 0);
         while (bits > (Uint8 *)intermediate_surface->pixels) {
@@ -830,7 +834,7 @@ int SDL_SaveBMP_IO(SDL_Surface *surface, SDL_IOStream *dst, SDL_bool closeio)
             }
         }
 
-        /* Write the BMP file size */
+        // Write the BMP file size
         new_offset = SDL_TellIO(dst);
         if (new_offset < 0) {
             goto done;
@@ -846,10 +850,10 @@ int SDL_SaveBMP_IO(SDL_Surface *surface, SDL_IOStream *dst, SDL_bool closeio)
             goto done;
         }
 
-        /* Close it up.. */
+        // Close it up..
         SDL_UnlockSurface(intermediate_surface);
 
-        was_error = SDL_FALSE;
+        was_error = false;
     }
 
 done:
@@ -857,17 +861,17 @@ done:
         SDL_DestroySurface(intermediate_surface);
     }
     if (closeio && dst) {
-        if (SDL_CloseIO(dst) < 0) {
-            was_error = SDL_TRUE;
+        if (!SDL_CloseIO(dst)) {
+            was_error = true;
         }
     }
     if (was_error) {
-        return -1;
+        return false;
     }
-    return 0;
+    return true;
 }
 
-int SDL_SaveBMP(SDL_Surface *surface, const char *file)
+bool SDL_SaveBMP(SDL_Surface *surface, const char *file)
 {
-    return SDL_SaveBMP_IO(surface, SDL_IOFromFile(file, "wb"), 1);
+    return SDL_SaveBMP_IO(surface, SDL_IOFromFile(file, "wb"), true);
 }
