@@ -20,7 +20,7 @@
 */
 #include "SDL_internal.h"
 
-/* NSOpenGL implementation of SDL OpenGL support */
+// NSOpenGL implementation of SDL OpenGL support
 
 #ifdef SDL_VIDEO_OPENGL_CGL
 #include "SDL_cocoavideo.h"
@@ -36,13 +36,13 @@
 
 #define DEFAULT_OPENGL "/System/Library/Frameworks/OpenGL.framework/Libraries/libGL.dylib"
 
-/* We still support OpenGL as long as Apple offers it, deprecated or not, so disable deprecation warnings about it. */
+// We still support OpenGL as long as Apple offers it, deprecated or not, so disable deprecation warnings about it.
 #ifdef __clang__
 #pragma clang diagnostic push
 #pragma clang diagnostic ignored "-Wdeprecated-declarations"
 #endif
 
-/* _Nullable is available starting Xcode 7 */
+// _Nullable is available starting Xcode 7
 #ifdef __has_feature
 #if __has_feature(nullability)
 #define HAS_FEATURE_NULLABLE
@@ -52,22 +52,22 @@
 #define _Nullable
 #endif
 
-static SDL_bool SDL_opengl_async_dispatch = SDL_FALSE;
+static bool SDL_opengl_async_dispatch = false;
 
 static void SDLCALL SDL_OpenGLAsyncDispatchChanged(void *userdata, const char *name, const char *oldValue, const char *hint)
 {
-    SDL_opengl_async_dispatch = SDL_GetStringBoolean(hint, SDL_FALSE);
+    SDL_opengl_async_dispatch = SDL_GetStringBoolean(hint, false);
 }
 
 static CVReturn DisplayLinkCallback(CVDisplayLinkRef displayLink, const CVTimeStamp *now, const CVTimeStamp *outputTime, CVOptionFlags flagsIn, CVOptionFlags *flagsOut, void *displayLinkContext)
 {
-    SDLOpenGLContext *nscontext = (__bridge SDLOpenGLContext *)displayLinkContext;
+    SDL3OpenGLContext *nscontext = (__bridge SDL3OpenGLContext *)displayLinkContext;
 
-    /*printf("DISPLAY LINK! %u\n", (unsigned int) SDL_GetTicks()); */
-    const int setting = SDL_AtomicGet(&nscontext->swapIntervalSetting);
-    if (setting != 0) { /* nothing to do if vsync is disabled, don't even lock */
+    // printf("DISPLAY LINK! %u\n", (unsigned int) SDL_GetTicks());
+    const int setting = SDL_GetAtomicInt(&nscontext->swapIntervalSetting);
+    if (setting != 0) { // nothing to do if vsync is disabled, don't even lock
         SDL_LockMutex(nscontext->swapIntervalMutex);
-        SDL_AtomicAdd(&nscontext->swapIntervalsPassed, 1);
+        SDL_AddAtomicInt(&nscontext->swapIntervalsPassed, 1);
         SDL_SignalCondition(nscontext->swapIntervalCond);
         SDL_UnlockMutex(nscontext->swapIntervalMutex);
     }
@@ -75,7 +75,7 @@ static CVReturn DisplayLinkCallback(CVDisplayLinkRef displayLink, const CVTimeSt
     return kCVReturnSuccess;
 }
 
-@implementation SDLOpenGLContext : NSOpenGLContext
+@implementation SDL3OpenGLContext : NSOpenGLContext
 
 - (id)initWithFormat:(NSOpenGLPixelFormat *)format
         shareContext:(NSOpenGLContext *)share
@@ -83,17 +83,17 @@ static CVReturn DisplayLinkCallback(CVDisplayLinkRef displayLink, const CVTimeSt
     self = [super initWithFormat:format shareContext:share];
     if (self) {
         self.openglPixelFormat = format;
-        SDL_AtomicSet(&self->dirty, 0);
+        SDL_SetAtomicInt(&self->dirty, 0);
         self->window = NULL;
-        SDL_AtomicSet(&self->swapIntervalSetting, 0);
-        SDL_AtomicSet(&self->swapIntervalsPassed, 0);
+        SDL_SetAtomicInt(&self->swapIntervalSetting, 0);
+        SDL_SetAtomicInt(&self->swapIntervalsPassed, 0);
         self->swapIntervalCond = SDL_CreateCondition();
         self->swapIntervalMutex = SDL_CreateMutex();
         if (!self->swapIntervalCond || !self->swapIntervalMutex) {
             return nil;
         }
 
-        /* !!! FIXME: check return values. */
+        // !!! FIXME: check return values.
         CVDisplayLinkCreateWithActiveCGDisplays(&self->displayLink);
         CVDisplayLinkSetOutputCallback(self->displayLink, &DisplayLinkCallback, (__bridge void *_Nullable)self);
         CVDisplayLinkSetCurrentCGDisplayFromOpenGLContext(self->displayLink, [self CGLContextObj], [format CGLPixelFormatObj]);
@@ -113,34 +113,34 @@ static CVReturn DisplayLinkCallback(CVDisplayLinkRef displayLink, const CVTimeSt
 
 - (void)scheduleUpdate
 {
-    SDL_AtomicAdd(&self->dirty, 1);
+    SDL_AddAtomicInt(&self->dirty, 1);
 }
 
-/* This should only be called on the thread on which a user is using the context. */
+// This should only be called on the thread on which a user is using the context.
 - (void)updateIfNeeded
 {
-    const int value = SDL_AtomicSet(&self->dirty, 0);
+    const int value = SDL_SetAtomicInt(&self->dirty, 0);
     if (value > 0) {
-        /* We call the real underlying update here, since -[SDLOpenGLContext update] just calls us. */
+        // We call the real underlying update here, since -[SDL3OpenGLContext update] just calls us.
         [self explicitUpdate];
     }
 }
 
-/* This should only be called on the thread on which a user is using the context. */
+// This should only be called on the thread on which a user is using the context.
 - (void)update
 {
-    /* This ensures that regular 'update' calls clear the atomic dirty flag. */
+    // This ensures that regular 'update' calls clear the atomic dirty flag.
     [self scheduleUpdate];
     [self updateIfNeeded];
 }
 
-/* Updates the drawable for the contexts and manages related state. */
+// Updates the drawable for the contexts and manages related state.
 - (void)setWindow:(SDL_Window *)newWindow
 {
     if (self->window) {
-        SDL_CocoaWindowData *oldwindowdata = (__bridge SDL_CocoaWindowData *)self->window->driverdata;
+        SDL_CocoaWindowData *oldwindowdata = (__bridge SDL_CocoaWindowData *)self->window->internal;
 
-        /* Make sure to remove us from the old window's context list, or we'll get scheduled updates from it too. */
+        // Make sure to remove us from the old window's context list, or we'll get scheduled updates from it too.
         NSMutableArray *contexts = oldwindowdata.nscontexts;
         @synchronized(contexts) {
             [contexts removeObject:self];
@@ -150,10 +150,10 @@ static CVReturn DisplayLinkCallback(CVDisplayLinkRef displayLink, const CVTimeSt
     self->window = newWindow;
 
     if (newWindow) {
-        SDL_CocoaWindowData *windowdata = (__bridge SDL_CocoaWindowData *)newWindow->driverdata;
+        SDL_CocoaWindowData *windowdata = (__bridge SDL_CocoaWindowData *)newWindow->internal;
         NSView *contentview = windowdata.sdlContentView;
 
-        /* Now sign up for scheduled updates for the new window. */
+        // Now sign up for scheduled updates for the new window.
         NSMutableArray *contexts = windowdata.nscontexts;
         @synchronized(contexts) {
             [contexts addObject:self];
@@ -208,7 +208,7 @@ static CVReturn DisplayLinkCallback(CVDisplayLinkRef displayLink, const CVTimeSt
 {
     [self setWindow:NULL];
 
-    SDL_DelHintCallback(SDL_HINT_MAC_OPENGL_ASYNC_DISPATCH, SDL_OpenGLAsyncDispatchChanged, NULL);
+    SDL_RemoveHintCallback(SDL_HINT_MAC_OPENGL_ASYNC_DISPATCH, SDL_OpenGLAsyncDispatchChanged, NULL);
     if (self->displayLink) {
         CVDisplayLinkRelease(self->displayLink);
         self->displayLink = nil;
@@ -225,22 +225,22 @@ static CVReturn DisplayLinkCallback(CVDisplayLinkRef displayLink, const CVTimeSt
 
 @end
 
-int Cocoa_GL_LoadLibrary(SDL_VideoDevice *_this, const char *path)
+bool Cocoa_GL_LoadLibrary(SDL_VideoDevice *_this, const char *path)
 {
-    /* Load the OpenGL library */
+    // Load the OpenGL library
     if (path == NULL) {
-        path = SDL_getenv("SDL_OPENGL_LIBRARY");
+        path = SDL_GetHint(SDL_HINT_OPENGL_LIBRARY);
     }
     if (path == NULL) {
         path = DEFAULT_OPENGL;
     }
     _this->gl_config.dll_handle = SDL_LoadObject(path);
     if (!_this->gl_config.dll_handle) {
-        return -1;
+        return false;
     }
     SDL_strlcpy(_this->gl_config.driver_path, path,
                 SDL_arraysize(_this->gl_config.driver_path));
-    return 0;
+    return true;
 }
 
 SDL_FunctionPointer Cocoa_GL_GetProcAddress(SDL_VideoDevice *_this, const char *proc)
@@ -258,10 +258,10 @@ SDL_GLContext Cocoa_GL_CreateContext(SDL_VideoDevice *_this, SDL_Window *window)
 {
     @autoreleasepool {
         SDL_VideoDisplay *display = SDL_GetVideoDisplayForWindow(window);
-        SDL_DisplayData *displaydata = (SDL_DisplayData *)display->driverdata;
+        SDL_DisplayData *displaydata = (SDL_DisplayData *)display->internal;
         NSOpenGLPixelFormatAttribute attr[32];
         NSOpenGLPixelFormat *fmt;
-        SDLOpenGLContext *context;
+        SDL3OpenGLContext *context;
         SDL_GLContext sdlcontext;
         NSOpenGLContext *share_context = nil;
         int i = 0;
@@ -274,7 +274,7 @@ SDL_GLContext Cocoa_GL_CreateContext(SDL_VideoDevice *_this, SDL_Window *window)
 
         if (_this->gl_config.profile_mask == SDL_GL_CONTEXT_PROFILE_ES) {
 #ifdef SDL_VIDEO_OPENGL_EGL
-            /* Switch to EGL based functions */
+            // Switch to EGL based functions
             Cocoa_GL_UnloadLibrary(_this);
             _this->GL_LoadLibrary = Cocoa_GLES_LoadLibrary;
             _this->GL_GetProcAddress = Cocoa_GLES_GetProcAddress;
@@ -284,7 +284,7 @@ SDL_GLContext Cocoa_GL_CreateContext(SDL_VideoDevice *_this, SDL_Window *window)
             _this->GL_SetSwapInterval = Cocoa_GLES_SetSwapInterval;
             _this->GL_GetSwapInterval = Cocoa_GLES_GetSwapInterval;
             _this->GL_SwapWindow = Cocoa_GLES_SwapWindow;
-            _this->GL_DeleteContext = Cocoa_GLES_DeleteContext;
+            _this->GL_DestroyContext = Cocoa_GLES_DestroyContext;
 
             if (Cocoa_GLES_LoadLibrary(_this, NULL) != 0) {
                 return NULL;
@@ -369,7 +369,7 @@ SDL_GLContext Cocoa_GL_CreateContext(SDL_VideoDevice *_this, SDL_Window *window)
             share_context = (__bridge NSOpenGLContext *)SDL_GL_GetCurrentContext();
         }
 
-        context = [[SDLOpenGLContext alloc] initWithFormat:fmt shareContext:share_context];
+        context = [[SDL3OpenGLContext alloc] initWithFormat:fmt shareContext:share_context];
 
         if (context == nil) {
             SDL_SetError("Failed creating OpenGL context");
@@ -378,15 +378,15 @@ SDL_GLContext Cocoa_GL_CreateContext(SDL_VideoDevice *_this, SDL_Window *window)
 
         sdlcontext = (SDL_GLContext)CFBridgingRetain(context);
 
-        /* vsync is handled separately by synchronizing with a display link. */
+        // vsync is handled separately by synchronizing with a display link.
         interval = 0;
         [context setValues:&interval forParameter:NSOpenGLCPSwapInterval];
 
         opaque = (window->flags & SDL_WINDOW_TRANSPARENT) ? 0 : 1;
         [context setValues:&opaque forParameter:NSOpenGLCPSurfaceOpacity];
 
-        if (Cocoa_GL_MakeCurrent(_this, window, sdlcontext) < 0) {
-            SDL_GL_DeleteContext(sdlcontext);
+        if (!Cocoa_GL_MakeCurrent(_this, window, sdlcontext)) {
+            SDL_GL_DestroyContext(sdlcontext);
             SDL_SetError("Failed making OpenGL context current");
             return NULL;
         }
@@ -394,33 +394,33 @@ SDL_GLContext Cocoa_GL_CreateContext(SDL_VideoDevice *_this, SDL_Window *window)
         if (_this->gl_config.major_version < 3 &&
             _this->gl_config.profile_mask == 0 &&
             _this->gl_config.flags == 0) {
-            /* This is a legacy profile, so to match other backends, we're done. */
+            // This is a legacy profile, so to match other backends, we're done.
         } else {
             const GLubyte *(APIENTRY * glGetStringFunc)(GLenum);
 
             glGetStringFunc = (const GLubyte *(APIENTRY *)(GLenum))SDL_GL_GetProcAddress("glGetString");
             if (!glGetStringFunc) {
-                SDL_GL_DeleteContext(sdlcontext);
+                SDL_GL_DestroyContext(sdlcontext);
                 SDL_SetError("Failed getting OpenGL glGetString entry point");
                 return NULL;
             }
 
             glversion = (const char *)glGetStringFunc(GL_VERSION);
             if (glversion == NULL) {
-                SDL_GL_DeleteContext(sdlcontext);
+                SDL_GL_DestroyContext(sdlcontext);
                 SDL_SetError("Failed getting OpenGL context version");
                 return NULL;
             }
 
             if (SDL_sscanf(glversion, "%d.%d", &glversion_major, &glversion_minor) != 2) {
-                SDL_GL_DeleteContext(sdlcontext);
+                SDL_GL_DestroyContext(sdlcontext);
                 SDL_SetError("Failed parsing OpenGL context version");
                 return NULL;
             }
 
             if ((glversion_major < _this->gl_config.major_version) ||
                 ((glversion_major == _this->gl_config.major_version) && (glversion_minor < _this->gl_config.minor_version))) {
-                SDL_GL_DeleteContext(sdlcontext);
+                SDL_GL_DestroyContext(sdlcontext);
                 SDL_SetError("Failed creating OpenGL context at version requested");
                 return NULL;
             }
@@ -428,18 +428,18 @@ SDL_GLContext Cocoa_GL_CreateContext(SDL_VideoDevice *_this, SDL_Window *window)
             /* In the future we'll want to do this, but to match other platforms
                we'll leave the OpenGL version the way it is for now
              */
-            /*_this->gl_config.major_version = glversion_major;*/
-            /*_this->gl_config.minor_version = glversion_minor;*/
+            // _this->gl_config.major_version = glversion_major;
+            // _this->gl_config.minor_version = glversion_minor;
         }
         return sdlcontext;
     }
 }
 
-int Cocoa_GL_MakeCurrent(SDL_VideoDevice *_this, SDL_Window *window, SDL_GLContext context)
+bool Cocoa_GL_MakeCurrent(SDL_VideoDevice *_this, SDL_Window *window, SDL_GLContext context)
 {
     @autoreleasepool {
         if (context) {
-            SDLOpenGLContext *nscontext = (__bridge SDLOpenGLContext *)context;
+            SDL3OpenGLContext *nscontext = (__bridge SDL3OpenGLContext *)context;
             if ([nscontext window] != window) {
                 [nscontext setWindow:window];
                 [nscontext updateIfNeeded];
@@ -449,69 +449,69 @@ int Cocoa_GL_MakeCurrent(SDL_VideoDevice *_this, SDL_Window *window, SDL_GLConte
             [NSOpenGLContext clearCurrentContext];
         }
 
-        return 0;
+        return true;
     }
 }
 
-int Cocoa_GL_SetSwapInterval(SDL_VideoDevice *_this, int interval)
+bool Cocoa_GL_SetSwapInterval(SDL_VideoDevice *_this, int interval)
 {
     @autoreleasepool {
-        SDLOpenGLContext *nscontext = (__bridge SDLOpenGLContext *)SDL_GL_GetCurrentContext();
-        int status;
+        SDL3OpenGLContext *nscontext = (__bridge SDL3OpenGLContext *)SDL_GL_GetCurrentContext();
+        bool result;
 
         if (nscontext == nil) {
-            status = SDL_SetError("No current OpenGL context");
+            result = SDL_SetError("No current OpenGL context");
         } else {
             SDL_LockMutex(nscontext->swapIntervalMutex);
-            SDL_AtomicSet(&nscontext->swapIntervalsPassed, 0);
-            SDL_AtomicSet(&nscontext->swapIntervalSetting, interval);
+            SDL_SetAtomicInt(&nscontext->swapIntervalsPassed, 0);
+            SDL_SetAtomicInt(&nscontext->swapIntervalSetting, interval);
             SDL_UnlockMutex(nscontext->swapIntervalMutex);
-            status = 0;
+            result = true;
         }
 
-        return status;
+        return result;
     }
 }
 
-int Cocoa_GL_GetSwapInterval(SDL_VideoDevice *_this, int *interval)
+bool Cocoa_GL_GetSwapInterval(SDL_VideoDevice *_this, int *interval)
 {
     @autoreleasepool {
-        SDLOpenGLContext *nscontext = (__bridge SDLOpenGLContext *)SDL_GL_GetCurrentContext();
+        SDL3OpenGLContext *nscontext = (__bridge SDL3OpenGLContext *)SDL_GL_GetCurrentContext();
         if (nscontext) {
-            *interval = SDL_AtomicGet(&nscontext->swapIntervalSetting);
-            return 0;
+            *interval = SDL_GetAtomicInt(&nscontext->swapIntervalSetting);
+            return true;
         } else {
             return SDL_SetError("no OpenGL context");
         }
     }
 }
 
-int Cocoa_GL_SwapWindow(SDL_VideoDevice *_this, SDL_Window *window)
+bool Cocoa_GL_SwapWindow(SDL_VideoDevice *_this, SDL_Window *window)
 {
     @autoreleasepool {
-        SDLOpenGLContext *nscontext = (__bridge SDLOpenGLContext *)SDL_GL_GetCurrentContext();
-        SDL_CocoaVideoData *videodata = (__bridge SDL_CocoaVideoData *)_this->driverdata;
-        const int setting = SDL_AtomicGet(&nscontext->swapIntervalSetting);
+        SDL3OpenGLContext *nscontext = (__bridge SDL3OpenGLContext *)SDL_GL_GetCurrentContext();
+        SDL_CocoaVideoData *videodata = (__bridge SDL_CocoaVideoData *)_this->internal;
+        const int setting = SDL_GetAtomicInt(&nscontext->swapIntervalSetting);
 
         if (setting == 0) {
-            /* nothing to do if vsync is disabled, don't even lock */
-        } else if (setting < 0) { /* late swap tearing */
+            // nothing to do if vsync is disabled, don't even lock
+        } else if (setting < 0) { // late swap tearing
             SDL_LockMutex(nscontext->swapIntervalMutex);
-            while (SDL_AtomicGet(&nscontext->swapIntervalsPassed) == 0) {
+            while (SDL_GetAtomicInt(&nscontext->swapIntervalsPassed) == 0) {
                 SDL_WaitCondition(nscontext->swapIntervalCond, nscontext->swapIntervalMutex);
             }
-            SDL_AtomicSet(&nscontext->swapIntervalsPassed, 0);
+            SDL_SetAtomicInt(&nscontext->swapIntervalsPassed, 0);
             SDL_UnlockMutex(nscontext->swapIntervalMutex);
         } else {
             SDL_LockMutex(nscontext->swapIntervalMutex);
-            do { /* always wait here so we know we just hit a swap interval. */
+            do { // always wait here so we know we just hit a swap interval.
                 SDL_WaitCondition(nscontext->swapIntervalCond, nscontext->swapIntervalMutex);
-            } while ((SDL_AtomicGet(&nscontext->swapIntervalsPassed) % setting) != 0);
-            SDL_AtomicSet(&nscontext->swapIntervalsPassed, 0);
+            } while ((SDL_GetAtomicInt(&nscontext->swapIntervalsPassed) % setting) != 0);
+            SDL_SetAtomicInt(&nscontext->swapIntervalsPassed, 0);
             SDL_UnlockMutex(nscontext->swapIntervalMutex);
         }
 
-        /*{ static Uint64 prev = 0; const Uint64 now = SDL_GetTicks(); const unsigned int diff = (unsigned int) (now - prev); prev = now; printf("GLSWAPBUFFERS TICKS %u\n", diff); }*/
+        // { static Uint64 prev = 0; const Uint64 now = SDL_GetTicks(); const unsigned int diff = (unsigned int) (now - prev); prev = now; printf("GLSWAPBUFFERS TICKS %u\n", diff); }
 
         /* on 10.14 ("Mojave") and later, this deadlocks if two contexts in two
            threads try to swap at the same time, so put a mutex around it. */
@@ -519,23 +519,23 @@ int Cocoa_GL_SwapWindow(SDL_VideoDevice *_this, SDL_Window *window)
         [nscontext flushBuffer];
         [nscontext updateIfNeeded];
         SDL_UnlockMutex(videodata.swaplock);
-        return 0;
+        return true;
     }
 }
 
-int Cocoa_GL_DeleteContext(SDL_VideoDevice *_this, SDL_GLContext context)
+bool Cocoa_GL_DestroyContext(SDL_VideoDevice *_this, SDL_GLContext context)
 {
     @autoreleasepool {
-        SDLOpenGLContext *nscontext = (__bridge SDLOpenGLContext *)context;
+        SDL3OpenGLContext *nscontext = (__bridge SDL3OpenGLContext *)context;
         [nscontext cleanup];
         CFRelease(context);
     }
-    return 0;
+    return true;
 }
 
-/* We still support OpenGL as long as Apple offers it, deprecated or not, so disable deprecation warnings about it. */
+// We still support OpenGL as long as Apple offers it, deprecated or not, so disable deprecation warnings about it.
 #ifdef __clang__
 #pragma clang diagnostic pop
 #endif
 
-#endif /* SDL_VIDEO_OPENGL_CGL */
+#endif // SDL_VIDEO_OPENGL_CGL
