@@ -33,237 +33,6 @@
 #include "SDL_emscriptenevents.h"
 #include "SDL_emscriptenvideo.h"
 
-/*
-.keyCode to SDL keycode
-https://developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent
-https://developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/keyCode
-*/
-static const SDL_Keycode emscripten_keycode_table[] = {
-    /*  0 */ SDLK_UNKNOWN,
-    /*  1 */ SDLK_UNKNOWN,
-    /*  2 */ SDLK_UNKNOWN,
-    /*  3 */ SDLK_CANCEL,
-    /*  4 */ SDLK_UNKNOWN,
-    /*  5 */ SDLK_UNKNOWN,
-    /*  6 */ SDLK_HELP,
-    /*  7 */ SDLK_UNKNOWN,
-    /*  8 */ SDLK_BACKSPACE,
-    /*  9 */ SDLK_TAB,
-    /*  10 */ SDLK_UNKNOWN,
-    /*  11 */ SDLK_UNKNOWN,
-    /*  12 */ SDLK_KP_5,
-    /*  13 */ SDLK_RETURN,
-    /*  14 */ SDLK_UNKNOWN,
-    /*  15 */ SDLK_UNKNOWN,
-    /*  16 */ SDLK_LSHIFT,
-    /*  17 */ SDLK_LCTRL,
-    /*  18 */ SDLK_LALT,
-    /*  19 */ SDLK_PAUSE,
-    /*  20 */ SDLK_CAPSLOCK,
-    /*  21 */ SDLK_UNKNOWN,
-    /*  22 */ SDLK_UNKNOWN,
-    /*  23 */ SDLK_UNKNOWN,
-    /*  24 */ SDLK_UNKNOWN,
-    /*  25 */ SDLK_UNKNOWN,
-    /*  26 */ SDLK_UNKNOWN,
-    /*  27 */ SDLK_ESCAPE,
-    /*  28 */ SDLK_UNKNOWN,
-    /*  29 */ SDLK_UNKNOWN,
-    /*  30 */ SDLK_UNKNOWN,
-    /*  31 */ SDLK_UNKNOWN,
-    /*  32 */ SDLK_SPACE,
-    /*  33 */ SDLK_PAGEUP,
-    /*  34 */ SDLK_PAGEDOWN,
-    /*  35 */ SDLK_END,
-    /*  36 */ SDLK_HOME,
-    /*  37 */ SDLK_LEFT,
-    /*  38 */ SDLK_UP,
-    /*  39 */ SDLK_RIGHT,
-    /*  40 */ SDLK_DOWN,
-    /*  41 */ SDLK_UNKNOWN,
-    /*  42 */ SDLK_UNKNOWN,
-    /*  43 */ SDLK_UNKNOWN,
-    /*  44 */ SDLK_UNKNOWN,
-    /*  45 */ SDLK_INSERT,
-    /*  46 */ SDLK_DELETE,
-    /*  47 */ SDLK_UNKNOWN,
-    /*  48 */ SDLK_0,
-    /*  49 */ SDLK_1,
-    /*  50 */ SDLK_2,
-    /*  51 */ SDLK_3,
-    /*  52 */ SDLK_4,
-    /*  53 */ SDLK_5,
-    /*  54 */ SDLK_6,
-    /*  55 */ SDLK_7,
-    /*  56 */ SDLK_8,
-    /*  57 */ SDLK_9,
-    /*  58 */ SDLK_UNKNOWN,
-    /*  59 */ SDLK_SEMICOLON,
-    /*  60 */ SDLK_BACKSLASH /*SDL_SCANCODE_NONUSBACKSLASH*/,
-    /*  61 */ SDLK_EQUALS,
-    /*  62 */ SDLK_UNKNOWN,
-    /*  63 */ SDLK_MINUS,
-    /*  64 */ SDLK_UNKNOWN,
-    /*  65 */ SDLK_a,
-    /*  66 */ SDLK_b,
-    /*  67 */ SDLK_c,
-    /*  68 */ SDLK_d,
-    /*  69 */ SDLK_e,
-    /*  70 */ SDLK_f,
-    /*  71 */ SDLK_g,
-    /*  72 */ SDLK_h,
-    /*  73 */ SDLK_i,
-    /*  74 */ SDLK_j,
-    /*  75 */ SDLK_k,
-    /*  76 */ SDLK_l,
-    /*  77 */ SDLK_m,
-    /*  78 */ SDLK_n,
-    /*  79 */ SDLK_o,
-    /*  80 */ SDLK_p,
-    /*  81 */ SDLK_q,
-    /*  82 */ SDLK_r,
-    /*  83 */ SDLK_s,
-    /*  84 */ SDLK_t,
-    /*  85 */ SDLK_u,
-    /*  86 */ SDLK_v,
-    /*  87 */ SDLK_w,
-    /*  88 */ SDLK_x,
-    /*  89 */ SDLK_y,
-    /*  90 */ SDLK_z,
-    /*  91 */ SDLK_LGUI,
-    /*  92 */ SDLK_UNKNOWN,
-    /*  93 */ SDLK_APPLICATION,
-    /*  94 */ SDLK_UNKNOWN,
-    /*  95 */ SDLK_UNKNOWN,
-    /*  96 */ SDLK_KP_0,
-    /*  97 */ SDLK_KP_1,
-    /*  98 */ SDLK_KP_2,
-    /*  99 */ SDLK_KP_3,
-    /* 100 */ SDLK_KP_4,
-    /* 101 */ SDLK_KP_5,
-    /* 102 */ SDLK_KP_6,
-    /* 103 */ SDLK_KP_7,
-    /* 104 */ SDLK_KP_8,
-    /* 105 */ SDLK_KP_9,
-    /* 106 */ SDLK_KP_MULTIPLY,
-    /* 107 */ SDLK_KP_PLUS,
-    /* 108 */ SDLK_UNKNOWN,
-    /* 109 */ SDLK_KP_MINUS,
-    /* 110 */ SDLK_KP_PERIOD,
-    /* 111 */ SDLK_KP_DIVIDE,
-    /* 112 */ SDLK_F1,
-    /* 113 */ SDLK_F2,
-    /* 114 */ SDLK_F3,
-    /* 115 */ SDLK_F4,
-    /* 116 */ SDLK_F5,
-    /* 117 */ SDLK_F6,
-    /* 118 */ SDLK_F7,
-    /* 119 */ SDLK_F8,
-    /* 120 */ SDLK_F9,
-    /* 121 */ SDLK_F10,
-    /* 122 */ SDLK_F11,
-    /* 123 */ SDLK_F12,
-    /* 124 */ SDLK_F13,
-    /* 125 */ SDLK_F14,
-    /* 126 */ SDLK_F15,
-    /* 127 */ SDLK_F16,
-    /* 128 */ SDLK_F17,
-    /* 129 */ SDLK_F18,
-    /* 130 */ SDLK_F19,
-    /* 131 */ SDLK_F20,
-    /* 132 */ SDLK_F21,
-    /* 133 */ SDLK_F22,
-    /* 134 */ SDLK_F23,
-    /* 135 */ SDLK_F24,
-    /* 136 */ SDLK_UNKNOWN,
-    /* 137 */ SDLK_UNKNOWN,
-    /* 138 */ SDLK_UNKNOWN,
-    /* 139 */ SDLK_UNKNOWN,
-    /* 140 */ SDLK_UNKNOWN,
-    /* 141 */ SDLK_UNKNOWN,
-    /* 142 */ SDLK_UNKNOWN,
-    /* 143 */ SDLK_UNKNOWN,
-    /* 144 */ SDLK_NUMLOCKCLEAR,
-    /* 145 */ SDLK_SCROLLLOCK,
-    /* 146 */ SDLK_UNKNOWN,
-    /* 147 */ SDLK_UNKNOWN,
-    /* 148 */ SDLK_UNKNOWN,
-    /* 149 */ SDLK_UNKNOWN,
-    /* 150 */ SDLK_UNKNOWN,
-    /* 151 */ SDLK_UNKNOWN,
-    /* 152 */ SDLK_UNKNOWN,
-    /* 153 */ SDLK_UNKNOWN,
-    /* 154 */ SDLK_UNKNOWN,
-    /* 155 */ SDLK_UNKNOWN,
-    /* 156 */ SDLK_UNKNOWN,
-    /* 157 */ SDLK_UNKNOWN,
-    /* 158 */ SDLK_UNKNOWN,
-    /* 159 */ SDLK_UNKNOWN,
-    /* 160 */ SDLK_BACKQUOTE,
-    /* 161 */ SDLK_UNKNOWN,
-    /* 162 */ SDLK_UNKNOWN,
-    /* 163 */ SDLK_KP_HASH, /*KaiOS phone keypad*/
-    /* 164 */ SDLK_UNKNOWN,
-    /* 165 */ SDLK_UNKNOWN,
-    /* 166 */ SDLK_UNKNOWN,
-    /* 167 */ SDLK_UNKNOWN,
-    /* 168 */ SDLK_UNKNOWN,
-    /* 169 */ SDLK_UNKNOWN,
-    /* 170 */ SDLK_KP_MULTIPLY, /*KaiOS phone keypad*/
-    /* 171 */ SDLK_RIGHTBRACKET,
-    /* 172 */ SDLK_UNKNOWN,
-    /* 173 */ SDLK_MINUS,      /*FX*/
-    /* 174 */ SDLK_VOLUMEDOWN, /*IE, Chrome*/
-    /* 175 */ SDLK_VOLUMEUP,   /*IE, Chrome*/
-    /* 176 */ SDLK_AUDIONEXT,  /*IE, Chrome*/
-    /* 177 */ SDLK_AUDIOPREV,  /*IE, Chrome*/
-    /* 178 */ SDLK_UNKNOWN,
-    /* 179 */ SDLK_AUDIOPLAY, /*IE, Chrome*/
-    /* 180 */ SDLK_UNKNOWN,
-    /* 181 */ SDLK_AUDIOMUTE,  /*FX*/
-    /* 182 */ SDLK_VOLUMEDOWN, /*FX*/
-    /* 183 */ SDLK_VOLUMEUP,   /*FX*/
-    /* 184 */ SDLK_UNKNOWN,
-    /* 185 */ SDLK_UNKNOWN,
-    /* 186 */ SDLK_SEMICOLON, /*IE, Chrome, D3E legacy*/
-    /* 187 */ SDLK_EQUALS,    /*IE, Chrome, D3E legacy*/
-    /* 188 */ SDLK_COMMA,
-    /* 189 */ SDLK_MINUS, /*IE, Chrome, D3E legacy*/
-    /* 190 */ SDLK_PERIOD,
-    /* 191 */ SDLK_SLASH,
-    /* 192 */ SDLK_BACKQUOTE, /*FX, D3E legacy (SDLK_APOSTROPHE in IE/Chrome)*/
-    /* 193 */ SDLK_UNKNOWN,
-    /* 194 */ SDLK_UNKNOWN,
-    /* 195 */ SDLK_UNKNOWN,
-    /* 196 */ SDLK_UNKNOWN,
-    /* 197 */ SDLK_UNKNOWN,
-    /* 198 */ SDLK_UNKNOWN,
-    /* 199 */ SDLK_UNKNOWN,
-    /* 200 */ SDLK_UNKNOWN,
-    /* 201 */ SDLK_UNKNOWN,
-    /* 202 */ SDLK_UNKNOWN,
-    /* 203 */ SDLK_UNKNOWN,
-    /* 204 */ SDLK_UNKNOWN,
-    /* 205 */ SDLK_UNKNOWN,
-    /* 206 */ SDLK_UNKNOWN,
-    /* 207 */ SDLK_UNKNOWN,
-    /* 208 */ SDLK_UNKNOWN,
-    /* 209 */ SDLK_UNKNOWN,
-    /* 210 */ SDLK_UNKNOWN,
-    /* 211 */ SDLK_UNKNOWN,
-    /* 212 */ SDLK_UNKNOWN,
-    /* 213 */ SDLK_UNKNOWN,
-    /* 214 */ SDLK_UNKNOWN,
-    /* 215 */ SDLK_UNKNOWN,
-    /* 216 */ SDLK_UNKNOWN,
-    /* 217 */ SDLK_UNKNOWN,
-    /* 218 */ SDLK_UNKNOWN,
-    /* 219 */ SDLK_LEFTBRACKET,
-    /* 220 */ SDLK_BACKSLASH,
-    /* 221 */ SDLK_RIGHTBRACKET,
-    /* 222 */ SDLK_QUOTE, /*FX, D3E legacy*/
-};
-
 /*
 Emscripten PK code to scancode
 https://developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent
@@ -410,27 +179,25 @@ static SDL_Scancode Emscripten_MapScanCode(const char *code)
     case DOM_PK_PASTE:
         return SDL_SCANCODE_PASTE;
     case DOM_PK_MEDIA_TRACK_PREVIOUS:
-        return SDL_SCANCODE_AUDIOPREV;
+        return SDL_SCANCODE_MEDIA_PREVIOUS_TRACK;
     case DOM_PK_CUT:
         return SDL_SCANCODE_CUT;
     case DOM_PK_COPY:
         return SDL_SCANCODE_COPY;
     case DOM_PK_MEDIA_TRACK_NEXT:
-        return SDL_SCANCODE_AUDIONEXT;
+        return SDL_SCANCODE_MEDIA_NEXT_TRACK;
     case DOM_PK_NUMPAD_ENTER:
         return SDL_SCANCODE_KP_ENTER;
     case DOM_PK_CONTROL_RIGHT:
         return SDL_SCANCODE_RCTRL;
     case DOM_PK_AUDIO_VOLUME_MUTE:
-        return SDL_SCANCODE_AUDIOMUTE;
-    case DOM_PK_LAUNCH_APP_2:
-        return SDL_SCANCODE_CALCULATOR;
+        return SDL_SCANCODE_MUTE;
     case DOM_PK_MEDIA_PLAY_PAUSE:
-        return SDL_SCANCODE_AUDIOPLAY;
+        return SDL_SCANCODE_MEDIA_PLAY_PAUSE;
     case DOM_PK_MEDIA_STOP:
-        return SDL_SCANCODE_AUDIOSTOP;
+        return SDL_SCANCODE_MEDIA_STOP;
     case DOM_PK_EJECT:
-        return SDL_SCANCODE_EJECT;
+        return SDL_SCANCODE_MEDIA_EJECT;
     case DOM_PK_AUDIO_VOLUME_DOWN:
         return SDL_SCANCODE_VOLUMEDOWN;
     case DOM_PK_AUDIO_VOLUME_UP:
@@ -485,128 +252,17 @@ static SDL_Scancode Emscripten_MapScanCode(const char *code)
         return SDL_SCANCODE_AC_FORWARD;
     case DOM_PK_BROWSER_BACK:
         return SDL_SCANCODE_AC_BACK;
-    case DOM_PK_LAUNCH_APP_1:
-        return SDL_SCANCODE_COMPUTER;
-    case DOM_PK_LAUNCH_MAIL:
-        return SDL_SCANCODE_MAIL;
     case DOM_PK_MEDIA_SELECT:
-        return SDL_SCANCODE_MEDIASELECT;
+        return SDL_SCANCODE_MEDIA_SELECT;
     }
 
     return SDL_SCANCODE_UNKNOWN;
 }
 
-static SDL_Keycode Emscripten_MapKeyCode(const EmscriptenKeyboardEvent *keyEvent)
-{
-    SDL_Keycode keycode = SDLK_UNKNOWN;
-    if (keyEvent->keyCode < SDL_arraysize(emscripten_keycode_table)) {
-        keycode = emscripten_keycode_table[keyEvent->keyCode];
-        if (keycode != SDLK_UNKNOWN) {
-            if (keyEvent->location == DOM_KEY_LOCATION_RIGHT) {
-                switch (keycode) {
-                case SDLK_LSHIFT:
-                    keycode = SDLK_RSHIFT;
-                    break;
-                case SDLK_LCTRL:
-                    keycode = SDLK_RCTRL;
-                    break;
-                case SDLK_LALT:
-                    keycode = SDLK_RALT;
-                    break;
-                case SDLK_LGUI:
-                    keycode = SDLK_RGUI;
-                    break;
-                default:
-                    break;
-                }
-            } else if (keyEvent->location == DOM_KEY_LOCATION_NUMPAD) {
-                switch (keycode) {
-                case SDLK_0:
-                case SDLK_INSERT:
-                    keycode = SDLK_KP_0;
-                    break;
-                case SDLK_1:
-                case SDLK_END:
-                    keycode = SDLK_KP_1;
-                    break;
-                case SDLK_2:
-                case SDLK_DOWN:
-                    keycode = SDLK_KP_2;
-                    break;
-                case SDLK_3:
-                case SDLK_PAGEDOWN:
-                    keycode = SDLK_KP_3;
-                    break;
-                case SDLK_4:
-                case SDLK_LEFT:
-                    keycode = SDLK_KP_4;
-                    break;
-                case SDLK_5:
-                    keycode = SDLK_KP_5;
-                    break;
-                case SDLK_6:
-                case SDLK_RIGHT:
-                    keycode = SDLK_KP_6;
-                    break;
-                case SDLK_7:
-                case SDLK_HOME:
-                    keycode = SDLK_KP_7;
-                    break;
-                case SDLK_8:
-                case SDLK_UP:
-                    keycode = SDLK_KP_8;
-                    break;
-                case SDLK_9:
-                case SDLK_PAGEUP:
-                    keycode = SDLK_KP_9;
-                    break;
-                case SDLK_RETURN:
-                    keycode = SDLK_KP_ENTER;
-                    break;
-                case SDLK_DELETE:
-                    keycode = SDLK_KP_PERIOD;
-                    break;
-                default:
-                    break;
-                }
-            }
-        }
-    }
-
-    return keycode;
-}
-
-/* "borrowed" from SDL_windowsevents.c */
-static int Emscripten_ConvertUTF32toUTF8(Uint32 codepoint, char *text)
-{
-    if (codepoint <= 0x7F) {
-        text[0] = (char)codepoint;
-        text[1] = '\0';
-    } else if (codepoint <= 0x7FF) {
-        text[0] = 0xC0 | (char)((codepoint >> 6) & 0x1F);
-        text[1] = 0x80 | (char)(codepoint & 0x3F);
-        text[2] = '\0';
-    } else if (codepoint <= 0xFFFF) {
-        text[0] = 0xE0 | (char)((codepoint >> 12) & 0x0F);
-        text[1] = 0x80 | (char)((codepoint >> 6) & 0x3F);
-        text[2] = 0x80 | (char)(codepoint & 0x3F);
-        text[3] = '\0';
-    } else if (codepoint <= 0x10FFFF) {
-        text[0] = 0xF0 | (char)((codepoint >> 18) & 0x0F);
-        text[1] = 0x80 | (char)((codepoint >> 12) & 0x3F);
-        text[2] = 0x80 | (char)((codepoint >> 6) & 0x3F);
-        text[3] = 0x80 | (char)(codepoint & 0x3F);
-        text[4] = '\0';
-    } else {
-        return SDL_FALSE;
-    }
-    return SDL_TRUE;
-}
-
 static EM_BOOL Emscripten_HandlePointerLockChange(int eventType, const EmscriptenPointerlockChangeEvent *changeEvent, void *userData)
 {
     SDL_WindowData *window_data = (SDL_WindowData *)userData;
-    /* keep track of lock losses, so we can regrab if/when appropriate. */
+    // keep track of lock losses, so we can regrab if/when appropriate.
     window_data->has_pointer_lock = changeEvent->isActive;
     return 0;
 }
@@ -614,10 +270,10 @@ static EM_BOOL Emscripten_HandlePointerLockChange(int eventType, const Emscripte
 static EM_BOOL Emscripten_HandleMouseMove(int eventType, const EmscriptenMouseEvent *mouseEvent, void *userData)
 {
     SDL_WindowData *window_data = userData;
-    const SDL_bool isPointerLocked = window_data->has_pointer_lock;
+    const bool isPointerLocked = window_data->has_pointer_lock;
     float mx, my;
 
-    /* rescale (in case canvas is being scaled)*/
+    // rescale (in case canvas is being scaled)
     double client_w, client_h, xscale, yscale;
     emscripten_get_element_css_size(window_data->canvas_id, &client_w, &client_h);
     xscale = window_data->window->w / client_w;
@@ -639,10 +295,9 @@ static EM_BOOL Emscripten_HandleMouseButton(int eventType, const EmscriptenMouse
 {
     SDL_WindowData *window_data = userData;
     Uint8 sdl_button;
-    Uint8 sdl_button_state;
-    SDL_EventType sdl_event_type;
+    bool sdl_button_state;
     double css_w, css_h;
-    SDL_bool prevent_default = SDL_FALSE; /* needed for iframe implementation in Chrome-based browsers. */
+    bool prevent_default = false; // needed for iframe implementation in Chrome-based browsers.
 
     switch (mouseEvent->button) {
     case 0:
@@ -660,18 +315,16 @@ static EM_BOOL Emscripten_HandleMouseButton(int eventType, const EmscriptenMouse
 
     if (eventType == EMSCRIPTEN_EVENT_MOUSEDOWN) {
         if (SDL_GetMouse()->relative_mode && !window_data->has_pointer_lock) {
-            emscripten_request_pointerlock(window_data->canvas_id, 0); /* try to regrab lost pointer lock. */
+            emscripten_request_pointerlock(window_data->canvas_id, 0); // try to regrab lost pointer lock.
         }
-        sdl_button_state = SDL_PRESSED;
-        sdl_event_type = SDL_EVENT_MOUSE_BUTTON_DOWN;
+        sdl_button_state = true;
     } else {
-        sdl_button_state = SDL_RELEASED;
-        sdl_event_type = SDL_EVENT_MOUSE_BUTTON_UP;
-        prevent_default = SDL_EventEnabled(sdl_event_type);
+        sdl_button_state = false;
+        prevent_default = SDL_EventEnabled(SDL_EVENT_MOUSE_BUTTON_UP);
     }
-    SDL_SendMouseButton(0, window_data->window, SDL_DEFAULT_MOUSE_ID, sdl_button_state, sdl_button);
+    SDL_SendMouseButton(0, window_data->window, SDL_DEFAULT_MOUSE_ID, sdl_button, sdl_button_state);
 
-    /* Do not consume the event if the mouse is outside of the canvas. */
+    // Do not consume the event if the mouse is outside of the canvas.
     emscripten_get_element_css_size(window_data->canvas_id, &css_w, &css_h);
     if (mouseEvent->targetX < 0 || mouseEvent->targetX >= css_w ||
         mouseEvent->targetY < 0 || mouseEvent->targetY >= css_h) {
@@ -685,10 +338,10 @@ static EM_BOOL Emscripten_HandleMouseFocus(int eventType, const EmscriptenMouseE
 {
     SDL_WindowData *window_data = userData;
 
-    const SDL_bool isPointerLocked = window_data->has_pointer_lock;
+    const bool isPointerLocked = window_data->has_pointer_lock;
 
     if (!isPointerLocked) {
-        /* rescale (in case canvas is being scaled)*/
+        // rescale (in case canvas is being scaled)
         float mx, my;
         double client_w, client_h;
         emscripten_get_element_css_size(window_data->canvas_id, &client_w, &client_h);
@@ -710,13 +363,13 @@ static EM_BOOL Emscripten_HandleWheel(int eventType, const EmscriptenWheelEvent
 
     switch (wheelEvent->deltaMode) {
     case DOM_DELTA_PIXEL:
-        deltaY /= 100; /* 100 pixels make up a step */
+        deltaY /= 100; // 100 pixels make up a step
         break;
     case DOM_DELTA_LINE:
-        deltaY /= 3; /* 3 lines make up a step */
+        deltaY /= 3; // 3 lines make up a step
         break;
     case DOM_DELTA_PAGE:
-        deltaY *= 80; /* A page makes up 80 steps */
+        deltaY *= 80; // A page makes up 80 steps
         break;
     }
 
@@ -762,7 +415,7 @@ static EM_BOOL Emscripten_HandleTouch(int eventType, const EmscriptenTouchEvent
             continue;
         }
 
-        id = touchEvent->touches[i].identifier;
+        id = touchEvent->touches[i].identifier + 1;
         if (client_w <= 1) {
             x = 0.5f;
         } else {
@@ -775,18 +428,18 @@ static EM_BOOL Emscripten_HandleTouch(int eventType, const EmscriptenTouchEvent
         }
 
         if (eventType == EMSCRIPTEN_EVENT_TOUCHSTART) {
-            SDL_SendTouch(0, deviceId, id, window_data->window, SDL_TRUE, x, y, 1.0f);
+            SDL_SendTouch(0, deviceId, id, window_data->window, true, x, y, 1.0f);
 
-            /* disable browser scrolling/pinch-to-zoom if app handles touch events */
+            // disable browser scrolling/pinch-to-zoom if app handles touch events
             if (!preventDefault && SDL_EventEnabled(SDL_EVENT_FINGER_DOWN)) {
                 preventDefault = 1;
             }
         } else if (eventType == EMSCRIPTEN_EVENT_TOUCHMOVE) {
             SDL_SendTouchMotion(0, deviceId, id, window_data->window, x, y, 1.0f);
         } else {
-            SDL_SendTouch(0, deviceId, id, window_data->window, SDL_FALSE, x, y, 1.0f);
+            SDL_SendTouch(0, deviceId, id, window_data->window, false, x, y, 1.0f);
 
-            /* block browser's simulated mousedown/mouseup on touchscreen devices */
+            // block browser's simulated mousedown/mouseup on touchscreen devices
             preventDefault = 1;
         }
     }
@@ -794,24 +447,70 @@ static EM_BOOL Emscripten_HandleTouch(int eventType, const EmscriptenTouchEvent
     return preventDefault;
 }
 
+/* This is a great tool to see web keyboard events live:
+ * https://w3c.github.io/uievents/tools/key-event-viewer.html
+ */
 static EM_BOOL Emscripten_HandleKey(int eventType, const EmscriptenKeyboardEvent *keyEvent, void *userData)
 {
-    const SDL_Keycode keycode = Emscripten_MapKeyCode(keyEvent);
+    SDL_WindowData *window_data = (SDL_WindowData *)userData;
     SDL_Scancode scancode = Emscripten_MapScanCode(keyEvent->code);
-    SDL_bool prevent_default = SDL_TRUE;
-    SDL_bool is_nav_key = SDL_FALSE;
+    SDL_Keycode keycode = SDLK_UNKNOWN;
+    bool prevent_default = false;
+    bool is_nav_key = false;
 
     if (scancode == SDL_SCANCODE_UNKNOWN) {
-        /* KaiOS Left Soft Key and Right Soft Key, they act as OK/Next/Menu and Cancel/Back/Clear */
-        if (SDL_strncmp(keyEvent->key, "SoftLeft", 9) == 0) {
+        if (SDL_strcmp(keyEvent->key, "Sleep") == 0) {
+            scancode = SDL_SCANCODE_SLEEP;
+        } else if (SDL_strcmp(keyEvent->key, "ChannelUp") == 0) {
+            scancode = SDL_SCANCODE_CHANNEL_INCREMENT;
+        } else if (SDL_strcmp(keyEvent->key, "ChannelDown") == 0) {
+            scancode = SDL_SCANCODE_CHANNEL_DECREMENT;
+        } else if (SDL_strcmp(keyEvent->key, "MediaPlay") == 0) {
+            scancode = SDL_SCANCODE_MEDIA_PLAY;
+        } else if (SDL_strcmp(keyEvent->key, "MediaPause") == 0) {
+            scancode = SDL_SCANCODE_MEDIA_PAUSE;
+        } else if (SDL_strcmp(keyEvent->key, "MediaRecord") == 0) {
+            scancode = SDL_SCANCODE_MEDIA_RECORD;
+        } else if (SDL_strcmp(keyEvent->key, "MediaFastForward") == 0) {
+            scancode = SDL_SCANCODE_MEDIA_FAST_FORWARD;
+        } else if (SDL_strcmp(keyEvent->key, "MediaRewind") == 0) {
+            scancode = SDL_SCANCODE_MEDIA_REWIND;
+        } else if (SDL_strcmp(keyEvent->key, "Close") == 0) {
+            scancode = SDL_SCANCODE_AC_CLOSE;
+        } else if (SDL_strcmp(keyEvent->key, "New") == 0) {
+            scancode = SDL_SCANCODE_AC_NEW;
+        } else if (SDL_strcmp(keyEvent->key, "Open") == 0) {
+            scancode = SDL_SCANCODE_AC_OPEN;
+        } else if (SDL_strcmp(keyEvent->key, "Print") == 0) {
+            scancode = SDL_SCANCODE_AC_PRINT;
+        } else if (SDL_strcmp(keyEvent->key, "Save") == 0) {
+            scancode = SDL_SCANCODE_AC_SAVE;
+        } else if (SDL_strcmp(keyEvent->key, "Props") == 0) {
+            scancode = SDL_SCANCODE_AC_PROPERTIES;
+        }
+    }
+
+    if (scancode == SDL_SCANCODE_UNKNOWN) {
+        // KaiOS Left Soft Key and Right Soft Key, they act as OK/Next/Menu and Cancel/Back/Clear
+        if (SDL_strcmp(keyEvent->key, "SoftLeft") == 0) {
             scancode = SDL_SCANCODE_AC_FORWARD;
-        } else if (SDL_strncmp(keyEvent->key, "SoftRight", 10) == 0) {
+        } else if (SDL_strcmp(keyEvent->key, "SoftRight") == 0) {
             scancode = SDL_SCANCODE_AC_BACK;
         }
     }
 
-    if (scancode != SDL_SCANCODE_UNKNOWN) {
-        SDL_SendKeyboardKeyAndKeycode(0, SDL_DEFAULT_KEYBOARD_ID, eventType == EMSCRIPTEN_EVENT_KEYDOWN ? SDL_PRESSED : SDL_RELEASED, scancode, keycode);
+    if (keyEvent->location == 0 && SDL_utf8strlen(keyEvent->key) == 1) {
+        const char *key = keyEvent->key;
+        keycode = SDL_StepUTF8(&key, NULL);
+        if (keycode == SDL_INVALID_UNICODE_CODEPOINT) {
+            keycode = SDLK_UNKNOWN;
+        }
+    }
+
+    if (keycode != SDLK_UNKNOWN) {
+        prevent_default = SDL_SendKeyboardKeyAndKeycode(0, SDL_DEFAULT_KEYBOARD_ID, 0, scancode, keycode, (eventType == EMSCRIPTEN_EVENT_KEYDOWN));
+    } else {
+        prevent_default = SDL_SendKeyboardKey(0, SDL_DEFAULT_KEYBOARD_ID, 0, scancode, (eventType == EMSCRIPTEN_EVENT_KEYDOWN));
     }
 
     /* if TEXTINPUT events are enabled we can't prevent keydown or we won't get keypress
@@ -825,11 +524,11 @@ static EM_BOOL Emscripten_HandleKey(int eventType, const EmscriptenKeyboardEvent
         (scancode == SDL_SCANCODE_DOWN) ||
         ((scancode >= SDL_SCANCODE_F1) && (scancode <= SDL_SCANCODE_F15)) ||
         keyEvent->ctrlKey) {
-        is_nav_key = SDL_TRUE;
+        is_nav_key = true;
     }
 
-    if ((eventType == EMSCRIPTEN_EVENT_KEYDOWN) && SDL_TextInputActive() && !is_nav_key) {
-        prevent_default = SDL_FALSE;
+    if ((eventType == EMSCRIPTEN_EVENT_KEYDOWN) && SDL_TextInputActive(window_data->window) && !is_nav_key) {
+        prevent_default = false;
     }
 
     return prevent_default;
@@ -837,11 +536,13 @@ static EM_BOOL Emscripten_HandleKey(int eventType, const EmscriptenKeyboardEvent
 
 static EM_BOOL Emscripten_HandleKeyPress(int eventType, const EmscriptenKeyboardEvent *keyEvent, void *userData)
 {
-    if (SDL_TextInputActive()) {
+    SDL_WindowData *window_data = (SDL_WindowData *)userData;
+
+    if (SDL_TextInputActive(window_data->window)) {
         char text[5];
-        if (Emscripten_ConvertUTF32toUTF8(keyEvent->charCode, text)) {
-            SDL_SendKeyboardText(text);
-        }
+        char *end = SDL_UCS4ToUTF8(keyEvent->charCode, text);
+        *end = '\0';
+        SDL_SendKeyboardText(text);
         return EM_TRUE;
     }
     return EM_FALSE;
@@ -858,7 +559,7 @@ static EM_BOOL Emscripten_HandleFullscreenChange(int eventType, const Emscripten
         SDL_SendWindowEvent(window_data->window, SDL_EVENT_WINDOW_LEAVE_FULLSCREEN, 0, 0);
     }
 
-    SDL_UpdateFullscreenMode(window_data->window, fullscreenChangeEvent->isFullscreen, SDL_FALSE);
+    SDL_UpdateFullscreenMode(window_data->window, fullscreenChangeEvent->isFullscreen, false);
 
     return 0;
 }
@@ -866,18 +567,18 @@ static EM_BOOL Emscripten_HandleFullscreenChange(int eventType, const Emscripten
 static EM_BOOL Emscripten_HandleResize(int eventType, const EmscriptenUiEvent *uiEvent, void *userData)
 {
     SDL_WindowData *window_data = userData;
-    SDL_bool force = SDL_FALSE;
+    bool force = false;
 
-    /* update pixel ratio */
+    // update pixel ratio
     if (window_data->window->flags & SDL_WINDOW_HIGH_PIXEL_DENSITY) {
         if (window_data->pixel_ratio != emscripten_get_device_pixel_ratio()) {
             window_data->pixel_ratio = emscripten_get_device_pixel_ratio();
-            force = SDL_TRUE;
+            force = true;
         }
     }
 
     if (!(window_data->window->flags & SDL_WINDOW_FULLSCREEN)) {
-        /* this will only work if the canvas size is set through css */
+        // this will only work if the canvas size is set through css
         if (window_data->window->flags & SDL_WINDOW_RESIZABLE) {
             double w = window_data->window->w;
             double h = window_data->window->h;
@@ -886,20 +587,20 @@ static EM_BOOL Emscripten_HandleResize(int eventType, const EmscriptenUiEvent *u
                 emscripten_get_element_css_size(window_data->canvas_id, &w, &h);
             }
 
-            emscripten_set_canvas_element_size(window_data->canvas_id, w * window_data->pixel_ratio, h * window_data->pixel_ratio);
+            emscripten_set_canvas_element_size(window_data->canvas_id, SDL_lroundf(w * window_data->pixel_ratio), SDL_lroundf(h * window_data->pixel_ratio));
 
-            /* set_canvas_size unsets this */
+            // set_canvas_size unsets this
             if (!window_data->external_size && window_data->pixel_ratio != 1.0f) {
                 emscripten_set_element_css_size(window_data->canvas_id, w, h);
             }
 
             if (force) {
-                /* force the event to trigger, so pixel ratio changes can be handled */
+                // force the event to trigger, so pixel ratio changes can be handled
                 window_data->window->w = 0;
                 window_data->window->h = 0;
             }
 
-            SDL_SendWindowEvent(window_data->window, SDL_EVENT_WINDOW_RESIZED, w, h);
+            SDL_SendWindowEvent(window_data->window, SDL_EVENT_WINDOW_RESIZED, SDL_lroundf(w), SDL_lroundf(h));
         }
     }
 
@@ -909,13 +610,13 @@ static EM_BOOL Emscripten_HandleResize(int eventType, const EmscriptenUiEvent *u
 EM_BOOL
 Emscripten_HandleCanvasResize(int eventType, const void *reserved, void *userData)
 {
-    /*this is used during fullscreen changes*/
+    // this is used during fullscreen changes
     SDL_WindowData *window_data = userData;
 
     if (window_data->fullscreen_resize) {
         double css_w, css_h;
         emscripten_get_element_css_size(window_data->canvas_id, &css_w, &css_h);
-        SDL_SendWindowEvent(window_data->window, SDL_EVENT_WINDOW_RESIZED, css_w, css_h);
+        SDL_SendWindowEvent(window_data->window, SDL_EVENT_WINDOW_RESIZED, SDL_lroundf(css_w), SDL_lroundf(css_h));
     }
 
     return 0;
@@ -932,16 +633,180 @@ static const char *Emscripten_HandleBeforeUnload(int eventType, const void *rese
 {
     /* This event will need to be handled synchronously, e.g. using
        SDL_AddEventWatch, as the page is being closed *now*. */
-    /* No need to send a SDL_EVENT_QUIT, the app won't get control again. */
+    // No need to send a SDL_EVENT_QUIT, the app won't get control again.
     SDL_SendAppEvent(SDL_EVENT_TERMINATING);
-    return ""; /* don't trigger confirmation dialog */
+    return ""; // don't trigger confirmation dialog
+}
+
+// IF YOU CHANGE THIS STRUCTURE, YOU NEED TO UPDATE THE JAVASCRIPT THAT FILLS IT IN: makePointerEventCStruct, below.
+typedef struct Emscripten_PointerEvent
+{
+    int pointerid;
+    int button;
+    int buttons;
+    float movementX;
+    float movementY;
+    float targetX;
+    float targetY;
+    float pressure;
+    float tangential_pressure;
+    float tiltx;
+    float tilty;
+    float rotation;
+} Emscripten_PointerEvent;
+
+static void Emscripten_UpdatePointerFromEvent(SDL_WindowData *window_data, const Emscripten_PointerEvent *event)
+{
+    const SDL_PenID pen = SDL_FindPenByHandle((void *) (size_t) event->pointerid);
+    if (pen) {
+        // rescale (in case canvas is being scaled)
+        double client_w, client_h;
+        emscripten_get_element_css_size(window_data->canvas_id, &client_w, &client_h);
+        const double xscale = window_data->window->w / client_w;
+        const double yscale = window_data->window->h / client_h;
+
+        const bool isPointerLocked = window_data->has_pointer_lock;
+        float mx, my;
+        if (isPointerLocked) {
+            mx = (float)(event->movementX * xscale);
+            my = (float)(event->movementY * yscale);
+        } else {
+            mx = (float)(event->targetX * xscale);
+            my = (float)(event->targetY * yscale);
+        }
+
+        SDL_SendPenMotion(0, pen, window_data->window, mx, my);
+
+        if (event->button == 0) {  // pen touch
+            bool down = ((event->buttons & 1) != 0);
+            SDL_SendPenTouch(0, pen, window_data->window, false, down);
+        } else if (event->button == 5) {  // eraser touch...? Not sure if this is right...
+            bool down = ((event->buttons & 32) != 0);
+            SDL_SendPenTouch(0, pen, window_data->window, true, down);
+        } else if (event->button == 1) {
+            bool down = ((event->buttons & 4) != 0);
+            SDL_SendPenButton(0, pen, window_data->window, 2, down);
+        } else if (event->button == 2) {
+            bool down = ((event->buttons & 2) != 0);
+            SDL_SendPenButton(0, pen, window_data->window, 1, down);
+        }
+
+        SDL_SendPenAxis(0, pen, window_data->window, SDL_PEN_AXIS_PRESSURE, event->pressure);
+        SDL_SendPenAxis(0, pen, window_data->window, SDL_PEN_AXIS_TANGENTIAL_PRESSURE, event->tangential_pressure);
+        SDL_SendPenAxis(0, pen, window_data->window, SDL_PEN_AXIS_XTILT, event->tiltx);
+        SDL_SendPenAxis(0, pen, window_data->window, SDL_PEN_AXIS_YTILT, event->tilty);
+        SDL_SendPenAxis(0, pen, window_data->window, SDL_PEN_AXIS_ROTATION, event->rotation);
+    }
+}
+
+EMSCRIPTEN_KEEPALIVE void Emscripten_HandlePointerEnter(SDL_WindowData *window_data, const Emscripten_PointerEvent *event)
+{
+    // Web browsers offer almost none of this information as specifics, but can without warning offer any of these specific things.
+    SDL_PenInfo peninfo;
+    SDL_zero(peninfo);
+    peninfo.capabilities = SDL_PEN_CAPABILITY_PRESSURE | SDL_PEN_CAPABILITY_ROTATION | SDL_PEN_CAPABILITY_XTILT | SDL_PEN_CAPABILITY_YTILT | SDL_PEN_CAPABILITY_TANGENTIAL_PRESSURE | SDL_PEN_CAPABILITY_ERASER;
+    peninfo.max_tilt = 90.0f;
+    peninfo.num_buttons = 2;
+    peninfo.subtype = SDL_PEN_TYPE_PEN;
+    SDL_AddPenDevice(0, NULL, &peninfo, (void *) (size_t) event->pointerid);
+    Emscripten_UpdatePointerFromEvent(window_data, event);
+}
+
+EMSCRIPTEN_KEEPALIVE void Emscripten_HandlePointerLeave(SDL_WindowData *window_data, const Emscripten_PointerEvent *event)
+{
+    const SDL_PenID pen = SDL_FindPenByHandle((void *) (size_t) event->pointerid);
+    if (pen) {
+        Emscripten_UpdatePointerFromEvent(window_data, event);  // last data updates?
+        SDL_RemovePenDevice(0, pen);
+    }
+}
+
+EMSCRIPTEN_KEEPALIVE void Emscripten_HandlePointerGeneric(SDL_WindowData *window_data, const Emscripten_PointerEvent *event)
+{
+    Emscripten_UpdatePointerFromEvent(window_data, event);
+}
+
+static void Emscripten_set_pointer_event_callbacks(SDL_WindowData *data)
+{
+    MAIN_THREAD_EM_ASM({
+        var target = document.querySelector(UTF8ToString($1));
+        if (target) {
+            var data = $0;
+
+            if (typeof(Module['SDL3']) === 'undefined') {
+                Module['SDL3'] = {};
+            }
+            var SDL3 = Module['SDL3'];
+
+            var makePointerEventCStruct = function(event) {
+                var ptr = 0;
+                if (event.pointerType == "pen") {
+                    ptr = _SDL_malloc($2);
+                    if (ptr != 0) {
+                        var rect = target.getBoundingClientRect();
+                        var idx = ptr >> 2;
+                        HEAP32[idx++] = event.pointerId;
+                        HEAP32[idx++] = (typeof(event.button) !== "undefined") ? event.button : -1;
+                        HEAP32[idx++] = event.buttons;
+                        HEAPF32[idx++] = event.movementX;
+                        HEAPF32[idx++] = event.movementY;
+                        HEAPF32[idx++] = event.clientX - rect.left;
+                        HEAPF32[idx++] = event.clientY - rect.top;
+                        HEAPF32[idx++] = event.pressure;
+                        HEAPF32[idx++] = event.tangentialPressure;
+                        HEAPF32[idx++] = event.tiltX;
+                        HEAPF32[idx++] = event.tiltY;
+                        HEAPF32[idx++] = event.twist;
+                    }
+                }
+                return ptr;
+            };
+
+            SDL3.eventHandlerPointerEnter = function(event) {
+                var d = makePointerEventCStruct(event); if (d != 0) { _Emscripten_HandlePointerEnter(data, d); _SDL_free(d); }
+            };
+            target.addEventListener("pointerenter", SDL3.eventHandlerPointerEnter);
+
+            SDL3.eventHandlerPointerLeave = function(event) {
+                var d = makePointerEventCStruct(event); if (d != 0) { _Emscripten_HandlePointerLeave(data, d); _SDL_free(d); }
+            };
+            target.addEventListener("pointerleave", SDL3.eventHandlerPointerLeave);
+            target.addEventListener("pointercancel", SDL3.eventHandlerPointerLeave);  // catch this, just in case.
+
+            SDL3.eventHandlerPointerGeneric = function(event) {
+                var d = makePointerEventCStruct(event); if (d != 0) { _Emscripten_HandlePointerGeneric(data, d); _SDL_free(d); }
+            };
+            target.addEventListener("pointerdown", SDL3.eventHandlerPointerGeneric);
+            target.addEventListener("pointerup", SDL3.eventHandlerPointerGeneric);
+            target.addEventListener("pointermove", SDL3.eventHandlerPointerGeneric);
+        }
+    }, data, data->canvas_id, sizeof (Emscripten_PointerEvent));
+}
+
+static void Emscripten_unset_pointer_event_callbacks(SDL_WindowData *data)
+{
+    MAIN_THREAD_EM_ASM({
+        var target = document.querySelector(UTF8ToString($0));
+        if (target) {
+            var SDL3 = Module['SDL3'];
+            target.removeEventListener("pointerenter", SDL3.eventHandlerPointerEnter);
+            target.removeEventListener("pointerleave", SDL3.eventHandlerPointerLeave);
+            target.removeEventListener("pointercancel", SDL3.eventHandlerPointerLeave);
+            target.removeEventListener("pointerdown", SDL3.eventHandlerPointerGeneric);
+            target.removeEventListener("pointerup", SDL3.eventHandlerPointerGeneric);
+            target.removeEventListener("pointermove", SDL3.eventHandlerPointerGeneric);
+            SDL3.eventHandlerPointerEnter = undefined;
+            SDL3.eventHandlerPointerLeave = undefined;
+            SDL3.eventHandlerPointerGeneric = undefined;
+        }
+    }, data->canvas_id);
 }
 
 void Emscripten_RegisterEventHandlers(SDL_WindowData *data)
 {
     const char *keyElement;
 
-    /* There is only one window and that window is the canvas */
+    // There is only one window and that window is the canvas
     emscripten_set_mousemove_callback(data->canvas_id, data, 0, Emscripten_HandleMouseMove);
 
     emscripten_set_mousedown_callback(data->canvas_id, data, 0, Emscripten_HandleMouseButton);
@@ -962,7 +827,7 @@ void Emscripten_RegisterEventHandlers(SDL_WindowData *data)
 
     emscripten_set_pointerlockchange_callback(EMSCRIPTEN_EVENT_TARGET_DOCUMENT, data, 0, Emscripten_HandlePointerLockChange);
 
-    /* Keyboard events are awkward */
+    // Keyboard events are awkward
     keyElement = SDL_GetHint(SDL_HINT_EMSCRIPTEN_KEYBOARD_ELEMENT);
     if (!keyElement) {
         keyElement = EMSCRIPTEN_EVENT_TARGET_WINDOW;
@@ -979,13 +844,21 @@ void Emscripten_RegisterEventHandlers(SDL_WindowData *data)
     emscripten_set_visibilitychange_callback(data, 0, Emscripten_HandleVisibilityChange);
 
     emscripten_set_beforeunload_callback(data, Emscripten_HandleBeforeUnload);
+
+    // !!! FIXME: currently Emscripten doesn't have a Pointer Events functions like emscripten_set_*_callback, but we should use those when they do:
+    // !!! FIXME:  https://github.com/emscripten-core/emscripten/issues/7278#issuecomment-2280024621
+    Emscripten_set_pointer_event_callbacks(data);
 }
 
 void Emscripten_UnregisterEventHandlers(SDL_WindowData *data)
 {
     const char *target;
 
-    /* only works due to having one window */
+    // !!! FIXME: currently Emscripten doesn't have a Pointer Events functions like emscripten_set_*_callback, but we should use those when they do:
+    // !!! FIXME:  https://github.com/emscripten-core/emscripten/issues/7278#issuecomment-2280024621
+    Emscripten_unset_pointer_event_callbacks(data);
+
+    // only works due to having one window
     emscripten_set_mousemove_callback(data->canvas_id, NULL, 0, NULL);
 
     emscripten_set_mousedown_callback(data->canvas_id, NULL, 0, NULL);
@@ -1024,4 +897,4 @@ void Emscripten_UnregisterEventHandlers(SDL_WindowData *data)
     emscripten_set_beforeunload_callback(NULL, NULL);
 }
 
-#endif /* SDL_VIDEO_DRIVER_EMSCRIPTEN */
+#endif // SDL_VIDEO_DRIVER_EMSCRIPTEN
