@@ -30,8 +30,6 @@ extern "C" {
 
 extern void HAIKU_InitOSKeymap(void);
 extern SDL_Scancode HAIKU_GetScancodeFromBeKey(int32 bkey);
-extern int8 HAIKU_GetKeyState(int32 bkey);
-extern void HAIKU_SetKeyState(int32 bkey, int8 state);
 
 #ifdef __cplusplus
 }
