@@ -33,10 +33,10 @@
 #include "SDL_uikitmodes.h"
 #include "SDL_uikitwindow.h"
 
-/* The maximum number of mouse buttons we support */
+// The maximum number of mouse buttons we support
 #define MAX_MOUSE_BUTTONS 5
 
-/* This is defined in SDL_sysjoystick.m */
+// This is defined in SDL_sysjoystick.m
 #ifndef SDL_JOYSTICK_DISABLED
 extern int SDL_AppleTVRemoteOpenedAsJoystick;
 #endif
@@ -53,7 +53,7 @@ extern int SDL_AppleTVRemoteOpenedAsJoystick;
 {
     if ((self = [super initWithFrame:frame])) {
 #ifdef SDL_PLATFORM_TVOS
-        /* Apple TV Remote touchpad swipe gestures. */
+        // Apple TV Remote touchpad swipe gestures.
         UISwipeGestureRecognizer *swipeUp = [[UISwipeGestureRecognizer alloc] initWithTarget:self action:@selector(swipeGesture:)];
         swipeUp.direction = UISwipeGestureRecognizerDirectionUp;
         [self addGestureRecognizer:swipeUp];
@@ -100,16 +100,16 @@ extern int SDL_AppleTVRemoteOpenedAsJoystick;
         return;
     }
 
-    /* Remove ourself from the old window. */
+    // Remove ourself from the old window.
     if (sdlwindow) {
         SDL_uikitview *view = nil;
-        data = (__bridge SDL_UIKitWindowData *)sdlwindow->driverdata;
+        data = (__bridge SDL_UIKitWindowData *)sdlwindow->internal;
 
         [data.views removeObject:self];
 
         [self removeFromSuperview];
 
-        /* Restore the next-oldest view in the old window. */
+        // Restore the next-oldest view in the old window.
         view = data.views.lastObject;
 
         data.viewcontroller.view = view;
@@ -120,14 +120,16 @@ extern int SDL_AppleTVRemoteOpenedAsJoystick;
         [data.uiwindow layoutIfNeeded];
     }
 
-    /* Add ourself to the new window. */
-    if (window) {
-        data = (__bridge SDL_UIKitWindowData *)window->driverdata;
+    sdlwindow = window;
 
-        /* Make sure the SDL window has a strong reference to this view. */
+    // Add ourself to the new window.
+    if (window) {
+        data = (__bridge SDL_UIKitWindowData *)window->internal;
+
+        // Make sure the SDL window has a strong reference to this view.
         [data.views addObject:self];
 
-        /* Replace the view controller's old view with this one. */
+        // Replace the view controller's old view with this one.
         [data.viewcontroller.view removeFromSuperview];
         data.viewcontroller.view = self;
 
@@ -144,8 +146,11 @@ extern int SDL_AppleTVRemoteOpenedAsJoystick;
          * layout now to immediately update the bounds. */
         [data.uiwindow layoutIfNeeded];
     }
+}
 
-    sdlwindow = window;
+- (SDL_Window *)getSDLWindow
+{
+    return sdlwindow;
 }
 
 #if !defined(SDL_PLATFORM_TVOS) && defined(__IPHONE_13_4)
@@ -158,7 +163,7 @@ extern int SDL_AppleTVRemoteOpenedAsJoystick;
         point.x -= origin.x;
         point.y -= origin.y;
 
-        SDL_SendMouseMotion(0, sdlwindow, SDL_GLOBAL_MOUSE_ID, SDL_FALSE, point.x, point.y);
+        SDL_SendMouseMotion(0, sdlwindow, SDL_GLOBAL_MOUSE_ID, false, point.x, point.y);
     }
     return [UIPointerRegion regionWithRect:self.bounds identifier:nil];
 }
@@ -171,7 +176,7 @@ extern int SDL_AppleTVRemoteOpenedAsJoystick;
         return [UIPointerStyle hiddenPointerStyle];
     }
 }
-#endif /* !defined(SDL_PLATFORM_TVOS) && __IPHONE_13_4 */
+#endif // !defined(SDL_PLATFORM_TVOS) && __IPHONE_13_4
 
 - (SDL_TouchDeviceType)touchTypeForTouch:(UITouch *)touch
 {
@@ -233,7 +238,7 @@ extern int SDL_AppleTVRemoteOpenedAsJoystick;
                     int i;
 
                     for (i = 1; i <= MAX_MOUSE_BUTTONS; ++i) {
-                        if (event.buttonMask & SDL_BUTTON(i)) {
+                        if (event.buttonMask & SDL_BUTTON_MASK(i)) {
                             Uint8 button;
 
                             switch (i) {
@@ -250,7 +255,7 @@ extern int SDL_AppleTVRemoteOpenedAsJoystick;
                                 button = (Uint8)i;
                                 break;
                             }
-                            SDL_SendMouseButton(UIKit_GetEventTimestamp([event timestamp]), sdlwindow, SDL_GLOBAL_MOUSE_ID, SDL_PRESSED, button);
+                            SDL_SendMouseButton(UIKit_GetEventTimestamp([event timestamp]), sdlwindow, SDL_GLOBAL_MOUSE_ID, button, true);
                         }
                     }
                 }
@@ -267,12 +272,12 @@ extern int SDL_AppleTVRemoteOpenedAsJoystick;
                 continue;
             }
 
-            /* FIXME, need to send: int clicks = (int) touch.tapCount; ? */
+            // FIXME, need to send: int clicks = (int) touch.tapCount; ?
 
             CGPoint locationInView = [self touchLocation:touch shouldNormalize:YES];
             SDL_SendTouch(UIKit_GetEventTimestamp([event timestamp]),
                           touchId, (SDL_FingerID)(uintptr_t)touch, sdlwindow,
-                          SDL_TRUE, locationInView.x, locationInView.y, pressure);
+                          true, locationInView.x, locationInView.y, pressure);
         }
     }
 }
@@ -289,7 +294,7 @@ extern int SDL_AppleTVRemoteOpenedAsJoystick;
                     int i;
 
                     for (i = 1; i <= MAX_MOUSE_BUTTONS; ++i) {
-                        if (event.buttonMask & SDL_BUTTON(i)) {
+                        if (event.buttonMask & SDL_BUTTON_MASK(i)) {
                             Uint8 button;
 
                             switch (i) {
@@ -306,7 +311,7 @@ extern int SDL_AppleTVRemoteOpenedAsJoystick;
                                 button = (Uint8)i;
                                 break;
                             }
-                            SDL_SendMouseButton(UIKit_GetEventTimestamp([event timestamp]), sdlwindow, SDL_GLOBAL_MOUSE_ID, SDL_RELEASED, button);
+                            SDL_SendMouseButton(UIKit_GetEventTimestamp([event timestamp]), sdlwindow, SDL_GLOBAL_MOUSE_ID, button, false);
                         }
                     }
                 }
@@ -323,12 +328,12 @@ extern int SDL_AppleTVRemoteOpenedAsJoystick;
                 continue;
             }
 
-            /* FIXME, need to send: int clicks = (int) touch.tapCount; ? */
+            // FIXME, need to send: int clicks = (int) touch.tapCount; ?
 
             CGPoint locationInView = [self touchLocation:touch shouldNormalize:YES];
             SDL_SendTouch(UIKit_GetEventTimestamp([event timestamp]),
                           touchId, (SDL_FingerID)(uintptr_t)touch, sdlwindow,
-                          SDL_FALSE, locationInView.x, locationInView.y, pressure);
+                          false, locationInView.x, locationInView.y, pressure);
         }
     }
 }
@@ -346,7 +351,7 @@ extern int SDL_AppleTVRemoteOpenedAsJoystick;
 #if !defined(SDL_PLATFORM_TVOS) && defined(__IPHONE_13_4)
         if (@available(iOS 13.4, *)) {
             if (touch.type == UITouchTypeIndirectPointer) {
-                /* Already handled in pointerInteraction callback */
+                // Already handled in pointerInteraction callback
                 handled = YES;
             }
         }
@@ -368,6 +373,18 @@ extern int SDL_AppleTVRemoteOpenedAsJoystick;
     }
 }
 
+- (void)safeAreaInsetsDidChange
+{
+    // Update the safe area insets
+    if (@available(iOS 11.0, tvOS 11.0, *)) {
+        SDL_SetWindowSafeAreaInsets(sdlwindow,
+                                    (int)SDL_ceilf(self.safeAreaInsets.left),
+                                    (int)SDL_ceilf(self.safeAreaInsets.right),
+                                    (int)SDL_ceilf(self.safeAreaInsets.top),
+                                    (int)SDL_ceilf(self.safeAreaInsets.bottom));
+    }
+}
+
 #if defined(SDL_PLATFORM_TVOS) || defined(__IPHONE_9_1)
 - (SDL_Scancode)scancodeFromPress:(UIPress *)press
 {
@@ -380,7 +397,7 @@ extern int SDL_AppleTVRemoteOpenedAsJoystick;
 #endif
 
 #ifndef SDL_JOYSTICK_DISABLED
-    /* Presses from Apple TV remote */
+    // Presses from Apple TV remote
     if (!SDL_AppleTVRemoteOpenedAsJoystick) {
         switch (press.type) {
         case UIPressTypeUpArrow:
@@ -392,19 +409,19 @@ extern int SDL_AppleTVRemoteOpenedAsJoystick;
         case UIPressTypeRightArrow:
             return SDL_SCANCODE_RIGHT;
         case UIPressTypeSelect:
-            /* HIG says: "primary button behavior" */
+            // HIG says: "primary button behavior"
             return SDL_SCANCODE_RETURN;
         case UIPressTypeMenu:
-            /* HIG says: "returns to previous screen" */
+            // HIG says: "returns to previous screen"
             return SDL_SCANCODE_ESCAPE;
         case UIPressTypePlayPause:
-            /* HIG says: "secondary button behavior" */
+            // HIG says: "secondary button behavior"
             return SDL_SCANCODE_PAUSE;
         default:
             break;
         }
     }
-#endif /* !SDL_JOYSTICK_DISABLED */
+#endif // !SDL_JOYSTICK_DISABLED
 
     return SDL_SCANCODE_UNKNOWN;
 }
@@ -414,10 +431,10 @@ extern int SDL_AppleTVRemoteOpenedAsJoystick;
     if (!SDL_HasKeyboard()) {
         for (UIPress *press in presses) {
             SDL_Scancode scancode = [self scancodeFromPress:press];
-            SDL_SendKeyboardKey(UIKit_GetEventTimestamp([event timestamp]), SDL_GLOBAL_KEYBOARD_ID, SDL_PRESSED, scancode);
+            SDL_SendKeyboardKey(UIKit_GetEventTimestamp([event timestamp]), SDL_GLOBAL_KEYBOARD_ID, 0, scancode, true);
         }
     }
-    if (SDL_TextInputActive()) {
+    if (SDL_TextInputActive(sdlwindow)) {
         [super pressesBegan:presses withEvent:event];
     }
 }
@@ -427,10 +444,10 @@ extern int SDL_AppleTVRemoteOpenedAsJoystick;
     if (!SDL_HasKeyboard()) {
         for (UIPress *press in presses) {
             SDL_Scancode scancode = [self scancodeFromPress:press];
-            SDL_SendKeyboardKey(UIKit_GetEventTimestamp([event timestamp]), SDL_GLOBAL_KEYBOARD_ID, SDL_RELEASED, scancode);
+            SDL_SendKeyboardKey(UIKit_GetEventTimestamp([event timestamp]), SDL_GLOBAL_KEYBOARD_ID, 0, scancode, false);
         }
     }
-    if (SDL_TextInputActive()) {
+    if (SDL_TextInputActive(sdlwindow)) {
         [super pressesEnded:presses withEvent:event];
     }
 }
@@ -440,28 +457,28 @@ extern int SDL_AppleTVRemoteOpenedAsJoystick;
     if (!SDL_HasKeyboard()) {
         for (UIPress *press in presses) {
             SDL_Scancode scancode = [self scancodeFromPress:press];
-            SDL_SendKeyboardKey(UIKit_GetEventTimestamp([event timestamp]), SDL_GLOBAL_KEYBOARD_ID, SDL_RELEASED, scancode);
+            SDL_SendKeyboardKey(UIKit_GetEventTimestamp([event timestamp]), SDL_GLOBAL_KEYBOARD_ID, 0, scancode, false);
         }
     }
-    if (SDL_TextInputActive()) {
+    if (SDL_TextInputActive(sdlwindow)) {
         [super pressesCancelled:presses withEvent:event];
     }
 }
 
 - (void)pressesChanged:(NSSet<UIPress *> *)presses withEvent:(UIPressesEvent *)event
 {
-    /* This is only called when the force of a press changes. */
-    if (SDL_TextInputActive()) {
+    // This is only called when the force of a press changes.
+    if (SDL_TextInputActive(sdlwindow)) {
         [super pressesChanged:presses withEvent:event];
     }
 }
 
-#endif /* defined(SDL_PLATFORM_TVOS) || defined(__IPHONE_9_1) */
+#endif // defined(SDL_PLATFORM_TVOS) || defined(__IPHONE_9_1)
 
 #ifdef SDL_PLATFORM_TVOS
 - (void)swipeGesture:(UISwipeGestureRecognizer *)gesture
 {
-    /* Swipe gestures don't trigger begin states. */
+    // Swipe gestures don't trigger begin states.
     if (gesture.state == UIGestureRecognizerStateEnded) {
 #ifndef SDL_JOYSTICK_DISABLED
         if (!SDL_AppleTVRemoteOpenedAsJoystick) {
@@ -482,11 +499,11 @@ extern int SDL_AppleTVRemoteOpenedAsJoystick;
                 break;
             }
         }
-#endif /* !SDL_JOYSTICK_DISABLED */
+#endif // !SDL_JOYSTICK_DISABLED
     }
 }
-#endif /* SDL_PLATFORM_TVOS */
+#endif // SDL_PLATFORM_TVOS
 
 @end
 
-#endif /* SDL_VIDEO_DRIVER_UIKIT */
+#endif // SDL_VIDEO_DRIVER_UIKIT
