@@ -24,8 +24,8 @@
 
 #include "SDL_internal.h"
 
-/* Keyboard functions */
+// Keyboard functions
 extern void VITA_InitKeyboard(void);
 extern void VITA_PollKeyboard(void);
 
-#endif /* SDL_vitakeyboard_h */
+#endif // SDL_vitakeyboard_h
