@@ -24,8 +24,8 @@
 
 #ifdef SDL_VIDEO_DRIVER_WAYLAND
 
-extern int Wayland_ShowMessageBox(const SDL_MessageBoxData *messageboxdata, int *buttonID);
+extern bool Wayland_ShowMessageBox(const SDL_MessageBoxData *messageboxdata, int *buttonID);
 
-#endif /* SDL_VIDEO_DRIVER_WAYLAND */
+#endif // SDL_VIDEO_DRIVER_WAYLAND
 
-#endif /* SDL_waylandmessagebox_h_ */
+#endif // SDL_waylandmessagebox_h_
