@@ -23,6 +23,6 @@
 #ifndef SDL_windowsshape_h_
 #define SDL_windowsshape_h_
 
-extern int WIN_UpdateWindowShape(SDL_VideoDevice *_this, SDL_Window *window, SDL_Surface *shape);
+extern bool WIN_UpdateWindowShape(SDL_VideoDevice *_this, SDL_Window *window, SDL_Surface *shape);
 
-#endif /* SDL_windowsshape_h_ */
+#endif // SDL_windowsshape_h_
