@@ -29,14 +29,20 @@
 #include "../SDL_video_c.h"
 #include "../../events/SDL_mouse_c.h"
 
-/* FIXME: Find a better place to put this... */
+struct SDL_CursorData
+{
+    Cursor cursor;
+};
+
+// FIXME: Find a better place to put this...
 static Cursor x11_empty_cursor = None;
+static bool x11_cursor_visible = true;
 
 static SDL_Cursor *sys_cursors[SDL_HITTEST_RESIZE_LEFT + 1];
 
 static Display *GetDisplay(void)
 {
-    return SDL_GetVideoDevice()->driverdata->display;
+    return SDL_GetVideoDevice()->internal->display;
 }
 
 static Cursor X11_CreateEmptyCursor(void)
@@ -68,15 +74,25 @@ static void X11_DestroyEmptyCursor(void)
     }
 }
 
+static SDL_Cursor *X11_CreateCursorAndData(Cursor x11_cursor)
+{
+    SDL_Cursor *cursor = (SDL_Cursor *)SDL_calloc(1, sizeof(*cursor));
+    if (cursor) {
+        SDL_CursorData *data = (SDL_CursorData *)SDL_calloc(1, sizeof(*data));
+        if (!data) {
+            SDL_free(cursor);
+            return NULL;
+        }
+        data->cursor = x11_cursor;
+        cursor->internal = data;
+    }
+    return cursor;
+}
+
 static SDL_Cursor *X11_CreateDefaultCursor(void)
 {
-    SDL_Cursor *cursor = SDL_calloc(1, sizeof(*cursor));
-    if (cursor) {
-        /* None is used to indicate the default cursor */
-        cursor->driverdata = (void *)(uintptr_t)None;
-    }
-
-    return cursor;
+    // None is used to indicate the default cursor
+    return X11_CreateCursorAndData(None);
 }
 
 #ifdef SDL_VIDEO_DRIVER_X11_XCURSOR
@@ -95,7 +111,7 @@ static Cursor X11_CreateXCursorCursor(SDL_Surface *surface, int hot_x, int hot_y
     image->yhot = hot_y;
     image->delay = 0;
 
-    SDL_assert(surface->format->format == SDL_PIXELFORMAT_ARGB8888);
+    SDL_assert(surface->format == SDL_PIXELFORMAT_ARGB8888);
     SDL_assert(surface->pitch == surface->w * 4);
     SDL_memcpy(image->pixels, surface->pixels, (size_t)surface->h * surface->pitch);
 
@@ -105,7 +121,7 @@ static Cursor X11_CreateXCursorCursor(SDL_Surface *surface, int hot_x, int hot_y
 
     return cursor;
 }
-#endif /* SDL_VIDEO_DRIVER_X11_XCURSOR */
+#endif // SDL_VIDEO_DRIVER_X11_XCURSOR
 
 static Cursor X11_CreatePixmapCursor(SDL_Surface *surface, int hot_x, int hot_y)
 {
@@ -130,8 +146,8 @@ static Cursor X11_CreatePixmapCursor(SDL_Surface *surface, int hot_x, int hot_y)
         return None;
     }
 
-    /* Code below assumes ARGB pixel format */
-    SDL_assert(surface->format->format == SDL_PIXELFORMAT_ARGB8888);
+    // Code below assumes ARGB pixel format
+    SDL_assert(surface->format == SDL_PIXELFORMAT_ARGB8888);
 
     rfg = gfg = bfg = rbg = gbg = bbg = fgBits = bgBits = 0;
     for (y = 0; y < surface->h; ++y) {
@@ -195,50 +211,45 @@ static Cursor X11_CreatePixmapCursor(SDL_Surface *surface, int hot_x, int hot_y)
 
 static SDL_Cursor *X11_CreateCursor(SDL_Surface *surface, int hot_x, int hot_y)
 {
-    SDL_Cursor *cursor = SDL_calloc(1, sizeof(*cursor));
-    if (cursor) {
-        Cursor x11_cursor = None;
+    Cursor x11_cursor = None;
 
 #ifdef SDL_VIDEO_DRIVER_X11_XCURSOR
-        if (SDL_X11_HAVE_XCURSOR) {
-            x11_cursor = X11_CreateXCursorCursor(surface, hot_x, hot_y);
-        }
-#endif
-        if (x11_cursor == None) {
-            x11_cursor = X11_CreatePixmapCursor(surface, hot_x, hot_y);
-        }
-        cursor->driverdata = (void *)(uintptr_t)x11_cursor;
+    if (SDL_X11_HAVE_XCURSOR) {
+        x11_cursor = X11_CreateXCursorCursor(surface, hot_x, hot_y);
     }
-
-    return cursor;
+#endif
+    if (x11_cursor == None) {
+        x11_cursor = X11_CreatePixmapCursor(surface, hot_x, hot_y);
+    }
+    return X11_CreateCursorAndData(x11_cursor);
 }
 
 static unsigned int GetLegacySystemCursorShape(SDL_SystemCursor id)
 {
     switch (id) {
-        /* X Font Cursors reference: */
-        /*   http://tronche.com/gui/x/xlib/appendix/b/ */
-        case SDL_SYSTEM_CURSOR_ARROW: return XC_left_ptr;
-        case SDL_SYSTEM_CURSOR_IBEAM: return XC_xterm;
+        // X Font Cursors reference:
+        // http://tronche.com/gui/x/xlib/appendix/b/
+        case SDL_SYSTEM_CURSOR_DEFAULT: return XC_left_ptr;
+        case SDL_SYSTEM_CURSOR_TEXT: return XC_xterm;
         case SDL_SYSTEM_CURSOR_WAIT: return XC_watch;
         case SDL_SYSTEM_CURSOR_CROSSHAIR: return XC_tcross;
-        case SDL_SYSTEM_CURSOR_WAITARROW: return XC_watch;
-        case SDL_SYSTEM_CURSOR_SIZENWSE: return XC_top_left_corner;
-        case SDL_SYSTEM_CURSOR_SIZENESW: return XC_top_right_corner;
-        case SDL_SYSTEM_CURSOR_SIZEWE: return XC_sb_h_double_arrow;
-        case SDL_SYSTEM_CURSOR_SIZENS: return XC_sb_v_double_arrow;
-        case SDL_SYSTEM_CURSOR_SIZEALL: return XC_fleur;
-        case SDL_SYSTEM_CURSOR_NO: return XC_pirate;
-        case SDL_SYSTEM_CURSOR_HAND: return XC_hand2;
-        case SDL_SYSTEM_CURSOR_WINDOW_TOPLEFT: return XC_top_left_corner;
-        case SDL_SYSTEM_CURSOR_WINDOW_TOP: return XC_top_side;
-        case SDL_SYSTEM_CURSOR_WINDOW_TOPRIGHT: return XC_top_right_corner;
-        case SDL_SYSTEM_CURSOR_WINDOW_RIGHT: return XC_right_side;
-        case SDL_SYSTEM_CURSOR_WINDOW_BOTTOMRIGHT: return XC_bottom_right_corner;
-        case SDL_SYSTEM_CURSOR_WINDOW_BOTTOM: return XC_bottom_side;
-        case SDL_SYSTEM_CURSOR_WINDOW_BOTTOMLEFT: return XC_bottom_left_corner;
-        case SDL_SYSTEM_CURSOR_WINDOW_LEFT: return XC_left_side;
-        case SDL_NUM_SYSTEM_CURSORS: break;  /* so the compiler might notice if an enum value is missing here. */
+        case SDL_SYSTEM_CURSOR_PROGRESS: return XC_watch;
+        case SDL_SYSTEM_CURSOR_NWSE_RESIZE: return XC_top_left_corner;
+        case SDL_SYSTEM_CURSOR_NESW_RESIZE: return XC_top_right_corner;
+        case SDL_SYSTEM_CURSOR_EW_RESIZE: return XC_sb_h_double_arrow;
+        case SDL_SYSTEM_CURSOR_NS_RESIZE: return XC_sb_v_double_arrow;
+        case SDL_SYSTEM_CURSOR_MOVE: return XC_fleur;
+        case SDL_SYSTEM_CURSOR_NOT_ALLOWED: return XC_pirate;
+        case SDL_SYSTEM_CURSOR_POINTER: return XC_hand2;
+        case SDL_SYSTEM_CURSOR_NW_RESIZE: return XC_top_left_corner;
+        case SDL_SYSTEM_CURSOR_N_RESIZE: return XC_top_side;
+        case SDL_SYSTEM_CURSOR_NE_RESIZE: return XC_top_right_corner;
+        case SDL_SYSTEM_CURSOR_E_RESIZE: return XC_right_side;
+        case SDL_SYSTEM_CURSOR_SE_RESIZE: return XC_bottom_right_corner;
+        case SDL_SYSTEM_CURSOR_S_RESIZE: return XC_bottom_side;
+        case SDL_SYSTEM_CURSOR_SW_RESIZE: return XC_bottom_left_corner;
+        case SDL_SYSTEM_CURSOR_W_RESIZE: return XC_left_side;
+        case SDL_SYSTEM_CURSOR_COUNT: break;  // so the compiler might notice if an enum value is missing here.
     }
 
     SDL_assert(0);
@@ -262,12 +273,7 @@ static SDL_Cursor *X11_CreateSystemCursor(SDL_SystemCursor id)
     }
 
     if (x11_cursor != None) {
-        cursor = SDL_calloc(1, sizeof(*cursor));
-        if (!cursor) {
-            SDL_OutOfMemory();
-        } else {
-            cursor->driverdata = (void *)(uintptr_t)x11_cursor;
-        }
+        cursor = X11_CreateCursorAndData(x11_cursor);
     }
 
     return cursor;
@@ -275,32 +281,35 @@ static SDL_Cursor *X11_CreateSystemCursor(SDL_SystemCursor id)
 
 static void X11_FreeCursor(SDL_Cursor *cursor)
 {
-    Cursor x11_cursor = (Cursor)cursor->driverdata;
+    Cursor x11_cursor = cursor->internal->cursor;
 
     if (x11_cursor != None) {
         X11_XFreeCursor(GetDisplay(), x11_cursor);
     }
+    SDL_free(cursor->internal);
     SDL_free(cursor);
 }
 
-static int X11_ShowCursor(SDL_Cursor *cursor)
+static bool X11_ShowCursor(SDL_Cursor *cursor)
 {
     Cursor x11_cursor = 0;
 
     if (cursor) {
-        x11_cursor = (Cursor)cursor->driverdata;
+        x11_cursor = cursor->internal->cursor;
     } else {
         x11_cursor = X11_CreateEmptyCursor();
     }
 
-    /* FIXME: Is there a better way than this? */
+    // FIXME: Is there a better way than this?
     {
         SDL_VideoDevice *video = SDL_GetVideoDevice();
         Display *display = GetDisplay();
         SDL_Window *window;
 
+        x11_cursor_visible = !!cursor;
+
         for (window = video->windows; window; window = window->next) {
-            SDL_WindowData *data = window->driverdata;
+            SDL_WindowData *data = window->internal;
             if (data) {
                 if (x11_cursor != None) {
                     X11_XDefineCursor(display, data->xwindow, x11_cursor);
@@ -311,19 +320,18 @@ static int X11_ShowCursor(SDL_Cursor *cursor)
         }
         X11_XFlush(display);
     }
-    return 0;
+    return true;
 }
 
 static void X11_WarpMouseInternal(Window xwindow, float x, float y)
 {
-    SDL_VideoData *videodata = SDL_GetVideoDevice()->driverdata;
+    SDL_VideoData *videodata = SDL_GetVideoDevice()->internal;
     Display *display = videodata->display;
-    SDL_Mouse *mouse = SDL_GetMouse();
-    SDL_bool warp_hack = SDL_FALSE;
+    bool warp_hack = false;
 
-    /* XWayland will only warp the cursor if it is hidden, so this workaround is required. */
-    if (videodata->is_xwayland && mouse && mouse->cursor_shown) {
-        warp_hack = SDL_TRUE;
+    // XWayland will only warp the cursor if it is hidden, so this workaround is required.
+    if (videodata->is_xwayland && x11_cursor_visible) {
+        warp_hack = true;
     }
 
     if (warp_hack) {
@@ -352,45 +360,45 @@ static void X11_WarpMouseInternal(Window xwindow, float x, float y)
         X11_ShowCursor(SDL_GetCursor());
     }
     X11_XSync(display, False);
-    videodata->global_mouse_changed = SDL_TRUE;
+    videodata->global_mouse_changed = true;
 }
 
-static int X11_WarpMouse(SDL_Window *window, float x, float y)
+static bool X11_WarpMouse(SDL_Window *window, float x, float y)
 {
-    SDL_WindowData *data = window->driverdata;
+    SDL_WindowData *data = window->internal;
 
 #ifdef SDL_VIDEO_DRIVER_X11_XFIXES
-    /* If we have no barrier, we need to warp */
-    if (data->pointer_barrier_active == SDL_FALSE) {
+    // If we have no barrier, we need to warp
+    if (data->pointer_barrier_active == false) {
         X11_WarpMouseInternal(data->xwindow, x, y);
     }
 #else
     X11_WarpMouseInternal(data->xwindow, x, y);
 #endif
-    return 0;
+    return true;
 }
 
-static int X11_WarpMouseGlobal(float x, float y)
+static bool X11_WarpMouseGlobal(float x, float y)
 {
     X11_WarpMouseInternal(DefaultRootWindow(GetDisplay()), x, y);
-    return 0;
+    return true;
 }
 
-static int X11_SetRelativeMouseMode(SDL_bool enabled)
+static bool X11_SetRelativeMouseMode(bool enabled)
 {
     if (!X11_Xinput2IsInitialized()) {
         return SDL_Unsupported();
     }
-    return 0;
+    return true;
 }
 
-static int X11_CaptureMouse(SDL_Window *window)
+static bool X11_CaptureMouse(SDL_Window *window)
 {
     Display *display = GetDisplay();
     SDL_Window *mouse_focus = SDL_GetMouseFocus();
 
     if (window) {
-        SDL_WindowData *data = window->driverdata;
+        SDL_WindowData *data = window->internal;
 
         /* If XInput2 is handling the pointer input, non-confinement grabs will always fail with 'AlreadyGrabbed',
          * since the pointer is being grabbed by XInput2.
@@ -413,24 +421,24 @@ static int X11_CaptureMouse(SDL_Window *window)
 
     X11_XSync(display, False);
 
-    return 0;
+    return true;
 }
 
-static Uint32 X11_GetGlobalMouseState(float *x, float *y)
+static SDL_MouseButtonFlags X11_GetGlobalMouseState(float *x, float *y)
 {
-    SDL_VideoData *videodata = SDL_GetVideoDevice()->driverdata;
+    SDL_VideoData *videodata = SDL_GetVideoDevice()->internal;
     SDL_DisplayID *displays;
     Display *display = GetDisplay();
     int i;
 
-    /* !!! FIXME: should we XSync() here first? */
+    // !!! FIXME: should we XSync() here first?
 
     if (!X11_Xinput2IsInitialized()) {
-        videodata->global_mouse_changed = SDL_TRUE;
+        videodata->global_mouse_changed = true;
     }
 
-    /* check if we have this cached since XInput last saw the mouse move. */
-    /* !!! FIXME: can we just calculate this from XInput's events? */
+    // check if we have this cached since XInput last saw the mouse move.
+    // !!! FIXME: can we just calculate this from XInput's events?
     if (videodata->global_mouse_changed) {
         displays = SDL_GetDisplays(NULL);
         if (displays) {
@@ -442,11 +450,11 @@ static Uint32 X11_GetGlobalMouseState(float *x, float *y)
                     unsigned int mask;
                     if (X11_XQueryPointer(display, RootWindow(display, data->screen), &root, &child, &rootx, &rooty, &winx, &winy, &mask)) {
                         XWindowAttributes root_attrs;
-                        Uint32 buttons = 0;
+                        SDL_MouseButtonFlags buttons = 0;
                         buttons |= (mask & Button1Mask) ? SDL_BUTTON_LMASK : 0;
                         buttons |= (mask & Button2Mask) ? SDL_BUTTON_MMASK : 0;
                         buttons |= (mask & Button3Mask) ? SDL_BUTTON_RMASK : 0;
-                        /* Use the SDL state for the extended buttons - it's better than nothing */
+                        // Use the SDL state for the extended buttons - it's better than nothing
                         buttons |= (SDL_GetMouseState(NULL, NULL) & (SDL_BUTTON_X1MASK | SDL_BUTTON_X2MASK));
                         /* SDL_DisplayData->x,y point to screen origin, and adding them to mouse coordinates relative to root window doesn't do the right thing
                          * (observed on dual monitor setup with primary display being the rightmost one - mouse was offset to the right).
@@ -456,7 +464,7 @@ static Uint32 X11_GetGlobalMouseState(float *x, float *y)
                         videodata->global_mouse_position.x = root_attrs.x + rootx;
                         videodata->global_mouse_position.y = root_attrs.y + rooty;
                         videodata->global_mouse_buttons = buttons;
-                        videodata->global_mouse_changed = SDL_FALSE;
+                        videodata->global_mouse_changed = false;
                         break;
                     }
                 }
@@ -465,7 +473,7 @@ static Uint32 X11_GetGlobalMouseState(float *x, float *y)
         }
     }
 
-    SDL_assert(!videodata->global_mouse_changed); /* The pointer wasn't on any X11 screen?! */
+    SDL_assert(!videodata->global_mouse_changed); // The pointer wasn't on any X11 screen?!
 
     *x = (float)videodata->global_mouse_position.x;
     *y = (float)videodata->global_mouse_position.y;
@@ -489,16 +497,16 @@ void X11_InitMouse(SDL_VideoDevice *_this)
     SDL_HitTestResult r = SDL_HITTEST_NORMAL;
     while (r <= SDL_HITTEST_RESIZE_LEFT) {
         switch (r) {
-        case SDL_HITTEST_NORMAL: sys_cursors[r] = X11_CreateSystemCursor(SDL_SYSTEM_CURSOR_ARROW); break;
-        case SDL_HITTEST_DRAGGABLE: sys_cursors[r] = X11_CreateSystemCursor(SDL_SYSTEM_CURSOR_ARROW); break;
-        case SDL_HITTEST_RESIZE_TOPLEFT: sys_cursors[r] = X11_CreateSystemCursor(SDL_SYSTEM_CURSOR_WINDOW_TOPLEFT); break;
-        case SDL_HITTEST_RESIZE_TOP: sys_cursors[r] = X11_CreateSystemCursor(SDL_SYSTEM_CURSOR_WINDOW_TOP); break;
-        case SDL_HITTEST_RESIZE_TOPRIGHT: sys_cursors[r] = X11_CreateSystemCursor(SDL_SYSTEM_CURSOR_WINDOW_TOPRIGHT); break;
-        case SDL_HITTEST_RESIZE_RIGHT: sys_cursors[r] = X11_CreateSystemCursor(SDL_SYSTEM_CURSOR_WINDOW_RIGHT); break;
-        case SDL_HITTEST_RESIZE_BOTTOMRIGHT: sys_cursors[r] = X11_CreateSystemCursor(SDL_SYSTEM_CURSOR_WINDOW_BOTTOMRIGHT); break;
-        case SDL_HITTEST_RESIZE_BOTTOM: sys_cursors[r] = X11_CreateSystemCursor(SDL_SYSTEM_CURSOR_WINDOW_BOTTOM); break;
-        case SDL_HITTEST_RESIZE_BOTTOMLEFT: sys_cursors[r] = X11_CreateSystemCursor(SDL_SYSTEM_CURSOR_WINDOW_BOTTOMLEFT); break;
-        case SDL_HITTEST_RESIZE_LEFT: sys_cursors[r] = X11_CreateSystemCursor(SDL_SYSTEM_CURSOR_WINDOW_LEFT); break;
+        case SDL_HITTEST_NORMAL: sys_cursors[r] = X11_CreateSystemCursor(SDL_SYSTEM_CURSOR_DEFAULT); break;
+        case SDL_HITTEST_DRAGGABLE: sys_cursors[r] = X11_CreateSystemCursor(SDL_SYSTEM_CURSOR_DEFAULT); break;
+        case SDL_HITTEST_RESIZE_TOPLEFT: sys_cursors[r] = X11_CreateSystemCursor(SDL_SYSTEM_CURSOR_NW_RESIZE); break;
+        case SDL_HITTEST_RESIZE_TOP: sys_cursors[r] = X11_CreateSystemCursor(SDL_SYSTEM_CURSOR_N_RESIZE); break;
+        case SDL_HITTEST_RESIZE_TOPRIGHT: sys_cursors[r] = X11_CreateSystemCursor(SDL_SYSTEM_CURSOR_NE_RESIZE); break;
+        case SDL_HITTEST_RESIZE_RIGHT: sys_cursors[r] = X11_CreateSystemCursor(SDL_SYSTEM_CURSOR_E_RESIZE); break;
+        case SDL_HITTEST_RESIZE_BOTTOMRIGHT: sys_cursors[r] = X11_CreateSystemCursor(SDL_SYSTEM_CURSOR_SE_RESIZE); break;
+        case SDL_HITTEST_RESIZE_BOTTOM: sys_cursors[r] = X11_CreateSystemCursor(SDL_SYSTEM_CURSOR_S_RESIZE); break;
+        case SDL_HITTEST_RESIZE_BOTTOMLEFT: sys_cursors[r] = X11_CreateSystemCursor(SDL_SYSTEM_CURSOR_SW_RESIZE); break;
+        case SDL_HITTEST_RESIZE_LEFT: sys_cursors[r] = X11_CreateSystemCursor(SDL_SYSTEM_CURSOR_W_RESIZE); break;
         }
         r++;
     }
@@ -508,7 +516,7 @@ void X11_InitMouse(SDL_VideoDevice *_this)
 
 void X11_QuitMouse(SDL_VideoDevice *_this)
 {
-    SDL_VideoData *data = _this->driverdata;
+    SDL_VideoData *data = _this->internal;
     SDL_XInput2DeviceInfo *i;
     SDL_XInput2DeviceInfo *next;
     int j;
@@ -536,4 +544,4 @@ void X11_SetHitTestCursor(SDL_HitTestResult rc)
     }
 }
 
-#endif /* SDL_VIDEO_DRIVER_X11 */
+#endif // SDL_VIDEO_DRIVER_X11
